@@ -3,35 +3,30 @@
 //
 // Class: Battle
 //
-
-#include <lslutils/misc.h>
-#include <lslutils/conversion.h>
 #include "battle.h"
 
-#include <wx/timer.h>
-#include <wx/image.h>
-#include <wx/string.h>
-#include <wx/log.h>
-#include <wx/filename.h>
+#include <lslutils/conversion.h>
+#include <lslutils/misc.h>
 #include <wx/file.h>
+#include <wx/filename.h>
+#include <wx/image.h>
+#include <wx/log.h>
+#include <wx/string.h>
+#include <wx/timer.h>
 
-
-#include "user.h"
-#include "utils/conversion.h"
-#include "utils/uievents.h"
-#include "utils/battleevents.h"
-#include "gui/uiutils.h"
-#include "settings.h"
-#include "useractions.h"
-#include "gui/customdialogs.h"
-#include "iconimagelist.h"
-#include "spring.h"
-#include "utils/conversion.h"
 #include "autohostmanager.h"
-#include "log.h"
+#include "gui/customdialogs.h"
+#include "gui/uiutils.h"
+#include "iconimagelist.h"
 #include "iserver.h"
+#include "log.h"
+#include "settings.h"
+#include "spring.h"
+#include "user.h"
+#include "useractions.h"
+#include "utils/conversion.h"
 #include "utils/globalevents.h"
-
+#include "utils/uievents.h"
 
 const unsigned int TIMER_INTERVAL = 1000;
 const unsigned int TIMER_ID = wxNewId();
@@ -43,6 +38,7 @@ END_EVENT_TABLE()
 Battle::Battle(IServer& serv, int id)
     : m_auto_unspec(false)
     , m_auto_unspec_num_players(0)
+    , m_autolaunch_game(true)
     , m_serv(serv)
     , m_ah(*this)
     , m_autolock_on_start(false)
@@ -56,10 +52,13 @@ Battle::Battle(IServer& serv, int id)
 
 Battle::~Battle()
 {
-	GlobalEventManager::Instance()->UnSubscribeAll(this);
-
 	wxDELETE(m_timer);
 	wxDELETE(m_autohost_manager);
+	Leave();
+	if (m_is_self_in) {
+		GlobalEventManager::Instance()->UnSubscribe(this, GlobalEventManager::OnUnitsyncReloaded);
+		m_is_self_in = false;
+	}
 }
 
 
@@ -74,29 +73,21 @@ void Battle::SendHostInfo(const std::string& Tag)
 	m_serv.SendHostInfo(Tag);
 }
 
-void Battle::Update(const std::string& Tag)
-{
-	BattleEvents::GetBattleEventSender(BattleEvents::BattleInfoUpdate).SendEvent(std::make_pair(this, Tag));
-}
-
-
 void Battle::Join(const std::string& password)
 {
 	if (m_autohost_manager == nullptr) {
 		m_autohost_manager = new AutohostManager();
 		m_autohost_manager->SetBattle(this);
-		GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnUnitsyncReloaded, wxObjectEventFunction(&Battle::OnUnitsyncReloaded));
 	}
 	m_serv.JoinBattle(m_opts.battleid, password);
-	m_is_self_in = true;
 }
 
 
 void Battle::Leave()
 {
-	GlobalEventManager::Instance()->UnSubscribe(this, GlobalEventManager::OnUnitsyncReloaded);
-	m_serv.LeaveBattle(m_opts.battleid);
-	m_is_self_in = false;
+	if (m_is_self_in) {
+		m_serv.LeaveBattle(m_opts.battleid);
+	}
 }
 
 void Battle::OnPlayerTrueskillChanged(const std::string& NickName, double TrueSkill)
@@ -145,12 +136,10 @@ void Battle::SetImReady(bool ready)
 	SendMyBattleStatus();
 }
 
-
-/*bool Battle::HasMod()
+void Battle::SetAutolaunchGame(bool autolaunch)
 {
-  return LSL::usync().GameExists( m_opts.gamename );
-}*/
-
+	m_autolaunch_game = autolaunch;
+}
 
 void Battle::Say(const std::string& msg)
 {
@@ -232,6 +221,12 @@ User& Battle::OnUserAdded(User& user)
 	user.SetBattle(this);
 	user.BattleStatus().isfromdemo = false;
 
+	if (&user == &GetMe()) {
+		assert(!m_is_self_in);
+		m_is_self_in = true;
+		SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnUnitsyncReloaded, Battle::OnUnitsyncReloaded);
+	}
+
 	if (IsFounderMe()) {
 		if (CheckBan(user))
 			return user;
@@ -292,7 +287,6 @@ void Battle::OnUserBattleStatusUpdated(User& user, UserBattleStatus status)
 		}
 	}
 	ShouldAutoUnspec();
-	GlobalEventManager::Instance()->Send(GlobalEventManager::UserBattleStatusChangedEvent, &user);
 }
 
 
@@ -301,6 +295,11 @@ void Battle::OnUserRemoved(User& user)
 	m_ah.OnUserRemoved(user);
 	IBattle::OnUserRemoved(user);
 	ShouldAutoUnspec();
+
+	if (&user == &GetMe()) {
+		m_is_self_in = false;
+		GlobalEventManager::Instance()->UnSubscribe(this, GlobalEventManager::OnUnitsyncReloaded);
+	}
 }
 
 
@@ -330,13 +329,11 @@ void Battle::RingNotSyncedPlayers()
 
 void Battle::RingNotSyncedAndNotReadyPlayers()
 {
-	for (user_map_t::size_type i = 0; i < GetNumUsers(); i++) {
-		User& u = GetUser(i);
-		UserBattleStatus& bs = u.BattleStatus();
-		if (bs.IsBot())
-			continue;
-		if ((!bs.sync || !bs.ready) && !bs.spectator)
-			m_serv.Ring(u.GetNick());
+	if (IsFounderMe()) {
+		RingNotReadyPlayers();
+		RingNotSyncedPlayers();
+	} else {
+		m_autohost_manager->GetAutohostHandler().Ring();
 	}
 }
 
@@ -616,15 +613,21 @@ void Battle::StartHostedBattle()
 
 void Battle::StartSpring()
 {
-	if (UserExists(GetMe().GetNick()) && !GetMe().Status().in_game) {
-		GetMe().BattleStatus().ready = false;
-		SendMyBattleStatus();
-		// set m_generating_script, this will make the script.txt writer realize we're just clients even if using a relayhost
-		m_generating_script = true;
-		GetMe().Status().in_game = spring().Run(*this);
-		m_generating_script = false;
-		GetMe().SendMyUserStatus();
-	}
+	if (!m_autolaunch_game)
+		return;
+
+	User& me = GetMe();
+	if (!UserExists(me.GetNick()))
+		return;
+	if (me.Status().in_game)
+		return;
+	me.BattleStatus().ready = false;
+	SendMyBattleStatus();
+	// set m_generating_script, this will make the script.txt writer realize we're just clients even if using a relayhost
+	m_generating_script = true;
+	me.Status().in_game = spring().Run(*this);
+	m_generating_script = false;
+	me.SendMyUserStatus();
 }
 
 void Battle::OnTimer(wxTimerEvent&)
@@ -677,7 +680,7 @@ void Battle::FixColours()
 {
 	if (!IsFounderMe())
 		return;
-	std::vector<LSL::lslColor>& palette = GetFixColoursPalette(m_teams_sizes.size() + 1);
+	const std::vector<LSL::lslColor>& palette = GetFixColoursPalette(m_teams_sizes.size() + 1);
 	std::vector<int> palette_use(palette.size(), 0);
 
 	LSL::lslColor my_col = GetMe().BattleStatus().colour; // Never changes color of founder (me) :-)
@@ -806,22 +809,6 @@ void shuffle(std::vector<User*>& players) // proper shuffle.
 	}
 }
 
-/*
-bool ClanRemovalFunction(const std::map<wxString, Alliance>::value_type &v){
-  return v.second.players.size()<2;
-}
-*/
-/*
-struct ClannersRemovalPredicate{
-  std::map<wxString, Alliance> &clans;
-  PlayerRemovalPredicate(std::map<wxString, Alliance> &clans_):clans(clans_)
-  {
-  }
-  bool operator()(User *u) const{
-    return clans.find(u->GetClan());
-  }
-}*/
-
 void Battle::Autobalance(BalanceType balance_type, bool support_clans, bool strong_clans, int numallyteams)
 {
 	wxLogMessage(_T("Autobalancing alliances, type=%d, clans=%d, strong_clans=%d, numallyteams=%d"), balance_type, support_clans, strong_clans, numallyteams);
@@ -1113,15 +1100,16 @@ void Battle::FixTeamIDs(BalanceType balance_type, bool support_clans, bool stron
 
 void Battle::OnUnitsyncReloaded(wxEvent& /*data*/)
 {
-	if (m_is_self_in)
+	if (m_is_self_in) {
 		SendMyBattleStatus();
+	}
 }
 
 void Battle::ShouldAutoUnspec()
 {
 	if (m_auto_unspec && !IsLocked() && GetMe().BattleStatus().spectator) {
 		unsigned int numplayers = 0;
-		std::map<int, int> allysizes = GetAllySizes();
+		const std::map<int, int>& allysizes = GetAllySizes();
 		for (std::map<int, int>::const_iterator itor = allysizes.begin(); itor != allysizes.end(); ++itor) {
 			numplayers += itor->second;
 		}
