@@ -7,9 +7,7 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/container/battlelist.h
 
@@ -49,7 +47,7 @@ private:
 class BattleList_Iter : public SL::NonCopyable
 {
 public:
-	BattleList_Iter(BattleList* battlelist)
+	explicit BattleList_Iter(BattleList* battlelist)
 	    : m_battlelist(battlelist)
 	{
 	}
