@@ -3,24 +3,21 @@
 /**
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-DO NOT CHANGE THIS FILE!
-
-this file is deprecated and will be replaced with
+TODO: remove all wx stuff & merge / move to
 
 lsl/container/channellist.cpp
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 **/
+#include "channellist.h"
 
-
+#include <wx/log.h>
 #include <iterator>
 #include <stdexcept>
-#include <wx/log.h>
 
-#include "channellist.h"
 #include "channel.h"
-#include "utils/conversion.h"
 #include "log.h"
+#include "utils/conversion.h"
 
 const UserList::user_map_t::size_type SEEKPOS_INVALID = UserList::user_map_t::size_type(-1);
 
