@@ -5,11 +5,11 @@
 //
 #include "agreementdialog.h"
 
-#include <wx/textctrl.h>
 #include <wx/button.h>
 #include <wx/sizer.h>
-#include <wx/stattext.h>
 #include <wx/statline.h>
+#include <wx/stattext.h>
+#include <wx/textctrl.h>
 
 BEGIN_EVENT_TABLE(AgreementDialog, wxDialog)
 
@@ -56,11 +56,11 @@ AgreementDialog::AgreementDialog(wxWindow* parent, const wxString& agreement)
 
 void AgreementDialog::OnYes(wxCommandEvent& /*unused*/)
 {
-	EndModal(1);
+	EndModal(wxID_OK);
 }
 
 
 void AgreementDialog::OnNo(wxCommandEvent& /*unused*/)
 {
-	EndModal(0);
+	EndModal(wxID_CANCEL);
 }
