@@ -1,62 +1,52 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
+#include "battlelisttab.h"
 
-#include <wx/intl.h>
-#include <wx/stattext.h>
-#include <wx/statline.h>
-#include <wx/textdlg.h>
-#include <wx/combobox.h>
 #include <wx/button.h>
-#include <wx/sizer.h>
 #include <wx/checkbox.h>
+#include <wx/colour.h>
+#include <wx/combobox.h>
+#include <wx/intl.h>
 #include <wx/log.h>
-#include <stdexcept>
-#if wxUSE_TOGGLEBTN
+#include <wx/sizer.h>
+#include <wx/statline.h>
+#include <wx/stattext.h>
+#include <wx/textdlg.h>
 #include <wx/tglbtn.h>
-#endif
 #include <set>
+#include <stdexcept>
 
 #include "aui/auimanager.h"
-#include "battlelisttab.h"
-#include "battledataviewcttrl.h"
-#include "gui/ui.h"
+#include "battledataviewctrl.h"
+#include "battlelistfilter.h"
+#include "exception.h"
 #include "gui/chatpanel.h"
-#include "utils/conversion.h"
-#include "gui/controls.h"
-#include "gui/uiutils.h"
+#include "gui/customdialogs.h"
 #include "gui/hosting/hostbattledialog.h"
 #include "gui/hosting/mainjoinbattletab.h"
-#include "iserver.h"
-#include "serverselector.h"
+#include "gui/mainwindow.h"
 #include "gui/mapctrl.h"
 #include "gui/nickdataviewctrl.h"
-#include "gui/mainwindow.h"
-#include "battlelistfilter.h"
+#include "gui/ui.h"
+#include "gui/uiutils.h"
 #include "iconimagelist.h"
-#include "useractions.h"
-#include "gui/customdialogs.h"
-#include "utils/slconfig.h"
-#include "utils/globalevents.h"
+#include "iserver.h"
 #include "log.h"
 #include "servermanager.h"
-#include "contentmanager.h"
-#include "contentdownloadrequest.h"
-#include "exception.h"
-
+#include "serverselector.h"
+#include "useractions.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
+#include "utils/slconfig.h"
 //const unsigned int BATTLELIST_COLUMNCOUNT = 10;
 
 BEGIN_EVENT_TABLE(BattleListTab, wxPanel)
-	EVT_BUTTON(BattleListTab::BATTLE_JOIN, BattleListTab::OnJoin)
-	EVT_BUTTON(BattleListTab::BATTLE_HOST, BattleListTab::OnHost)
-	EVT_DATAVIEW_ITEM_ACTIVATED(BattleDataViewCtrl::BATTLELIST_DATAVIEW_ID, BattleListTab::OnListJoin)
-	EVT_DATAVIEW_SELECTION_CHANGED(BattleDataViewCtrl::BATTLELIST_DATAVIEW_ID, BattleListTab::OnSelect)
-	EVT_CHECKBOX(BattleListTab::BATTLE_LIST_FILTER_ACTIV, BattleListTab::OnFilterActiv)
-	#if wxUSE_TOGGLEBTN
-	EVT_TOGGLEBUTTON(BattleListTab::BATTLE_LIST_FILTER_BUTTON, BattleListTab::OnFilter)
-	EVT_TOGGLEBUTTON(BattleListTab::BATTLE_LIST_INFO_BUTTON, BattleListTab::OnInfoShow)
-	#else
-	EVT_CHECKBOX(BattleListTab::BATTLE_LIST_FILTER_BUTTON, BattleListTab::OnFilter)
-	EVT_CHECKBOX(BattleListTab::BATTLE_LIST_INFO_BUTTON, BattleListTab::OnOnInfoShow)
-	#endif
+EVT_BUTTON(BattleListTab::BATTLE_JOIN, BattleListTab::OnJoin)
+EVT_BUTTON(BattleListTab::BATTLE_HOST, BattleListTab::OnHost)
+EVT_DATAVIEW_ITEM_ACTIVATED(BattleDataViewCtrl::BATTLELIST_DATAVIEW_ID, BattleListTab::OnListJoin)
+EVT_DATAVIEW_SELECTION_CHANGED(BattleDataViewCtrl::BATTLELIST_DATAVIEW_ID, BattleListTab::OnSelect)
+EVT_CHECKBOX(BattleListTab::BATTLE_LIST_FILTER_ACTIV, BattleListTab::OnFilterActiv)
+EVT_TOGGLEORCHECK(BattleListTab::BATTLE_LIST_FILTER_BUTTON, BattleListTab::OnFilter)
+EVT_TOGGLEORCHECK(BattleListTab::BATTLE_LIST_INFO_BUTTON, BattleListTab::OnInfoShow)
 END_EVENT_TABLE()
 
 SLCONFIG("/BattleFilter/Active", false, "determines if battle list filter is active");
@@ -67,111 +57,105 @@ BattleListTab::BattleListTab(wxWindow* parent)
     : wxPanel(parent, -1)
     , m_sel_battle(0)
 {
+	auto AddToSizer = [&](wxSizer* sizer, int height, wxWindow* window) {
+		return sizer->Add (window, 0, wxALL, height);
+	};
+
 	GetAui().manager->AddPane(this, wxLEFT, _T( "battlelisttab" ));
 
-	m_main_sizer = new wxBoxSizer(wxVERTICAL);
-
-	wxBoxSizer* m_filter_sizer;
-	m_filter_sizer = new wxBoxSizer(wxVERTICAL);
-
-
-	m_battlelist_sizer = new wxBoxSizer(wxVERTICAL);
-
-	m_battle_list = new BattleDataViewCtrl(_T("BattleDataViewCtrl_BattleList"), this);
+	m_battle_list = new BattleDataViewCtrl(_T("BattleDataViewCtrl_BattleList2"), this);
 //	m_battle_list->SetHighLightAction(UserActions::ActHighlight);
-	m_battlelist_sizer->Add(m_battle_list, 1, wxEXPAND);
 
-	m_main_sizer->Add(m_battlelist_sizer, 1, wxEXPAND);
+
+	m_players_lbl  = new wxStaticText(this, wxID_ANY, _("Players:"));
+	m_players_text = new wxStaticText(this, wxID_ANY, wxEmptyString);
+	m_map_lbl      = new wxStaticText(this, wxID_ANY, _("Map:"));
+	m_map_text     = new wxStaticText(this, wxID_ANY, wxEmptyString);
+	m_game_lbl     = new wxStaticText(this, wxID_ANY, _("Game:"));
+	m_game_text    = new wxStaticText(this, wxID_ANY, wxEmptyString);
+	m_engine_lbl   = new wxStaticText(this, wxID_ANY, _("Engine:"));
+	m_engine_text  = new wxStaticText(this, wxID_ANY, wxEmptyString);
+	m_host_lbl     = new wxStaticText(this, wxID_ANY, _("Host:"));
+	m_host_text    = new wxStaticText(this, wxID_ANY, wxEmptyString);
+
+	const int bib_height = 5; // Battle Info element border height
+	const wxSize bib_button_size(-1, m_host_text->GetSize().GetHeight()+2*bib_height);
+
+	m_host_notify_button = new wxToggleOrCheck(this, wxID_ANY, _("Notify"), wxDefaultPosition,
+	                                           bib_button_size, wxBU_EXACTFIT);
+	m_host_notify_button->Disable();
+	m_host_notify_button->SetToolTip(_("Notify me when the battle ends (Only supported by bots)"));
+	m_host_notify_button->Bind(wxEVT_TOGGLEBUTTON, &BattleListTab::OnNotifyWhenBattleEnds, this);
+
+	wxBoxSizer* m_host_info_sizer = new wxBoxSizer(wxHORIZONTAL);
+	m_host_info_sizer->Add(m_host_notify_button);
+	m_host_info_sizer->Add(m_host_text, 0, wxALL, bib_height);
+
+	m_data_sizer = new wxFlexGridSizer(5, 2, 0, 0);
+	AddToSizer(m_data_sizer, bib_height, m_players_lbl);
+	AddToSizer(m_data_sizer, bib_height, m_players_text);
+	AddToSizer(m_data_sizer, bib_height, m_map_lbl);
+	AddToSizer(m_data_sizer, bib_height, m_map_text);
+	AddToSizer(m_data_sizer, bib_height, m_game_lbl);
+	AddToSizer(m_data_sizer, bib_height, m_game_text);
+	AddToSizer(m_data_sizer, bib_height, m_engine_lbl);
+	AddToSizer(m_data_sizer, bib_height, m_engine_text);
+	AddToSizer(m_data_sizer, bib_height, m_host_lbl);
+	m_data_sizer->Add(m_host_info_sizer, 0, wxALL, 0);
+
+
+	wxSize s = m_data_sizer->CalcMin();
+	wxLogDebug (_T("Minimum size for data sizer: %d x %d"), s.GetHeight(), s.GetWidth() );
+	m_minimap = new MapCtrl(this, s.GetHeight(), 0, true, false, false);
+	m_players = new NickDataViewCtrl(_T("NickDataViewCtrl_BattleListTab"), this, false, 0, true);
 
 	m_info_sizer = new wxBoxSizer(wxHORIZONTAL);
-
-	m_minimap = new MapCtrl(this, 100, 0, true, false, false);
-	m_info_sizer->Add(m_minimap, 0, wxALL, 5);
-
-	m_data_sizer = new wxFlexGridSizer(4, 2, 0, 0);
-
-	m_map_lbl = new wxStaticText(this, wxID_ANY, _("Map:"), wxDefaultPosition, wxDefaultSize, 0);
-	m_data_sizer->Add(m_map_lbl, 0, wxALL, 5);
-
-	m_map_text = new wxStaticText(this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0);
-	m_data_sizer->Add(m_map_text, 0, wxALL, 5);
-
-	m_mod_lbl = new wxStaticText(this, wxID_ANY, _("Game:"), wxDefaultPosition, wxDefaultSize, 0);
-	m_data_sizer->Add(m_mod_lbl, 0, wxALL, 5);
-
-	m_mod_text = new wxStaticText(this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0);
-	m_data_sizer->Add(m_mod_text, 0, wxALL, 5);
-
-	m_players_lbl = new wxStaticText(this, wxID_ANY, _("Players:"), wxDefaultPosition, wxDefaultSize, 0);
-	m_data_sizer->Add(m_players_lbl, 0, wxALL, 5);
-
-	m_players_text = new wxStaticText(this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0);
-	m_data_sizer->Add(m_players_text, 0, wxALL, 5);
-
-	m_spec_lbl = new wxStaticText(this, wxID_ANY, _("Spectators:"), wxDefaultPosition, wxDefaultSize, 0);
-	m_data_sizer->Add(m_spec_lbl, 0, wxALL, 5);
-
-	m_spec_text = new wxStaticText(this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0);
-	m_data_sizer->Add(m_spec_text, 0, wxALL, 5);
-
-	m_info_sizer->Add(m_data_sizer, 1, wxEXPAND, 5);
-
-	m_players = new NickDataViewCtrl(_T("NickDataViewCtrl_BattleListTab"), this, false, 0, true);
-	m_info_sizer->Add(m_players, 1, wxALL | wxEXPAND, 5);
-
-	m_main_sizer->Add(m_info_sizer, 0, wxEXPAND, 5);
+	m_info_sizer->Add(m_minimap, 0, wxALL, bib_height);
+	m_info_sizer->Add(m_data_sizer, 1, wxEXPAND, bib_height);
+	m_info_sizer->Add(m_players, 1, wxALL | wxEXPAND, bib_height);
 
 
-	m_filter = new BattleListFilter(this, wxID_ANY, this, wxDefaultPosition, wxSize(-1, -1), wxEXPAND);
-	m_filter_sizer->Add(m_filter, 0, wxEXPAND, 5);
-
-	m_main_sizer->Add(m_filter_sizer, 0, wxEXPAND, 5);
-
-	m_buttons_sep = new wxStaticLine(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxLI_HORIZONTAL);
-	m_main_sizer->Add(m_buttons_sep, 0, wxALL | wxEXPAND, 5);
-
-	wxBoxSizer* m_buttons_sizer;
-	m_buttons_sizer = new wxBoxSizer(wxHORIZONTAL);
-
-	m_buttons_sizer->Add(0, 0, 1, wxEXPAND, 0);
-
-#if wxUSE_TOGGLEBTN
-	m_filter_show = new wxToggleButton(this, BATTLE_LIST_FILTER_BUTTON, _(" Filter "), wxDefaultPosition, wxSize(-1, 28), 0);
-#else
-	m_filter_show = new wxCheckBox(this, BATTLE_LIST_FILTER_BUTTON, _(" Filter "), wxDefaultPosition, wxSize(-1, 28), 0);
-#endif
-	m_buttons_sizer->Add(m_filter_show, 0, 0, 5);
-
-	m_filter_activ = new wxCheckBox(this, BATTLE_LIST_FILTER_ACTIV, _("Activated"), wxDefaultPosition, wxDefaultSize, 0);
-	m_buttons_sizer->Add(m_filter_activ, 0, wxALL, 5);
-
-#if wxUSE_TOGGLEBTN
-	m_info_show = new wxToggleButton(this, BATTLE_LIST_INFO_BUTTON, _(" Battle infos "), wxDefaultPosition, wxSize(-1, 28), 0);
-#else
-	m_info_show = new wxCheckBox(this, BATTLE_LIST_INFO_BUTTON, _(" Battle infos "), wxDefaultPosition, wxSize(-1, 28), 0);
-#endif
-	m_buttons_sizer->Add(m_info_show, 0, 0, 5);
-
-	m_battle_num = new wxStaticText(this, wxID_ANY, _("0 battles displayed"), wxDefaultPosition, wxDefaultSize, 0);
-	m_buttons_sizer->Add(m_battle_num, 0, wxALIGN_CENTER | wxLEFT | wxRIGHT, 4);
-	m_buttons_sizer->Add(0, 0, 1, wxEXPAND, 0);
-
-	m_host_btn = new wxButton(this, BATTLE_HOST, _("Host new..."), wxDefaultPosition, wxSize(-1, 28), 0);
-	m_buttons_sizer->Add(m_host_btn, 0, wxBOTTOM | wxLEFT | wxRIGHT, 5);
-
-	m_join_btn = new wxButton(this, BATTLE_JOIN, _("Join"), wxDefaultPosition, wxSize(-1, 28), 0);
-	m_buttons_sizer->Add(m_join_btn, 0, wxBOTTOM | wxRIGHT, 5);
-
-	m_main_sizer->Add(m_buttons_sizer, 0, wxEXPAND, 5);
-
+	m_filter = new BattleListFilter(this, wxID_ANY, this, wxDefaultPosition, wxDefaultSize, wxEXPAND);
 	m_filter->Hide();
 
+
+	const wxSize br_size (-1, 28); // Button row size
+	m_host_btn = new wxButton(this, BATTLE_HOST, _("Host new..."), wxDefaultPosition, br_size, 0);
+	m_filter_activ = new wxCheckBox(this, BATTLE_LIST_FILTER_ACTIV, _("Activated"));
+	m_filter_show = new wxToggleOrCheck(this, BATTLE_LIST_FILTER_BUTTON, _(" Filter "), wxDefaultPosition, br_size, 0);
+	m_info_show = new wxToggleOrCheck(this, BATTLE_LIST_INFO_BUTTON, _(" Battle infos "), wxDefaultPosition, br_size, 0);
+	m_battle_num = new wxStaticText(this, wxID_ANY, _("0 battles displayed"));
+	m_rank_warn = new wxStaticText(this, wxID_ANY, _("Insufficient rank") + _T("!"));
+	m_rank_warn->SetForegroundColour(*wxRED);
+	m_rank_warn->Hide();
+	m_join_btn = new wxButton(this, BATTLE_JOIN, _("Join"), wxDefaultPosition, br_size, 0);
+
+	wxBoxSizer* m_buttons_sizer = new wxBoxSizer(wxHORIZONTAL);
+	m_buttons_sizer->Add(m_host_btn, 0, wxBOTTOM | wxLEFT | wxRIGHT, 5);
+	m_buttons_sizer->Add(0, 0, 1, wxEXPAND, 0);
+	m_buttons_sizer->Add(m_filter_show, 0, 0, 5);
+	m_buttons_sizer->Add(m_filter_activ, 0, wxALL, 5);
+	m_buttons_sizer->Add(m_info_show, 0, 0, 5);
+	m_buttons_sizer->Add(m_battle_num, 0, wxALIGN_CENTER | wxLEFT | wxRIGHT, 4);
+	m_buttons_sizer->Add(0, 0, 1, wxEXPAND, 0);
+	m_buttons_sizer->Add(m_rank_warn,  0, wxALIGN_CENTER | wxLEFT | wxRIGHT, 4);
+	m_buttons_sizer->Add(m_join_btn, 0, wxBOTTOM | wxRIGHT, 5);
+
+
+	m_buttons_sep = new wxStaticLine(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxLI_HORIZONTAL);
+
+	m_main_sizer = new wxBoxSizer(wxVERTICAL);
+	m_main_sizer->Add(m_battle_list, 1, wxEXPAND);
+	m_main_sizer->Add(m_info_sizer, 0, wxEXPAND, 5);
+	m_main_sizer->Add(m_filter, 0, wxEXPAND, 5);
+	m_main_sizer->Add(m_buttons_sep, 0, wxALL | wxEXPAND, 5);
+	m_main_sizer->Add(m_buttons_sizer, 0, wxEXPAND, 5);
 	SetSizer(m_main_sizer);
 	Layout();
 
 	SelectBattle(0);
 	ShowExtendedInfos(cfg().ReadBool(_T("/BattleListTab/ShowExtendedInfos")));
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnUnitsyncReloaded, wxObjectEventFunction(&BattleListTab::OnUnitsyncReloaded));
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnUnitsyncReloaded, BattleListTab::OnUnitsyncReloaded);
 }
 
 
@@ -199,19 +183,41 @@ void BattleListTab::SelectBattle(IBattle* battle)
 {
 	m_sel_battle = battle;
 	m_minimap->SetBattle(m_sel_battle);
+	m_host_notify_button->SetValue(false);
 	m_players->ClearUsers();
+	m_players_text->SetForegroundColour(wxNullColour); //Resets colour
+
 	if (m_sel_battle != 0) {
+		int num_players = static_cast<int>(battle->GetNumUsers()) - battle->GetSpectators();
+
+		if (m_sel_battle->GetFounder().Status().bot) {
+			m_host_notify_button->Enable();
+		} else {
+			m_host_notify_button->Disable();
+		}
+		if (m_sel_battle->GetRankNeeded() > m_sel_battle->GetMe().GetRank())
+			m_rank_warn->Show();
+		else
+			m_rank_warn->Hide();
+		m_engine_text->SetLabel(m_sel_battle->GetEngineName() + _T(" ") + m_sel_battle->GetEngineVersion());
+		m_game_text->SetLabel(TowxString(m_sel_battle->GetHostGameName()));
+		m_host_text->SetLabel(m_sel_battle->GetFounder().GetNick());
 		m_map_text->SetLabel(TowxString(m_sel_battle->GetHostMapName()));
-		m_mod_text->SetLabel(TowxString(m_sel_battle->GetHostGameName()));
-		m_players_text->SetLabel(wxString::Format(_T( "%d / %d" ), int(m_sel_battle->GetNumUsers()) - int(m_sel_battle->GetSpectators()), int(m_sel_battle->GetMaxPlayers())));
-		m_spec_text->SetLabel(wxString::Format(_T( "%d" ), m_sel_battle->GetSpectators()));
 		m_players->SetUsers(m_sel_battle->GetUsers());
+		m_players_text->SetLabel(wxString::Format(_T("%d (Max: %d) + %d spectators"), num_players,
+		  static_cast<int>(m_sel_battle->GetMaxPlayers()), m_sel_battle->GetSpectators() ));
+		if (num_players == static_cast<int>(m_sel_battle->GetMaxPlayers()))
+			m_players_text->SetForegroundColour(*wxRED);
 	} else {
+		m_engine_text->SetLabel(wxEmptyString);
+		m_host_notify_button->Disable();
+		m_game_text->SetLabel(wxEmptyString);
+		m_host_text->SetLabel(wxEmptyString);
 		m_map_text->SetLabel(wxEmptyString);
-		m_mod_text->SetLabel(wxEmptyString);
-		m_players_text->SetLabel(_T( "0 / 0" ));
-		m_spec_text->SetLabel(_T( "0" ));
+		m_players_text->SetLabel(wxEmptyString);
+		m_rank_warn->Hide();
 	}
+	this->Layout();
 }
 
 void BattleListTab::AddBattle(IBattle& battle)
@@ -297,7 +303,7 @@ void BattleListTab::OnHost(wxCommandEvent& /*unused*/)
 {
 	if (!ServerManager::Instance()->IsConnected()) {
 		wxLogWarning(_T( "Trying to host while offline" ));
-		customMessageBoxNoModal(SL_MAIN_ICON, _("You cannot host a game while being offline. Please connect to a lobby server."), _("Not Online."), wxOK);
+		customMessageBoxModal(SL_MAIN_ICON, _("You cannot host a game while being offline. Please connect to a lobby server."), _("Not Online."), wxOK);
 		ui().ShowConnectWindow();
 		return;
 	}
@@ -315,6 +321,14 @@ void BattleListTab::OnHost(wxCommandEvent& /*unused*/)
 	HostBattleDialog::RunHostBattleDialog(this);
 }
 
+void BattleListTab::OnNotifyWhenBattleEnds(wxCommandEvent& event)
+{
+	if (m_host_notify_button->GetValue()) {
+		m_host_notify_button->Disable();
+		m_battle_list->OnNotifyWhenBattleEnds(event);
+	}
+}
+
 /**
  * Procees "Show Filtes" toggle buttton clicked. Show/hides filters options panel
  * @param
@@ -393,15 +407,15 @@ void BattleListTab::DoJoin(IBattle& battle)
 
 	IBattle* curbattle = ui().mw().GetJoinTab().GetCurrentBattle();
 
-	//If trying to join battle player already joined
-	if (curbattle != 0 && curbattle->GetID() == battle.GetID()) {
-		ui().mw().ShowTab(MainWindow::PAGE_JOIN);
-		return;
-	}
-
 	//If player already in another battle
 	if (curbattle != 0) {
-		if (ui().Ask(_("Already in another battle"), _("You are already in a battle.\n\nDo you want to leave your current battle and join this one?"))) {
+		//If trying to join same battle again
+		if (curbattle->GetID() == battle.GetID()) {
+			ui().mw().ShowTab(MainWindow::PAGE_BATTLEROOM);
+			return;
+		}
+
+		if (ui().Ask(_("Already in another battle"), _("You are already in a battle.") + _("Do you want to leave your current battle and join this one?"))) {
 			curbattle->Leave();
 			ui().mw().GetJoinTab().LeaveCurrentBattle();
 		} else {
@@ -421,27 +435,10 @@ void BattleListTab::DoJoin(IBattle& battle)
 		password.Replace(_T(" "), wxEmptyString);
 	}
 
-	//Check if some content needs to be downloaded
-	ContentDownloadRequest req = ContentManager::Instance()->WhatContentForBattleIsRequired(battle);
-	if (req.IsSomethingNeeded()) {
-		if (wxYES == customMessageBox(SL_MAIN_ICON,
-				TowxString(req.GetRequiredContentAsString()) + _("Shall I download it for you?"),
-				_("Content is needed"),
-				wxYES_NO | wxICON_QUESTION)) {
-			try {
-				ContentManager::Instance()->DownloadContent(req);
-			} catch (Exception& e) {
-				wxLogError(e.Reason());
-				return;
-			}
-		} else {
-			return;
-		}
-	}
 
 	battle.Join(STD_STRING(password));
 	//Change Tab to show user joining to battle is in progress
-	ui().mw().ShowTab(MainWindow::PAGE_JOIN);
+	ui().mw().ShowTab(MainWindow::PAGE_BATTLEROOM);
 }
 
 /**
@@ -465,7 +462,7 @@ void BattleListTab::OnSelect(wxDataViewEvent& /*event*/)
  */
 void BattleListTab::OnUnitsyncReloaded(wxCommandEvent& /*data*/)
 {
-	ASSERT_LOGIC(wxThread::IsMain(), "wxThread::IsMain() == false");
+	ASSERT_LOGIC(wxThread::IsMain(), "wxThread::IsMain()");
 
 	if (!serverSelector().IsServerAvailible())
 		return;
