@@ -3,53 +3,52 @@
 //
 // Class: ChatPanel
 //
-
-#include "utils/curlhelper.h" //has to be first include, as else it warns about winsock2.h should be included first
-#include "utils/conversion.h"
-#include "gui/customdialogs.h"
-#include "uiutils.h"
-
 #include "chatpanel.h"
 
-#include <wx/intl.h>
-#include <wx/splitter.h>
-#include <wx/tokenzr.h>
 #include <wx/app.h>
+#include <wx/bmpbuttn.h>
 #include <wx/clipbrd.h>
 #include <wx/dataobj.h>
-#include <wx/bmpbuttn.h>
+#include <wx/intl.h>
+#include <wx/splitter.h>
 #include <wx/stattext.h>
+#include <wx/tokenzr.h>
 #include <wx/wupdlock.h>
 
 #include "aui/auimanager.h"
-#include "gui/slbook.h"
 #include "channel.h"
+#include "chatpanelmenu.h"
+#include "gui/controls.h"
+#include "gui/customdialogs.h"
+#include "gui/hosting/votepanel.h"
+#include "gui/iconscollection.h"
+#include "gui/mainwindow.h"
+#include "gui/pastedialog.h"
+#include "gui/slbook.h"
+#include "gui/wxtextctrlhist.h"
+#include "ibattle.h"
+#include "iserver.h"
+#include "log.h"
+#include "mainwindow.h"
+#include "nickdataviewctrl.h"
+#include "serverselector.h"
+#include "uiutils.h"
+#include "utils/conversion.h"
+#include "utils/curlhelper.h" //has to be first include, as else it warns about winsock2.h should be included first
+#include "utils/globalevents.h"
+#include "utils/slconfig.h"
 #include "utils/uievents.h"
 #include "utils/version.h"
-#include "iserver.h"
-#include "serverselector.h"
-#include "ibattle.h"
-#include "nickdataviewctrl.h"
-#include "mainwindow.h"
-#include "chatpanelmenu.h"
-#include "gui/pastedialog.h"
-#include "gui/wxtextctrlhist.h"
-#include "log.h"
-#include "utils/slconfig.h"
-#include "gui/hosting/votepanel.h"
-#include "utils/globalevents.h"
-#include "iconimagelist.h"
-#include "gui/controls.h"
 
 BEGIN_EVENT_TABLE(ChatPanel, wxPanel)
-	EVT_TEXT_ENTER(CHAT_TEXT, ChatPanel::OnSay)
-	EVT_TEXT_PASTE(CHAT_TEXT, ChatPanel::OnPaste)
-	EVT_BUTTON(CHAT_CHAN_OPTS, ChatPanel::OnChanOpts)
-	EVT_BUTTON(CHAT_SEND, ChatPanel::OnSay)
-	EVT_TEXT_URL(CHAT_LOG, ChatPanel::OnLinkEvent)
-	EVT_MENU(wxID_ANY, ChatPanel::OnMenuItem)
-	EVT_TEXT(FILTER_USERS, ChatPanel::OnFilterUsers)
-	EVT_CHECKBOX(SHOW_PLAYERS_ONLY_CHECK, ChatPanel::OnShowPlayerOnlyCheck)
+EVT_TEXT_ENTER(CHAT_TEXT, ChatPanel::OnSay)
+EVT_TEXT_PASTE(CHAT_TEXT, ChatPanel::OnPaste)
+EVT_BUTTON(CHAT_CHAN_OPTS, ChatPanel::OnChanOpts)
+EVT_BUTTON(CHAT_SEND, ChatPanel::OnSay)
+EVT_TEXT_URL(CHAT_LOG, ChatPanel::OnLinkEvent)
+EVT_MENU(wxID_ANY, ChatPanel::OnMenuItem)
+EVT_TEXT(FILTER_USERS, ChatPanel::OnFilterUsers)
+EVT_CHECKBOX(SHOW_PLAYERS_ONLY_CHECK, ChatPanel::OnShowPlayerOnlyCheck)
 END_EVENT_TABLE()
 
 
@@ -91,8 +90,8 @@ void ChatPanel::Init(const wxString& panelname)
 	GetAui().manager->AddPane(this, wxLEFT, _T("chatpanel-channel-") + panelname);
 	m_chatlog_text->Connect(wxEVT_RIGHT_DOWN, wxMouseEventHandler(ChatPanel::OnMouseDown), 0, this);
 
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnLogin, wxObjectEventFunction(&ChatPanel::OnLogin));
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::ApplicationSettingsChangedEvent, wxObjectEventFunction(&ChatPanel::OnSettingsChanged));
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnLogin, ChatPanel::OnLogin);
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::ApplicationSettingsChangedEvent, ChatPanel::OnSettingsChanged);
 }
 
 ChatPanel::ChatPanel(wxWindow* parent, Channel& chan, wxImageList* imaglist)
@@ -229,6 +228,7 @@ ChatPanel::~ChatPanel()
 
 	m_chatlog_text->Disconnect(wxEVT_RIGHT_DOWN, wxMouseEventHandler(ChatPanel::OnMouseDown), 0, 0);
 	wxDELETE(m_chatlog_text);
+	wxDELETE(m_popup_menu);
 
 	if (GetAui().manager) {
 		GetAui().manager->DetachPane(this);
@@ -254,8 +254,8 @@ void ChatPanel::CreateControls()
 		m_usercount_label = new wxStaticText(m_nick_panel, wxID_ANY, wxEmptyString);
 		m_showPlayerOnlyCheck = new wxCheckBox(m_nick_panel, SHOW_PLAYERS_ONLY_CHECK, _("Hide bots"));
 
-		wxBoxSizer* nickListHeaderSizer = new wxBoxSizer(wxHORIZONTAL);
-		nickListHeaderSizer->Add(m_usercount_label, 1, wxEXPAND);
+		wxBoxSizer* nickListHeaderSizer = new wxBoxSizer(wxVERTICAL);
+		nickListHeaderSizer->Add(m_usercount_label, 0, wxEXPAND);
 		nickListHeaderSizer->Add(m_showPlayerOnlyCheck, 0, wxEXPAND);
 
 		UpdateUserCountLabel();
@@ -295,20 +295,15 @@ void ChatPanel::CreateControls()
 
 	wxBitmap ico;
 	if (m_type == CPT_User && (m_user != NULL)) {
-		const int userstatus = icons().GetUserBattleStateIcon(m_user->GetStatus());
-		if (userstatus == icons().ICON_NOSTATE) {
-			ico = icons().GetBitmap(icons().ICON_CHANNEL_OPTIONS);
-		} else {
-			ico = icons().GetBitmap(userstatus);
-		}
+		ico = IconsCollection::Instance()->GetUserBattleStateBmp(m_user->GetStatus());
 	} else {
-		ico = icons().GetBitmap(icons().ICON_CHANNEL_OPTIONS);
+		ico = IconsCollection::Instance()->BMP_CHANNEL_OPTIONS;
 	}
 	m_chan_opts_button = new wxBitmapButton(m_chat_panel, CHAT_CHAN_OPTS, ico, wxDefaultPosition, wxSize(CONTROL_HEIGHT, CONTROL_HEIGHT));
 
 	m_say_text = new wxTextCtrlHist(
 	    textcompletiondatabase, m_chat_panel, CHAT_TEXT,
-	    wxEmptyString, wxDefaultPosition, wxSize(100, CONTROL_HEIGHT),
+	    wxEmptyString, wxDefaultPosition, wxDefaultSize,
 	    wxTE_PROCESS_ENTER | wxTE_PROCESS_TAB);
 	m_say_button = new wxButton(m_chat_panel, CHAT_SEND, _("Send"), wxDefaultPosition, wxSize(80, CONTROL_HEIGHT));
 
@@ -322,7 +317,7 @@ void ChatPanel::CreateControls()
 	if (m_show_nick_list) {
 		m_chat_panel->SetSizer(m_chat_sizer);
 		m_splitter->SplitVertically(m_chat_panel, m_nick_panel, 100);
-		m_splitter->SetMinimumPaneSize(30);
+		m_splitter->SetMinimumPaneSize(MINIMUM_PANE_SIZE);
 		m_main_sizer->Add(m_splitter, 1, wxEXPAND | wxALL, 2);
 	} else {
 		m_main_sizer->Add(m_chat_sizer, 4, wxEXPAND | wxALL, 2);
@@ -333,7 +328,7 @@ void ChatPanel::CreateControls()
 
 	if (m_show_nick_list) {
 		wxSize s = m_splitter->GetSize();
-		m_splitter->SetSashPosition(s.GetWidth() - 238, true);
+		m_splitter->SetSashPosition(s.GetWidth() - MINIMUM_PANE_SIZE, true);
 	}
 
 	m_chatlog_text->ShowPosition(m_chatlog_text->GetLastPosition());
@@ -382,17 +377,14 @@ void ChatPanel::OutputLine(const wxString& message, const wxColour& col, bool sh
 	if (!m_chatlog_text)
 		return;
 
-	wxDateTime now = wxDateTime::Now();
-	wxTextAttr timestyle(sett().GetChatColorTime(), sett().GetChatColorBackground());
-	wxTextAttr chatstyle(col, sett().GetChatColorBackground());
-
 	ChatLine newline;
-	newline.chat = wxString(message.c_str());
-	newline.chatstyle = chatstyle;
+	newline.chat = message;
+	newline.chatstyle = wxTextAttr(col, sett().GetChatColorBackground());
 	if (showtime) {
+		wxDateTime now = wxDateTime::Now();
 		newline.time = _T( "[" ) + now.Format(_T( "%H:%M:%S" )) + _T( "]" );
-		newline.timestyle = timestyle;
-		m_chat_log.AddMessage(message);
+		newline.timestyle = wxTextAttr(sett().GetChatColorTime(), sett().GetChatColorBackground());
+		m_chat_log.AddMessage(newline.time + _T(" ") + message);
 	} else {
 		newline.time.clear();
 	}
@@ -404,6 +396,19 @@ void ChatPanel::OutputLine(const wxString& message, const wxColour& col, bool sh
 	}
 }
 
+static size_t FirstSpecialChar(const wxString& str)
+{
+	for (size_t pos = 0; pos < str.Len(); pos++) {
+		if (!str.GetChar(pos).IsAscii()) {
+			continue;
+		}
+		const unsigned char uc = str.GetChar(pos);
+		if (uc == 0x1f || uc == 0x1d || uc == 0x03 || uc == 0x02 || uc == 0x016 || uc == 0x0F) { //get all text until first irc color is found
+			return pos;
+		}
+	}
+	return -1;
+}
 
 void ChatPanel::OutputLine(const ChatLine& line)
 {
@@ -423,7 +428,9 @@ void ChatPanel::OutputLine(const ChatLine& line)
 
 	if (!line.time.empty()) {
 		m_chatlog_text->SetDefaultStyle(line.timestyle);
-		m_chatlog_text->AppendText(line.time);
+		m_chatlog_text->AppendText(line.time + _T(" "));
+	} else {
+		m_chatlog_text->SetDefaultStyle(line.chatstyle);
 	}
 
 #ifndef __WXOSX_COCOA__
@@ -439,30 +446,8 @@ void ChatPanel::OutputLine(const ChatLine& line)
 		const wxColor oldcolor(line.chatstyle.GetTextColour());
 
 		while (m1.Len() > 0) {
-			const wxUniChar c = m1.GetChar(0);
-			if (c == 3 && m1.Len() > 1 && (m1.GetChar(1) >= 48 && m1.GetChar(1) <= 58)) { // Color
-				if (m1.Len() > 2 && (m1.GetChar(2) >= 48 && m1.GetChar(2) <= 58)) {
-					color = (int(m1.GetChar(1)) - 48) * 10 + (int(m1.GetChar(2)) - 48);
-					m1 = m1.Mid(3);
-				} else {
-					color = int(m1.GetChar(1)) - 48;
-					m1 = m1.Mid(2);
-				}
-
-				wxColor dummy(0, 0, 0);
-				if ((color > -1) && (color < long((sizeof(m_irc_colors) / sizeof(dummy))))) {
-					curcolor = m_irc_colors[color];
-				}
-
-			} else if (c == 2) { //Bold
-				bold = !bold;
-				m1 = m1.Mid(1);
-			} else if (c == 0x0F) { //Reset formatting
-				bold = false;
-				curcolor = oldcolor;
-				m1 = m1.Mid(1);
-			} else {
-
+			const size_t firstspec = FirstSpecialChar(m1);
+			if (firstspec > 0) {	   //unformated text found, add as whole
 				wxFont font = oldfont; //isn't needed any more in wx3.0
 				at = line.chatstyle;
 				if (bold)
@@ -470,9 +455,44 @@ void ChatPanel::OutputLine(const ChatLine& line)
 				at.SetFont(font);
 				at.SetTextColour(curcolor);
 				m_chatlog_text->SetDefaultStyle(at);
-				m_chatlog_text->AppendText(m1.Mid(0, 1));
-				m1 = m1.Mid(1);
+				m_chatlog_text->AppendText(m1.Mid(0, firstspec));
+				m1 = m1.Mid(firstspec);
+				if (m1.Len() <= 0) { //no chars left, abort
+					break;
+				}
 			}
+			const unsigned char uc = m1.GetChar(0);
+			switch (uc) {      //  http://en.wikichip.org/wiki/irc/colors
+				case 0x1f: //underline
+					break;
+				case 0x1d: //italics
+					break;
+				case 0x03: {
+					if (m1.Len() > 2 && (m1.GetChar(2) >= 48 && m1.GetChar(2) <= 58)) {
+						color = (int(m1.GetChar(1)) - 48) * 10 + (int(m1.GetChar(2)) - 48);
+						m1 = m1.Mid(2); //next chars
+					} else {
+						color = int(m1.GetChar(1)) - 48;
+						m1 = m1.Mid(1); //next char
+					}
+
+					wxColor dummy(0, 0, 0);
+					if ((color > -1) && (color < long((sizeof(m_irc_colors) / sizeof(dummy))))) {
+						curcolor = m_irc_colors[color];
+					}
+					break;
+				}
+				case 0x02: //bold
+					bold = !bold;
+					break;
+				case 0x16: //reverse;
+					break;
+				case 0x0F: //reset formating
+					bold = false;
+					curcolor = oldcolor;
+					break;
+			}
+			m1 = m1.Mid(1); //next char!
 		}
 		m_chatlog_text->AppendText(_T("\n"));
 	} else
@@ -510,6 +530,13 @@ void ChatPanel::OnSay(wxCommandEvent& /*unused*/)
 {
 	if (Say(m_say_text->GetValue()))
 		m_say_text->SetValue(wxEmptyString);
+	/*
+	Say("\x02Test\x02Test");
+	Say("\x02\x02Test\x02Test");
+	Say("Test\x02Test");
+	Say("TestTes\x02t");
+	Say("TestTest\x02");
+*/
 }
 
 void ChatPanel::OnFilterUsers(wxCommandEvent& /*unused*/)
@@ -569,9 +596,9 @@ void ChatPanel::Said(const wxString& who, const wxString& message)
 		wxString message2;
 		who2 = message.BeforeFirst('>').AfterFirst('<');
 		message2 = message.AfterFirst('>');
-		OutputLine(_T( " <" ) + who2 + _T( "> " ) + message2, col);
+		OutputLine(_T( "<" ) + who2 + _T( "> " ) + message2, col);
 	} else {
-		OutputLine(_T( " <" ) + who + _T( "> " ) + message, col);
+		OutputLine(_T( "<" ) + who + _T( "> " ) + message, col);
 	}
 
 
@@ -602,7 +629,7 @@ bool ChatPanel::ContainsWordToHighlight(const wxString& message) const
  */
 void ChatPanel::CheckForPromotion(const wxString& /*who*/, const wxString& action)
 {
-	if (m_reactOnPromoteEvents == false) { //If this feature disabled in options do nothing
+	if (!m_reactOnPromoteEvents) { //If this feature disabled in options do nothing
 		return;
 	}
 
@@ -613,9 +640,7 @@ void ChatPanel::CheckForPromotion(const wxString& /*who*/, const wxString& actio
 	//Detect event and notify user
 	//TODO: Rework for using array of regexps, not shit crap
 	if (action.Contains(promoteMessageTemplate) || action.Contains(promoteMessageTemplate2)) {
-		wxCommandEvent promoteEvent = wxCommandEvent(GlobalEventManager::GamePromotedEvent);
-		promoteEvent.SetString(action); //Send action string with that should be shown
-		GlobalEventManager::Instance()->Send(promoteEvent);
+		UiEvents::GetNotificationEventSender().SendEvent(UiEvents::NotficationData(UiEvents::GamePromoted, action));
 	}
 }
 
@@ -635,7 +660,7 @@ void ChatPanel::DidAction(const wxString& who, const wxString& action)
 
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_say);
-	OutputLine(_T( " * " ) + who + _T( " " ) + action, sett().GetChatColorAction());
+	OutputLine(_T( "* " ) + who + _T( " " ) + action, sett().GetChatColorAction());
 	if (m_type == CPT_User && (ui().GetActiveChatPanel() != this || !wxTheApp->IsActive())) {
 		const wxString msg = wxString::Format(_T("%s \n%s"), who.c_str(), action.Left(50).c_str());
 		UiEvents::GetNotificationEventSender().SendEvent(
@@ -650,7 +675,7 @@ void ChatPanel::Motd(const wxString& message)
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_say);
-	OutputLine(_T( " ** motd ** " ) + message, sett().GetChatColorServer());
+	OutputLine(_T( "** motd ** " ) + message, sett().GetChatColorServer());
 }
 
 void ChatPanel::StatusMessage(const wxString& message)
@@ -660,25 +685,25 @@ void ChatPanel::StatusMessage(const wxString& message)
 	} else {
 		if (CPT_Server == m_type)
 			SetIconHighlight(highlight_important);
-		OutputLine(_T( " ** Server ** " ) + message, sett().GetChatColorServer());
+		OutputLine(_T( "** Server ** " ) + message, sett().GetChatColorServer());
 	}
 }
 
 void ChatPanel::ClientMessage(const wxString& message)
 {
-	OutputLine(_T( " ** " ) + message, sett().GetChatColorClient());
+	OutputLine(_T( "** " ) + message, sett().GetChatColorClient());
 }
 
 void ChatPanel::UnknownCommand(const wxString& command, const wxString& params)
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_important);
-	OutputLine(_(" !! Command: \"") + command + _("\" params: \"") + params + _T( "\"." ), sett().GetChatColorError());
+	OutputLine(_("!! Command: \"") + command + _("\" params: \"") + params + _T( "\"." ), sett().GetChatColorError());
 }
 
 void ChatPanel::OutputError(const wxString& message)
 {
-	OutputLine(wxString::Format(_(" Error: %s"), message.c_str()), sett().GetChatColorError());
+	OutputLine(wxString::Format(_("Error: %s"), message.c_str()), sett().GetChatColorError());
 }
 
 
@@ -701,7 +726,7 @@ void ChatPanel::Joined(User& who)
 		if (m_type == CPT_Channel) {
 			SetIconHighlight(highlight_join_leave);
 		}
-		OutputLine(_T( " ** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
+		OutputLine(_T( "** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
 	}
 
 	if (m_show_nick_list && (m_nicklist != nullptr)) {
@@ -720,7 +745,7 @@ void ChatPanel::OnChannelJoin(User& who)
 		UpdateUserCountLabel();
 	}
 	if (m_display_joinitem) {
-		OutputLine(_T( " ** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
+		OutputLine(_T( "** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
 	}
 	// Also add the User to the TextCompletionDatabase
 	textcompletiondatabase.Insert_Mapping(TowxString(who.GetNick()), TowxString(who.GetNick()));
@@ -733,7 +758,7 @@ void ChatPanel::Parted(User& who, const wxString& message)
 	const wxString nick = TowxString(who.GetNick());
 	const bool wasactive = m_active_users.erase(nick) > 0;
 	if (m_display_joinitem || (wasactive && !who.IsBot())) {
-		OutputLine(_T( " ** " ) + wxString::Format(_("%s left %s (%s)."), nick.c_str(), GetChatTypeStr().c_str(), message.c_str()), sett().GetChatColorJoinPart());
+		OutputLine(_T( "** " ) + wxString::Format(_("%s left %s (%s)."), nick.c_str(), GetChatTypeStr().c_str(), message.c_str()), sett().GetChatColorJoinPart());
 	}
 	if (m_type == CPT_Channel) {
 		if (m_channel == 0)
@@ -772,20 +797,20 @@ void ChatPanel::SetTopic(const wxString& who, const wxString& message)
 	// change the image of the tab to show new events
 	if (m_topic_set)
 		SetIconHighlight(highlight_say);
-	OutputLine(_(" ** Channel topic:"), col);
+	OutputLine(_T("** ") + _("Channel topic"), col);
 	wxStringTokenizer tkz(message, _T("\n"));
 	while (tkz.HasMoreTokens()) {
 		wxString msg = tkz.GetNextToken();
 		OutputLine(_T(" ") + msg, col);
 	}
-	OutputLine(_(" ** Set by ") + who, col);
+	OutputLine(_T("** ") + wxString::Format(_("Set by %s"), who), col);
 	m_topic_set = true;
 }
 
 void ChatPanel::UserStatusUpdated(User& who)
 {
 	if ((m_type == CPT_User) && (m_user == &who) && (m_chan_opts_button != NULL)) {
-		m_chan_opts_button->SetBitmapLabel(icons().GetBitmap(icons().GetUserListStateIcon(who.GetStatus(), false, who.GetBattle() != 0)));
+		m_chan_opts_button->SetBitmapLabel(IconsCollection::Instance()->GetUserListStateBmp(who.GetStatus(), false, who.GetBattle() != 0));
 	}
 	if (!m_show_nick_list || (m_nicklist == nullptr))
 		return;
@@ -803,7 +828,6 @@ const Channel* ChatPanel::GetChannel() const
 
 void ChatPanel::SetChannel(Channel* chan)
 {
-	ASSERT_LOGIC(this, "this==null");
 	ASSERT_LOGIC(m_type == CPT_Channel, "Not of type channel");
 
 	if ((chan == 0) && (m_channel != 0)) {
@@ -863,13 +887,13 @@ void ChatPanel::SetUser(User* usr)
 		if (m_user != NULL) {
 			m_user->panel = nullptr;
 			if (m_chan_opts_button != NULL) {
-				m_chan_opts_button->SetBitmapLabel(icons().GetBitmap(icons().ICON_EMPTY));
+				m_chan_opts_button->SetBitmapLabel(IconsCollection::Instance()->BMP_EMPTY);
 			}
 		}
 	} else {
 		usr->panel = this;
 		if (m_chan_opts_button != NULL) {
-			const wxBitmap icon = icons().GetBitmap(icons().GetUserListStateIcon(usr->GetStatus(), false, usr->GetBattle() != 0));
+			const wxBitmap icon = IconsCollection::Instance()->GetUserListStateIcon(usr->GetStatus(), false, usr->GetBattle() != 0);
 			m_chan_opts_button->SetBitmapLabel(icon);
 		}
 	}
@@ -882,7 +906,7 @@ ChatPanelType ChatPanel::GetPanelType() const
 }
 
 
-bool ChatPanel::Say(const wxString& message)
+bool ChatPanel::Say(const wxString& message) //FIXME: remove all parsing / tokenizing / ... to dedicated file
 {
 	static const unsigned int flood_threshold = 5;
 	slLogDebugFunc("");
@@ -898,7 +922,7 @@ bool ChatPanel::Say(const wxString& message)
 					Say(url);
 					return true;
 				} else {
-					customMessageBoxNoModal(SL_MAIN_ICON, _("Failed to post to pastebin.com."));
+					customMessageBoxModal(SL_MAIN_ICON, wxString::Format(_("Failed to post to %s"), _T("paste.springfiles.com")));
 					return false;
 				}
 			}
@@ -908,16 +932,21 @@ bool ChatPanel::Say(const wxString& message)
 	}
 	while (lines.HasMoreTokens()) {
 		wxString line = lines.GetNextToken();
-		wxLogMessage(_T( "line: %s" ), line.c_str());
+		wxLogDebug(_T( "line: %s" ), line.c_str());
 
-		if (line.Find('/') == 0) {
-			if (ui().ExecuteSayCommand(line))
-				return true;
+		if (line == "/help") {
+			ui().ConsoleHelp();
+			return true;
+		}
+
+		if (line == "/channels") {
+			ui().mw().ShowChannelChooser();
+			return true;
 		}
 
 		if (line == _T( "/ver" )) {
 			//!this instance is not replaced with GetAppname for sake of help/debug online
-			OutputLine(_(" You have SpringLobby v") + TowxString(getSpringlobbyVersion()), sett().GetChatColorNormal());
+			OutputLine(wxString::Format(_("You have %s."), GetSpringlobbyAgent()), sett().GetChatColorNormal());
 			return true;
 		}
 
@@ -961,7 +990,7 @@ bool ChatPanel::Say(const wxString& message)
 		} else if (m_type == CPT_User) {
 
 			if (m_user == 0) {
-				OutputError(_(" User is offline."));
+				OutputError(_("User is offline."));
 				return true;
 			}
 			if (line.StartsWith(_T( "/" ))) {
@@ -999,7 +1028,7 @@ bool ChatPanel::Say(const wxString& message)
 			}
 
 			m_server->SendCmd(STD_STRING(line), "");
-			OutputLine(_(" Sent: \"") + line + _("\""), sett().GetChatColorNormal());
+			OutputLine(_("Sent: \"") + line + _T("\""), sett().GetChatColorNormal());
 		}
 	}
 	return true;
@@ -1033,14 +1062,14 @@ void ChatPanel::OnUserDisconnected()
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_join_leave);
-	OutputLine(_(" ** User is now offline."), sett().GetChatColorJoinPart());
+	OutputLine(_T("** ") + _("User is now offline."), sett().GetChatColorJoinPart());
 }
 
 void ChatPanel::OnUserConnected()
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_join_leave);
-	OutputLine(_(" ** User just got online."), sett().GetChatColorJoinPart());
+	OutputLine(_T("** ") + _("User just got online."), sett().GetChatColorJoinPart());
 }
 
 
@@ -1166,7 +1195,7 @@ void ChatPanel::SetBattle(IBattle* battle)
 	}
 
 	if (m_battle != NULL) {
-		OutputLine(_(" ** Left Battle."), sett().GetChatColorNotification());
+		OutputLine(_T("** ") + _("Left Battle."), sett().GetChatColorNotification());
 	}
 
 	if (battle == NULL) {
@@ -1174,7 +1203,7 @@ void ChatPanel::SetBattle(IBattle* battle)
 		return;
 	}
 
-	OutputLine(_(" ** Joined Battle."), sett().GetChatColorNotification());
+	OutputLine(_T("** ") + _("Joined Battle."), sett().GetChatColorNotification());
 
 	for (unsigned int i = 0; i < battle->GetNumUsers(); ++i) {
 		const wxString nick = TowxString(battle->GetUser(i).GetNick());
@@ -1194,6 +1223,7 @@ void ChatPanel::OnLogin(wxCommandEvent& /*data*/)
 			}
 			break;
 		case CPT_Server:
+			assert(m_server != nullptr);
 			m_nicklist->SetUsers(m_server->GetUserList().GetUsers());
 			UpdateUserCountLabel();
 		case CPT_Battle:
