@@ -1,20 +1,19 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
 #include "chatpanelmenu.h"
 
 #include <wx/log.h>
 
-#include "chatpanel.h"
-#include "channel.h"
-#include "iserver.h"
-#include "serverselector.h"
-#include "user.h"
-#include "mainwindow.h"
-#include "settings.h"
 #include "battlelist/battlelisttab.h"
-#include "utils/conversion.h"
+#include "channel.h"
+#include "chatpanel.h"
 #include "gui/customdialogs.h"
+#include "iserver.h"
+#include "mainwindow.h"
+#include "serverselector.h"
+#include "settings.h"
 #include "uiutils.h"
+#include "user.h"
+#include "utils/conversion.h"
 
 ChatPanelMenu::ChatPanelMenu(ChatPanel* parent, bool addChanServ, const wxString& /*title */, long /*style*/)
     : wxEvtHandler()
@@ -52,11 +51,6 @@ wxMenu* ChatPanelMenu::GetMenu()
 	if (m_chatpanel->m_type == CPT_Channel) {
 		wxLogMessage(_T( "channel" ));
 
-		m_subscribe = new wxMenuItem(m_menu_all, CHAT_MENU_CH_SUBSCRIBE, _("Subscribe to this channel"), wxEmptyString, wxITEM_CHECK);
-		m_menu_all->Append(m_subscribe);
-		m_subscribe->Check(m_chatpanel->m_channel->IsSubscribed());
-
-
 		wxMenuItem* leaveitem = new wxMenuItem(m_menu_all, CHAT_MENU_CH_LEAVE, _("Leave"), wxEmptyString, wxITEM_NORMAL);
 		m_menu_all->Append(leaveitem);
 	}
@@ -718,18 +712,7 @@ void ChatPanelMenu::OnUserMenuCreateGroup(wxCommandEvent& /*unused*/)
 			useractions().AddUserToGroup(name, TowxString(user->GetNick()));
 			ui().mw().ShowConfigure(MainWindow::OPT_PAGE_GROUPS);
 		} else
-			customMessageBoxNoModal(SL_MAIN_ICON, _("couldn't add user"), _("Error"));
-	}
-}
-
-void ChatPanelMenu::OnChannelSubscribe(wxCommandEvent& /*unused*/)
-{
-	const std::string chan = m_chatpanel->m_channel->GetName();
-	IServer& serv = m_chatpanel->m_channel->GetServer();
-	if (!m_chatpanel->m_channel->IsSubscribed()) {
-		serv.SendCmd("SUBSCRIBE", "chanName=" + chan);
-	} else {
-		serv.SendCmd("UNSUBSCRIBE", "chanName=" + chan);
+			customMessageBoxModal(SL_MAIN_ICON, _("couldn't add user"), _("Error"));
 	}
 }
 
@@ -839,9 +822,6 @@ void ChatPanelMenu::OnMenuItem(wxCommandEvent& event)
 		OnUserMenuDeleteFromGroup(event);
 	else if (event.GetId() == wxID_COPY)
 		m_chatpanel->m_chatlog_text->OnCopy(event);
-	else if (event.GetId() == CHAT_MENU_CH_SUBSCRIBE)
-		OnChannelSubscribe(event);
-
 	else
 		OnUserMenuAddToGroup(event);
 }
