@@ -4,12 +4,20 @@
 #define SPRINGLOBBY_HEADERGUARD_BATTLEROOMTAB_H
 
 #include <lslunitsync/optionswrapper.h>
-#include "utils/uievents.h"
 #include <map>
+#include <wx/panel.h>
+
+#include "utils/uievents.h"
+
+namespace GUI
+{
+namespace Controls
+{
+class BitmapComboBox;
+}
+}
 
-class Ui;
 class IBattle;
-struct BattleBot;
 class BattleroomDataViewCtrl;
 class User;
 class ChatPanel;
@@ -24,10 +32,6 @@ class wxCheckBox;
 class wxListCtrl;
 class MapCtrl;
 class ColorButton;
-class wxBitmapComboBox;
-struct UnitSyncMap;
-class wxToggleButton;
-class wxChoice;
 class wxListEvent;
 class VotePanel;
 
@@ -46,7 +50,6 @@ public:
 	IBattle* GetBattle();
 	ChatPanel& GetChatPanel();
 
-	void UpdateBattleInfo();
 	void UpdateBattleInfo(const wxString& Tag);
 
 
@@ -67,13 +70,14 @@ public:
 	void SetBattle(IBattle* battle);
 
 	void PrintAllySetup();
-	void UpdateMyInfo();
 
 private:
+	void UpdateBattleInfo();
 	void RegenerateOptionsList();
 
 	void UpdateStatsLabels();
 	void UpdateMapInfoSummary();
+	void OnPromote(wxCommandEvent& event);
 	void OnStart(wxCommandEvent& event);
 	void OnHostNew(wxCommandEvent& event);
 	void OnLeave(wxCommandEvent& event);
@@ -81,6 +85,12 @@ private:
 	void OnFixTeams(wxCommandEvent& event);
 	void OnFixColours(wxCommandEvent& event);
 	void OnAddBot(wxCommandEvent& event);
+	void OnAutolaunch();
+	void OnAutolaunch(wxCommandEvent& /*unused*/)
+	{
+		OnAutolaunch();
+	}
+	void OnImReady();
 	void OnImReady(wxCommandEvent& event);
 	void OnLock(wxCommandEvent& event);
 	void OnAutoHost(wxCommandEvent& event);
@@ -120,6 +130,7 @@ private:
 	void OnAutohostNotify(wxCommandEvent& event);
 
 	void OnUnitsyncReloaded(wxCommandEvent& /*data*/);
+	void OnDownloadFailed(wxCommandEvent& /*data*/);
 
 	long AddMMOptionsToList(long pos, LSL::Enum::GameOption optFlag);
 
@@ -147,7 +158,7 @@ private:
 	wxComboBox* m_team_sel;
 	wxComboBox* m_ally_sel;
 	ColorButton* m_color_sel;
-	wxBitmapComboBox* m_side_sel;
+	GUI::Controls::BitmapComboBox* m_side_sel;
 	wxComboBox* m_options_preset_sel;
 
 	wxStaticText* m_team_lbl;
@@ -175,6 +186,7 @@ private:
 	wxStaticLine* m_command_line;
 
 	wxButton* m_leave_btn;
+	wxButton* m_promote_btn;
 	wxButton* m_start_btn;
 	wxButton* m_addbot_btn;
 	wxButton* m_manage_players_btn;
@@ -192,6 +204,7 @@ private:
 	wxMenuItem* m_autocontrol_mnu;
 	wxMenuItem* m_autopaste_mnu;
 
+	wxCheckBox* m_autolaunch_chk;
 	wxCheckBox* m_ready_chk;
 	wxCheckBox* m_spec_chk;
 	wxCheckBox* m_auto_unspec_chk;
@@ -204,6 +217,7 @@ private:
 
 	enum {
 		BROOM_LEAVE = wxID_HIGHEST,
+		BROOM_AUTOLAUNCH,
 		BROOM_IMREADY,
 		BROOM_LOCK,
 		BROOM_LOCK_BALANCE,
@@ -214,6 +228,7 @@ private:
 		BROOM_ALLYSEL,
 		BROOM_COLOURSEL,
 		BROOM_SIDESEL,
+		BROOM_PROMOTE,
 		BROOM_START,
 		BROOM_ADDBOT,
 		BROOM_BALANCE,
