@@ -3,45 +3,37 @@
 //
 // Class: HostBattleDialog
 //
-
 #include "hostbattledialog.h"
 
-#include <wx/intl.h>
-#include <wx/string.h>
-#include <wx/sizer.h>
-#include <wx/choice.h>
-#include <wx/slider.h>
-#include <wx/statline.h>
-#include <wx/button.h>
-#include <wx/stattext.h>
-#include <wx/statline.h>
-#include <wx/statbox.h>
-#include <wx/radiobox.h>
-#include <wx/radiobut.h>
-#include <wx/textctrl.h>
-#include <wx/statbmp.h>
-#include <wx/checkbox.h>
-#include <wx/log.h>
-#include <wx/menu.h>
-#include <wx/image.h>
-#include <wx/bmpbuttn.h>
-#include <wx/scrolwin.h>
-
-
-#include "settings.h"
-#include "user.h"
-#include "gui/uiutils.h"
-#include "gui/controls.h"
-#include "gui/customdialogs.h"
-#include "utils/slpaths.h"
-#include "utils/conversion.h"
-#include "utils/lslconversion.h"
-#include "gui/ui.h"
-#include "iserver.h"
-#include "serverselector.h"
+#include <lslunitsync/optionswrapper.h>
 #include <lslunitsync/springbundle.h>
 #include <lslunitsync/unitsync.h>
+#include <wx/bmpbuttn.h>
+#include <wx/button.h>
+#include <wx/checkbox.h>
+#include <wx/choice.h>
+#include <wx/image.h>
+#include <wx/intl.h>
+#include <wx/log.h>
+#include <wx/menu.h>
+#include <wx/radiobox.h>
+#include <wx/radiobut.h>
+#include <wx/scrolwin.h>
+#include <wx/sizer.h>
+#include <wx/slider.h>
+#include <wx/statbmp.h>
+#include <wx/statbox.h>
+#include <wx/statline.h>
+#include <wx/stattext.h>
+#include <wx/string.h>
+#include <wx/textctrl.h>
 
+#include "gui/controls.h"
+#include "gui/customdialogs.h"
+#include "gui/ui.h"
+#include "gui/uiutils.h"
+#include "ibattle.h"
+#include "images/arrow_refresh.png.h"
 #include "images/rank0.xpm"
 #include "images/rank1.xpm"
 #include "images/rank2.xpm"
@@ -50,7 +42,13 @@
 #include "images/rank5.xpm"
 #include "images/rank6.xpm"
 #include "images/rank7.xpm"
-#include "images/arrow_refresh.png.h"
+#include "iserver.h"
+#include "serverselector.h"
+#include "settings.h"
+#include "user.h"
+#include "utils/conversion.h"
+#include "utils/lslconversion.h"
+#include "utils/slpaths.h"
 
 BEGIN_EVENT_TABLE(HostBattleDialog, wxDialog)
 EVT_BUTTON(HOST_CANCEL, HostBattleDialog::OnCancel)
@@ -96,22 +94,20 @@ HostBattleDialog::HostBattleDialog(wxWindow* parent)
 	m_mod_lbl->Wrap(-1);
 	topsizer->Add(m_mod_lbl, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
 
-	wxArrayString m_engine_picChoices;
 	wxBoxSizer* mod_choice_button_sizer2 = new wxBoxSizer(wxHORIZONTAL);
-	m_engine_pic = new wxChoice(m_panel, CHOOSE_ENGINE, wxDefaultPosition, wxDefaultSize, m_engine_picChoices, 0);
-	m_engine_pic->SetToolTip(_("Select the engine version to play."));
-	mod_choice_button_sizer2->Add(m_engine_pic, 0, wxALL, 5);
+	m_engine_choice = new wxChoice(m_panel, CHOOSE_ENGINE);
+	m_engine_choice->SetToolTip(_("Select the engine version to play."));
+	mod_choice_button_sizer2->Add(m_engine_choice, 0, wxALL, 5);
 	topsizer->Add(mod_choice_button_sizer2, 0, wxEXPAND | wxALL, 1);
 
 	m_mod_lbl = new wxStaticText(m_panel, wxID_ANY, _("Game"), wxDefaultPosition, wxDefaultSize, 0);
 	m_mod_lbl->Wrap(-1);
 	topsizer->Add(m_mod_lbl, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
 
-	wxArrayString m_mod_picChoices;
 	wxBoxSizer* mod_choice_button_sizer = new wxBoxSizer(wxHORIZONTAL);
-	m_mod_pic = new wxChoice(m_panel, wxID_ANY, wxDefaultPosition, wxDefaultSize, m_mod_picChoices, 0);
-	m_mod_pic->SetToolTip(_("Select the game to play."));
-	mod_choice_button_sizer->Add(m_mod_pic, 0, wxALL, 5);
+	m_game_choice = new wxChoice(m_panel, wxID_ANY);
+	m_game_choice->SetToolTip(_("Select the game to play."));
+	mod_choice_button_sizer->Add(m_game_choice, 0, wxALL, 5);
 
 	wxBitmap mp = charArr2wxBitmap(arrow_refresh_png, sizeof(arrow_refresh_png));
 	m_refresh_btn = new wxBitmapButton(m_panel, BTN_REFRESH, mp);
@@ -291,39 +287,39 @@ HostBattleDialog::HostBattleDialog(wxWindow* parent)
 
 void HostBattleDialog::ReloadModList()
 {
-	m_mod_pic->Clear();
+	m_game_choice->Clear();
 
 	wxArrayString modlist = lslTowxArrayString(LSL::usync().GetGameList());
 	wxString last = sett().GetLastHostMod();
 
 	size_t nummods = modlist.Count();
 	for (size_t i = 0; i < nummods; i++) {
-		m_mod_pic->Insert(modlist[i], i);
+		m_game_choice->Insert(modlist[i], i);
 		if (last == modlist[i])
-			m_mod_pic->SetSelection(i);
+			m_game_choice->SetSelection(i);
 	}
 
-	if (m_mod_pic->GetSelection() == wxNOT_FOUND) {
-		m_mod_pic->SetSelection(0);
+	if (m_game_choice->GetSelection() == wxNOT_FOUND) {
+		m_game_choice->SetSelection(0);
 	}
 }
 
 void HostBattleDialog::ReloadEngineList()
 {
-	m_engine_pic->Clear();
+	m_engine_choice->Clear();
 	std::map<std::string, LSL::SpringBundle> versions = SlPaths::GetSpringVersionList();
 	const std::string last = SlPaths::GetCurrentUsedSpringIndex();
 	int i = 0;
 	for (auto pair : versions) {
-		m_engine_pic->Insert(TowxString(pair.first), i);
+		m_engine_choice->Insert(TowxString(pair.first), i);
 		if (last == pair.first) {
-			m_engine_pic->SetSelection(i);
+			m_engine_choice->SetSelection(i);
 		}
 		i++;
 	}
 
-	if (m_engine_pic->GetSelection() == wxNOT_FOUND) {
-		m_engine_pic->SetSelection(0);
+	if (m_engine_choice->GetSelection() == wxNOT_FOUND) {
+		m_engine_choice->SetSelection(0);
 	}
 	//unitsync change needs a refresh of games as well
 	ReloadModList();
@@ -332,13 +328,13 @@ void HostBattleDialog::ReloadEngineList()
 
 void HostBattleDialog::OnOk(wxCommandEvent& /*unused*/)
 {
-	if (m_mod_pic->GetSelection() == wxNOT_FOUND) {
+	if (m_game_choice->GetSelection() == wxNOT_FOUND) {
 		wxLogWarning(_T( "no game selected" ));
 		customMessageBox(SL_MAIN_ICON, _("You have to select a game first."), _("No game selected."), wxOK);
 		return;
 	}
 
-	if (m_engine_pic->GetSelection() == wxNOT_FOUND) {
+	if (m_engine_choice->GetSelection() == wxNOT_FOUND) {
 		wxLogWarning(_T( "no engine selected" ));
 		customMessageBox(SL_MAIN_ICON, _("You have to select a engine version first."), _("No engine selected."), wxOK);
 		return;
@@ -347,7 +343,7 @@ void HostBattleDialog::OnOk(wxCommandEvent& /*unused*/)
 	if (m_desc_text->GetValue().IsEmpty())
 		m_desc_text->SetValue(_T( "(none)" ));
 	sett().SetLastHostDescription(m_desc_text->GetValue());
-	sett().SetLastHostMod(m_mod_pic->GetString(m_mod_pic->GetSelection()));
+	sett().SetLastHostMod(m_game_choice->GetString(m_game_choice->GetSelection()));
 	wxString password = m_pwd_text->GetValue();
 	password.Replace(_T(" "), wxEmptyString);
 	sett().SetLastHostPassword(password);
@@ -437,7 +433,7 @@ void HostBattleDialog::OnUseRelay(wxCommandEvent&)
 
 void HostBattleDialog::OnEngineSelect(wxCommandEvent& /*event*/)
 {
-	SlPaths::SetUsedSpringIndex(STD_STRING(m_engine_pic->GetString(m_engine_pic->GetSelection())));
+	SlPaths::SetUsedSpringIndex(STD_STRING(m_engine_choice->GetString(m_engine_choice->GetSelection())));
 	LSL::usync().ReloadUnitSyncLib();
 	ReloadEngineList();
 }
@@ -473,19 +469,23 @@ void HostBattleDialog::RunHostBattleDialog(wxWindow* parent)
 		bo.gamename = mod.name;
 	} catch (...) {
 		wxLogWarning(_T( "can't host: game not found" ));
-		customMessageBoxNoModal(SL_MAIN_ICON, _("Battle not started beacuse the game you selected could not be found. "), _("Error starting battle."), wxOK);
+		customMessageBoxModal(SL_MAIN_ICON, _("Battle not started beacuse the game you selected could not be found. "), _("Error starting battle."), wxOK);
 		return;
 	}
 
 	LSL::UnitsyncMap map;
 	const auto mname = STD_STRING(sett().GetLastHostMap());
-	if (LSL::usync().MapExists(mname)) {
+	if (!mname.empty() && LSL::usync().MapExists(mname)) {
 		map = LSL::usync().GetMap(mname);
 	} else {
 		std::vector<std::string> maps = LSL::usync().GetMapList();
 		if (maps.size() <= 0) {
-			wxLogWarning(_T( "no maps found" ));
-			customMessageBoxNoModal(SL_MAIN_ICON, _("Couldn't find any maps in your spring installation. This could happen when you set the Spring settings incorrectly."), _("No maps found"), wxOK);
+			wxLogWarning(_T("no maps found"));
+			customMessageBoxModal(SL_MAIN_ICON, _(
+			  "Could not find any maps in engine's search path. Have you downloaded any?"
+			  " You can join any multiplayer room for automatic download or use search in the Downloads tab. "
+			  " Note that this can also happen when you set the paths in preferences incorrectly."),
+			  _("No maps found"), wxOK);
 			return;
 		}
 		map = LSL::usync().GetMap(maps[0]);
@@ -495,5 +495,4 @@ void HostBattleDialog::RunHostBattleDialog(wxWindow* parent)
 	bo.mapname = map.name;
 
 	serverSelector().GetServer().HostBattle(bo, STD_STRING(sett().GetLastHostPassword()));
-
 }
