@@ -1,4 +1,5 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
+#include "maindownloadtab.h"
 
 #ifdef _MSC_VER
 #ifndef NOMINMAX
@@ -7,30 +8,29 @@
 #include <winsock2.h>
 #endif // _MSC_VER
 
-#include "maindownloadtab.h"
-
+#include <wx/button.h>
 #include <wx/intl.h>
+#include <wx/msgdlg.h>
 #include <wx/sizer.h>
 #include <wx/stattext.h>
-#include <wx/button.h>
-#include <wx/msgdlg.h>
 
-#include "downloader/downloaddataviewctrl.h"
-#include "utils/conversion.h"
-#include "gui/controls.h"
-#include "gui/colorbutton.h"
 #include "aui/auimanager.h"
+#include "downloader/prdownloader.h"
+#include "gui/colorbutton.h"
 #include "gui/contentdownloaddialog.h"
+#include "gui/controls.h"
+#include "gui/customdialogs.h"
+#include "gui/downloaddataviewctrl.h"
+#include "utils/conversion.h"
 #include "utils/globalevents.h"
 #include "utils/slpaths.h"
 
 BEGIN_EVENT_TABLE(MainDownloadTab, wxPanel)
 //(*EventTable(MainTorrentTab)
 //*)
-	EVT_BUTTON(ID_BUTTON_CANCEL, MainDownloadTab::OnCancelButton)
-	EVT_BUTTON(ID_BUTTON_CLEAR, MainDownloadTab::OnClearFinished)
-	EVT_BUTTON(ID_DOWNLOAD_DIALOG, MainDownloadTab::OnDownloadDialog)
-	EVT_TIMER(ID_TIMER, MainDownloadTab::OnUpdate)
+EVT_BUTTON(ID_BUTTON_CANCEL, MainDownloadTab::OnCancelButton)
+EVT_BUTTON(ID_BUTTON_CLEAR, MainDownloadTab::OnClearFinished)
+EVT_BUTTON(ID_DOWNLOAD_DIALOG, MainDownloadTab::OnDownloadDialog)
 END_EVENT_TABLE()
 
 MainDownloadTab::MainDownloadTab(wxWindow* parent)
@@ -55,8 +55,8 @@ MainDownloadTab::MainDownloadTab(wxWindow* parent)
 	m_buttonbox->Add(m_but_download, 0, wxALL | wxALIGN_BOTTOM, 5);
 
 	wxStaticBoxSizer* currDownloadDirSizer = new wxStaticBoxSizer(wxHORIZONTAL, this, _("Current download directory"));
-	wxString downloadDir = TowxString(SlPaths::GetDownloadDir());
-	wxStaticText* m_currDownloadDirText = new wxStaticText(this, wxID_ANY, downloadDir);
+
+	m_currDownloadDirText = new wxStaticText(this, wxID_ANY, wxEmptyString);
 	currDownloadDirSizer->Add(m_currDownloadDirText, 1, wxALL | wxEXPAND, 5);
 
 	wxBoxSizer* manageAndInfoSizer = new wxBoxSizer(wxHORIZONTAL);
@@ -69,29 +69,20 @@ MainDownloadTab::MainDownloadTab(wxWindow* parent)
 
 	Layout();
 
-	timer = new wxTimer(this, ID_TIMER);
-	timer->Start(1000 * 2);
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnDownloadFailed, MainDownloadTab::OnDownloadFailed);
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnUnitsyncReloaded, MainDownloadTab::OnUnitsyncReloaded);
 
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnDownloadStarted, wxObjectEventFunction(&MainDownloadTab::OnNewDownloadStarted));
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnDownloadComplete, wxObjectEventFunction(&MainDownloadTab::OnDownloadComplete));
+	UpdateDownloadDir();
 }
 
 MainDownloadTab::~MainDownloadTab()
 {
-	timer->Stop();
-	wxDELETE(timer);
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
 }
 
 void MainDownloadTab::OnClearFinished(wxCommandEvent& /*event*/)
 {
-	m_DownloadDataView->Clear();
-
-	//TODO: clear finished from ContentManager
-}
-
-void MainDownloadTab::OnUpdate(wxTimerEvent& /*event*/)
-{
-	m_DownloadDataView->UpdateDownloadsList();
+	m_DownloadDataView->ClearFinished();
 }
 
 void MainDownloadTab::OnCancelButton(wxCommandEvent& /*unused*/)
@@ -109,14 +100,19 @@ void MainDownloadTab::OnDownloadDialog(wxCommandEvent& /*unused*/)
 	}
 }
 
-void MainDownloadTab::OnNewDownloadStarted(wxCommandEvent& event) {
-	DownloadInfo* dInfo = static_cast<DownloadInfo*>(event.GetClientData());
-
-	wxASSERT(dInfo != nullptr);
-
-	m_DownloadDataView->AddDownloadInfo(dInfo);
+void MainDownloadTab::OnDownloadFailed(wxCommandEvent& /*event*/)
+{
+	customMessageBox(SL_MAIN_ICON, _("Failed to download selected item."), _("Failed to download"), wxOK);
 }
 
-void MainDownloadTab::OnDownloadComplete(wxCommandEvent& /*event*/) {
-	m_DownloadDataView->UpdateDownloadsList();
+void MainDownloadTab::OnUnitsyncReloaded(wxCommandEvent &/*event*/)
+{
+	UpdateDownloadDir();
 }
+
+void MainDownloadTab::UpdateDownloadDir()
+{
+	wxString downloadDir = TowxString(SlPaths::GetDownloadDir());
+	m_currDownloadDirText->SetLabelText(downloadDir);
+}
+
