@@ -3,79 +3,77 @@
 //
 // Class: MainWindow
 //
-
-#include <wx/frame.h>
-#include <wx/textdlg.h>
-#include <wx/imaglist.h>
-#include <wx/image.h>
-#include <wx/icon.h>
-#include <wx/sizer.h>
-#include <wx/menu.h>
-#include <wx/log.h>
-#include <wx/dcmemory.h>
-#include <wx/choicdlg.h>
-#include <wx/wupdlock.h>
-#include <wx/aui/auibook.h>
-#include <wx/tooltip.h>
-
-#include <stdexcept>
-#include <iostream>
-
-#include "aboutbox.h"
-#include "aui/auimanager.h"
-#include "gui/slbook.h"
-#include "gui/statusbar.h"
-#include "springlobbyapp.h"
 #include "mainwindow.h"
-#include "settings.h"
-#include "iserver.h"
-#include "serverselector.h"
-#include "utils/platform.h"
-#include "utils/version.h"
-#include "utils/globalevents.h"
-#include "battlelist/battlelisttab.h"
-#include "mainchattab.h"
-#include "hosting/mainjoinbattletab.h"
-#include "hosting/mainsingleplayertab.h"
-#include "battlelist/battlelisttab.h"
-#include "options/mainoptionstab.h"
-#include "uiutils.h"
-#include "chatpanel.h"
-#include "playback/playbacktab.h"
-#include "infodialog.h"
-#include "maindownloadtab.h"
-#include "user.h"
-#include "mapselectdialog.h"
-#include "downloader/prdownloader.h"
-#include "utils/slconfig.h"
-#include "utils/conversion.h"
-#include "springsettings/frame.h"
-#include "gui/customdialogs.h"
-#include "utils/slpaths.h"
-#include "channel/autojoinchanneldialog.h"
-#include "channel/channelchooserdialog.h"
-#include "gui/controls.h"
-#include "gui/ui.h"
-#include "log.h"
-#include "servermanager.h"
+
 #include <lslunitsync/unitsync.h>
-
-#include "iconimagelist.h"
-#include "images/chat_icon.png.h"
-#include "images/join_icon.png.h"
-#include "images/single_player_icon.png.h"
-#include "images/options_icon.png.h"
-#include "images/downloads_icon.png.h"
-#include "images/replay_icon.png.h"
-#include "images/broom_tab_icon.png.h"
-#include "images/floppy_icon.png.h"
-
-
+#include <wx/aui/auibook.h>
+#include <wx/choicdlg.h>
+#include <wx/dcmemory.h>
+#include <wx/frame.h>
+#include <wx/icon.h>
+#include <wx/image.h>
+#include <wx/imaglist.h>
+#include <wx/log.h>
+#include <wx/menu.h>
+#include <wx/sizer.h>
+#include <wx/textdlg.h>
+#include <wx/tooltip.h>
+#include <wx/wupdlock.h>
+#include <iostream>
+#include <stdexcept>
 #if defined(__WXMSW__)
 #include <wx/msw/winundef.h>
 #include <iostream>
 #endif
 
+#include "aboutbox.h"
+#include "aui/auimanager.h"
+#include "battlelist/battlelisttab.h"
+#include "channel/autojoinchanneldialog.h"
+#include "channel/channelchooserdialog.h"
+#include "chatpanel.h"
+#include "downloader/prdownloader.h"
+#include "gui/controls.h"
+#include "gui/customdialogs.h"
+#include "gui/iconscollection.h"
+#include "gui/slbook.h"
+#include "gui/statusbar.h"
+#include "gui/ui.h"
+#include "hosting/mainjoinbattletab.h"
+#include "hosting/mainsingleplayertab.h"
+#include "images/broom_tab_icon.png.h"
+#include "images/chat_icon.png.h"
+#include "images/downloads_icon.png.h"
+#include "images/floppy_icon.png.h"
+#include "images/join_icon.png.h"
+#include "images/options_icon.png.h"
+#include "images/replay_icon.png.h"
+#include "images/single_player_icon.png.h"
+#include "infodialog.h"
+#include "iserver.h"
+#include "log.h"
+#include "mainchattab.h"
+#include "maindownloadtab.h"
+#include "mapselectdialog.h"
+#include "options/mainoptionstab.h"
+#include "playback/playbacktab.h"
+#include "servermanager.h"
+#include "serverselector.h"
+#include "settings.h"
+#include "springlobbyapp.h"
+#include "springsettings/frame.h"
+#include "uiutils.h"
+#include "user.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
+#include "utils/platform.h"
+#include "utils/slconfig.h"
+#include "utils/slpaths.h"
+#include "utils/version.h"
+
+const wxEventType MainwindowMessageEvent = wxNewEventType();
+
+
 SLCONFIG("/GUI/UseTabIcons", true, "Show icons in main tabs");
 SLCONFIG("/GUI/DoubleBuffered", false, "Double buffer gui controls (reduces flickering)");
 
@@ -108,11 +106,12 @@ EVT_SET_FOCUS(MainWindow::OnSetFocus)
 EVT_KILL_FOCUS(MainWindow::OnKillFocus)
 EVT_AUINOTEBOOK_PAGE_CHANGED(MAIN_TABS, MainWindow::OnTabsChanged)
 EVT_CLOSE(MainWindow::OnClose)
+EVT_END_SESSION(MainWindow::OnClose)
 EVT_COMMAND(mySHOW_ERROR_MESSAGE, wxEVT_SHOW, MainWindow::OnShowErrorMessage)
 END_EVENT_TABLE()
 
 MainWindow::MainWindow()
-    : wxFrame(NULL, -1, TowxString(getSpringlobbyName()))
+    : wxFrame(NULL, -1, TowxString(GetSpringlobbyName()))
     , WindowAttributesPickle(_T("MAINWINDOW"), this, wxSize(720, 576))
     , m_opts_dialog(NULL)
     , m_autojoin_dialog(NULL)
@@ -131,7 +130,9 @@ MainWindow::MainWindow()
 	m_tab_names.Add(_("Replays"));
 	m_tab_names.Add(_("Downloads"));
 
-	SetIcon(icons().GetIcon(icons().ICON_SPRINGLOBBY));
+	wxIcon mainIcon = wxIcon();
+	mainIcon.CopyFromBitmap(IconsCollection::Instance()->BMP_SPRINGLOBBY);
+	SetIcon(mainIcon);
 
 	GetAui().manager = new wxAuiManager(this);
 
@@ -155,7 +156,7 @@ MainWindow::MainWindow()
 	m_menuEdit->Append(MENU_RESET_LAYOUT, _("&Reset layout"));
 	m_menuEdit->Append(m_settings_menu);
 
-	m_menuEdit->Enable(MENU_SETTINGSPP, LSL::usync().IsLoaded()); //unitsync isn't loaded yet, disable menu entry
+	m_menuEdit->Enable(MENU_SETTINGSPP, false); //unitsync isn't loaded yet, disable menu entry
 
 	m_menuTools = new wxMenu;
 	m_menuTools->Append(MENU_JOIN, _("&Join channel..."));
@@ -202,12 +203,12 @@ MainWindow::MainWindow()
 
 	//use Insert so no Changepage events are triggered
 	m_func_tabs->InsertPage(PAGE_CHAT, m_chat_tab, m_tab_names[PAGE_CHAT], true);
-	m_func_tabs->InsertPage(PAGE_LIST, m_list_tab, m_tab_names[PAGE_LIST], false);
-	m_func_tabs->InsertPage(PAGE_JOIN, m_join_tab, m_tab_names[PAGE_JOIN], false);
-	m_func_tabs->InsertPage(PAGE_SINGLE, m_sp_tab, m_tab_names[PAGE_SINGLE], false);
+	m_func_tabs->InsertPage(PAGE_BATTLELIST, m_list_tab, m_tab_names[PAGE_BATTLELIST], false);
+	m_func_tabs->InsertPage(PAGE_BATTLEROOM, m_join_tab, m_tab_names[PAGE_BATTLEROOM], false);
+	m_func_tabs->InsertPage(PAGE_SINGLEPLAYER, m_sp_tab, m_tab_names[PAGE_SINGLEPLAYER], false);
 	//    m_func_tabs->InsertPage( PAGE_SAVEGAME, m_savegame_tab, m_tab_names[PAGE_SAVEGAME], false );
-	m_func_tabs->InsertPage(PAGE_REPLAY, m_replay_tab, m_tab_names[PAGE_REPLAY], false);
-	m_func_tabs->InsertPage(PAGE_TORRENT, m_torrent_tab, m_tab_names[PAGE_TORRENT], false);
+	m_func_tabs->InsertPage(PAGE_REPLAYS, m_replay_tab, m_tab_names[PAGE_REPLAYS], false);
+	m_func_tabs->InsertPage(PAGE_DOWNLOADS, m_torrent_tab, m_tab_names[PAGE_DOWNLOADS], false);
 
 	LoadPerspectives();
 	SetTabIcons();
@@ -236,7 +237,7 @@ MainWindow::MainWindow()
 	Logger::ShowDebugWindow(true);
 	//	Logger::ShowDebugWindow(cfg().ReadBool(_T("/debug")));
 
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::GamePromotedEvent, wxObjectEventFunction(&MainWindow::OnGamePromoted));
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnUnitsyncReloaded, MainWindow::OnUnitSyncReloaded);
 }
 
 wxBitmap MainWindow::GetTabIcon(const unsigned char* data, size_t size) const
@@ -250,11 +251,11 @@ wxBitmap MainWindow::GetTabIcon(const unsigned char* data, size_t size) const
 void MainWindow::SetTabIcons()
 {
 	m_func_tabs->SetPageBitmap(PAGE_CHAT, GetTabIcon(chat_icon_png, sizeof(chat_icon_png)));
-	m_func_tabs->SetPageBitmap(PAGE_LIST, GetTabIcon(join_icon_png, sizeof(join_icon_png)));
-	m_func_tabs->SetPageBitmap(PAGE_JOIN, GetTabIcon(broom_tab_icon_png, sizeof(broom_tab_icon_png)));
-	m_func_tabs->SetPageBitmap(PAGE_SINGLE, GetTabIcon(single_player_icon_png, sizeof(single_player_icon_png)));
-	m_func_tabs->SetPageBitmap(PAGE_TORRENT, GetTabIcon(downloads_icon_png, sizeof(downloads_icon_png)));
-	m_func_tabs->SetPageBitmap(PAGE_REPLAY, GetTabIcon(replay_icon_png, sizeof(replay_icon_png)));
+	m_func_tabs->SetPageBitmap(PAGE_BATTLELIST, GetTabIcon(join_icon_png, sizeof(join_icon_png)));
+	m_func_tabs->SetPageBitmap(PAGE_BATTLEROOM, GetTabIcon(broom_tab_icon_png, sizeof(broom_tab_icon_png)));
+	m_func_tabs->SetPageBitmap(PAGE_SINGLEPLAYER, GetTabIcon(single_player_icon_png, sizeof(single_player_icon_png)));
+	m_func_tabs->SetPageBitmap(PAGE_DOWNLOADS, GetTabIcon(downloads_icon_png, sizeof(downloads_icon_png)));
+	m_func_tabs->SetPageBitmap(PAGE_REPLAYS, GetTabIcon(replay_icon_png, sizeof(replay_icon_png)));
 	//m_func_tabs->SetPageBitmap( ??         , GetTabIcon( floppy_icon_png        , sizeof (floppy_icon_png) ) );
 	//m_func_tabs->SetPageBitmap( ??         , GetTabIcon( options_icon_png       , sizeof (options_icon_png) ) );
 	Refresh();
@@ -272,6 +273,7 @@ void MainWindow::SetLogWin(wxLogWindow* log)
 }
 MainWindow::~MainWindow()
 {
+	GlobalEventManager::Instance()->UnSubscribeAll(this);
 	Logger::ShowDebugWindow(false);
 	SetEvtHandlerEnabled(false);
 	if (m_opts_dialog) {
@@ -282,12 +284,12 @@ MainWindow::~MainWindow()
 
 void MainWindow::OnClose(wxCloseEvent& /*unused*/)
 {
+	wxLogWarning("MainWindow::OnClose");
 	Logger::ShowDebugWindow(false);
 	GlobalEventManager::Instance()->Send(GlobalEventManager::OnQuit);
 	//	GlobalEvent::Disconnect(MainWindow::OnClose, GlobalEvent::)
 	//	SetEvtHandlerEnabled(false);
 	{
-		wxWindowUpdateLocker lock(this);
 		SavePerspectives();
 		wxAuiManager* manager = GetAui().manager;
 		if (manager) {
@@ -320,7 +322,7 @@ void MainWindow::OnKillFocus(wxFocusEvent&)
 
 void MainWindow::OnMessage(wxCommandEvent& event)
 {
-	customMessageBoxNoModal(SL_MAIN_ICON, event.GetString());
+	customMessageBoxModal(SL_MAIN_ICON, event.GetString());
 }
 
 void MainWindow::AddMessageEvent(const wxString& message)
@@ -414,7 +416,7 @@ ChatPanel* MainWindow::GetActiveChatPanel()
 	unsigned int index = m_func_tabs->GetSelection();
 	if (index == PAGE_CHAT)
 		return m_chat_tab->GetActiveChatPanel();
-	if (index == PAGE_JOIN)
+	if (index == PAGE_BATTLEROOM)
 		return m_join_tab->GetActiveChatPanel();
 	return 0;
 }
@@ -453,7 +455,7 @@ void MainWindow::ShowTab(const unsigned int idx)
 	if (idx < m_tab_names.GetCount()) {
 		m_func_tabs->SetSelection(idx);
 		switch (idx) {
-			case PAGE_JOIN: {
+			case PAGE_BATTLEROOM: {
 				GetJoinTab().SetFocus();
 				ChatPanel* p = GetJoinTab().GetActiveChatPanel();
 				if (p != NULL) {
@@ -499,7 +501,7 @@ void MainWindow::OnMenuJoin(wxCommandEvent& /*unused*/)
 		return;
 	wxString answer;
 	if (ui().AskText(_("Join channel..."), _("Name of channel to join"), answer)) {
-		ServerManager::Instance()->JoinChannel(answer, wxEmptyString);
+		ServerManager::Instance()->JoinChannel(STD_STRING(answer), "");
 	}
 }
 
@@ -556,9 +558,18 @@ void MainWindow::OnMenuVersion(wxCommandEvent& /*unused*/)
 
 void MainWindow::OnUnitSyncReload(wxCommandEvent& /*unused*/)
 {
-	LSL::usync().ReloadUnitSyncLib();
-	m_menuEdit->Enable(MENU_SETTINGSPP, LSL::usync().IsLoaded());
-	GlobalEventManager::Instance()->Send(GlobalEventManager::OnUnitsyncReloaded);
+	bool res = LSL::usync().ReloadUnitSyncLib();
+	m_menuEdit->Enable(MENU_SETTINGSPP, false);
+	if (res) {
+		GlobalEventManager::Instance()->Send(GlobalEventManager::OnUnitsyncReloaded);
+		return;
+	}
+	wxLogWarning("Couldn't reload unitsync");
+}
+
+void MainWindow::OnUnitSyncReloaded(wxCommandEvent& /*unused*/)
+{
+	m_menuEdit->Enable(MENU_SETTINGSPP, true);
 }
 
 void MainWindow::MainWindow::OnShowWriteableDir(wxCommandEvent& /*unused*/)
@@ -622,10 +633,10 @@ void MainWindow::OnMenuAutojoinChannels(wxCommandEvent& /*unused*/)
 void MainWindow::OnMenuSelectLocale(wxCommandEvent& /*unused*/)
 {
 	if (wxGetApp().SelectLanguage()) {
-		customMessageBoxNoModal(SL_MAIN_ICON,
-					_("You need to restart SpringLobby for the language change to take effect."),
-					_("Restart required"),
-					wxICON_EXCLAMATION | wxOK);
+		customMessageBoxModal(SL_MAIN_ICON, wxString::Format(
+		  _("You need to restart %s for the language change to take effect."),
+		  GetSpringlobbyName()),
+		  _("Restart required"), wxICON_EXCLAMATION | wxOK);
 	}
 }
 
@@ -657,7 +668,8 @@ void MainWindow::OnMenuResetLayout(wxCommandEvent& /*event*/)
 {
 	cfg().Write(_T( "/ResetLayout" ), true);
 	sett().SaveSettings();
-	customMessageBoxNoModal(SL_MAIN_ICON, _("Please restart SpringLobby now"), wxEmptyString);
+	customMessageBoxModal(SL_MAIN_ICON, wxString::Format(
+	  _("Please restart %s now"), GetSpringlobbyName()), wxEmptyString);
 }
 
 const wxArrayString& MainWindow::GetTabNames()
@@ -711,7 +723,7 @@ void MainWindow::OnMenuPathInfo(wxCommandEvent& /*event*/)
 void MainWindow::OnMenuDownload(wxCommandEvent& /*event*/)
 {
 	wxString lines;
-	if (!ui().AskText(_("Which Archives to download? Put each archive on a single line, for example \ngame:ba:stable\nmap:The Rock Final\nengine:spring 98.0"), _("Download Archives"), lines, true))
+	if (!ui().AskText(_("Which Archives to download? Put each archive on a single line, for example") + _T("\ngame:ba:stable\nmap:The Rock Final\nengine:spring 104.0"), _("Download Archives"), lines, true))
 		return;
 	size_t start = 0;
 	int pos = 0;
@@ -722,17 +734,8 @@ void MainWindow::OnMenuDownload(wxCommandEvent& /*event*/)
 		const std::string category = STD_STRING(line.BeforeFirst(':'));
 		const std::string archive = STD_STRING(line.AfterFirst(':'));
 		if (!category.empty() && !archive.empty()) {
-			prDownloader().GetDownload(category, archive);
+			prDownloader().Download(DownloadEnum::getCatFromStr(category), archive);
 		}
 		start = pos + 1;
 	} while (pos != wxNOT_FOUND);
 }
-
-void MainWindow::OnGamePromoted(wxCommandEvent& promoteEvent)
-{
-	//Promote user without checking his status
-	//TODO: Maybe need to separate users by status to groups which one should be notified
-	//and which one should not be.
-	wxString msg = promoteEvent.GetString();
-	UiEvents::GetNotificationEventSender().SendEvent(UiEvents::NotficationData(UiEvents::GamePromoted, msg));
-}
