@@ -1,25 +1,23 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
-#include <wx/dcbuffer.h>
-#include <wx/geometry.h>
-#include <wx/settings.h>
-#include <wx/log.h>
-
 #define HAVE_WX
 #include "mapgridctrl.h"
 
+#include <lslunitsync/image.h>
+#include <lslutils/misc.h>
+#include <wx/dcbuffer.h>
+#include <wx/geometry.h>
+#include <wx/log.h>
+#include <wx/settings.h>
+#include <algorithm>
+#include <functional>
+
+#include "images/map_select_1.png.h"
+#include "images/map_select_2.png.h"
+#include "log.h"
 #include "settings.h"
 #include "uiutils.h"
 #include "utils/conversion.h"
 
-
-#include <algorithm>
-#include <lslutils/misc.h>
-#include <lslunitsync/image.h>
-#include "log.h"
-
-#include "images/map_select_1.png.h"
-#include "images/map_select_2.png.h"
 /// Size of the map previews.  This should be same as size of map previews in
 /// battle list and as prefetch size in SpringUnitSync for performance reasons.
 const int MINIMAP_SIZE = 98;
@@ -46,8 +44,8 @@ const wxEventType MapGridCtrl::LoadingCompletedEvt = wxNewEventType();
 
 MapGridCtrl::MapGridCtrl(wxWindow* parent, wxSize size, wxWindowID id)
     : wxPanel(parent, id, wxDefaultPosition, size, wxSIMPLE_BORDER | wxFULL_REPAINT_ON_RESIZE)
-    , m_async_image(boost::bind(&MapGridCtrl::OnGetMapImageAsyncCompleted, this, _1))
-    , m_async_ex(boost::bind(&MapGridCtrl::OnGetMapExAsyncCompleted, this, _1))
+    , m_async_image(std::bind(&MapGridCtrl::OnGetMapImageAsyncCompleted, this, std::placeholders::_1))
+    , m_async_ex(std::bind(&MapGridCtrl::OnGetMapExAsyncCompleted, this, std::placeholders::_1))
     , m_async_ops_count(0)
     , m_selection_follows_mouse(sett().GetMapSelectorFollowsMouse())
     , m_size(0, 0)
@@ -76,12 +74,16 @@ MapGridCtrl::MapGridCtrl(wxWindow* parent, wxSize size, wxWindowID id)
 
 MapGridCtrl::~MapGridCtrl()
 {
+	//m_mutex.Lock(); //FIXME: deadlocks sometimes, WTF?!
+	m_async_ex.Disconnect();
+	m_async_image.Disconnect();
 	Clear();
 	m_pending_mapimages.clear();
 	m_pending_mapinfos.clear();
 	m_async_ops_count = 0;
 	m_grid.clear();
 	m_maps.clear();
+	//m_mutex.Unlock();
 }
 
 
@@ -241,9 +243,9 @@ void MapGridCtrl::Clear()
 }
 
 
-bool MapGridCtrl::IsInGrid(const std::string& mapname)
+bool MapGridCtrl::IsInGrid(const wxString& mapname)
 {
-	for (auto gridentry : m_grid) {
+	for (const MapData* gridentry : m_grid) {
 		if (gridentry->name == mapname) {
 			return true;
 		}
@@ -256,10 +258,9 @@ void MapGridCtrl::AddMap(const wxString& mapname)
 	assert(wxThread::IsMain());
 	assert(!mapname.empty());
 
-	const std::string _mapname(mapname.mb_str());
-	if (!LSL::usync().MapExists(_mapname)) {
+	if (!LSL::usync().MapExists(STD_STRING(mapname))) {
 		//FIXME: offer download button on image instead?
-		wxLogError(_("Map %s doesn't exist!"), mapname.wc_str());
+		wxLogWarning(_("Map %s doesn't exist!"), mapname.wc_str());
 		return;
 	}
 
@@ -273,7 +274,7 @@ void MapGridCtrl::AddMap(const wxString& mapname)
 		UpdateAsyncFetches();
 	}
 
-	if (IsInGrid(_mapname)) {
+	if (IsInGrid(mapname)) {
 		wxLogWarning(_("Map %s already in grid!"), mapname.wc_str());
 		return;
 	}
@@ -340,7 +341,7 @@ void MapGridCtrl::UpdateAsyncFetches()
 	if (!m_pending_mapinfos.empty()) {
 		m_async_ops_count++;
 		const MapData* m = GetMaxPriorityMap(m_pending_mapinfos);
-		m_async_ex.GetMap(m->name);
+		m_async_ex.GetMapImageAsync(m->name, LSL::IMAGE_MAP_THUMB, MINIMAP_SIZE, MINIMAP_SIZE);
 	} else if (!m_pending_mapimages.empty()) {
 		MapData* m = GetMaxPriorityMap(m_pending_mapimages);
 		if (m->state != MapState_NoMinimap) //FIXME: this shouldn never happen
@@ -348,7 +349,7 @@ void MapGridCtrl::UpdateAsyncFetches()
 		m_async_ops_count++;
 
 		m->state = MapState_GetMinimap;
-		m_async_image.GetMinimap(m->name, MINIMAP_SIZE, MINIMAP_SIZE);
+		m_async_image.GetMapImageAsync(m->name, LSL::IMAGE_MAP_THUMB, MINIMAP_SIZE, MINIMAP_SIZE);
 	} else {
 		wxCommandEvent evt(LoadingCompletedEvt, GetId());
 		evt.SetEventObject(this);
@@ -363,6 +364,7 @@ void MapGridCtrl::DrawMap(wxDC& dc, MapData& map, int x, int y)
 		case MapState_NoMinimap:
 			map.priority = 1;
 			UpdateAsyncFetches();
+			[[fallthrough]];
 		// fall through, both when starting fetch and when waiting
 		// for it to finish, we want to show temporary image
 		case MapState_GetMinimap:
@@ -524,11 +526,14 @@ void MapGridCtrl::SelectMap(MapData* map)
 
 void MapGridCtrl::OnGetMapImageAsyncCompleted(const std::string& _mapname)
 {
+	m_mutex.Lock();
 	// if mapname is empty, some error occurred in LSL::usync().GetMinimap...
-	if (_mapname.empty())
+	if (!m_async_ex.Connected() || !m_async_image.Connected() || _mapname.empty()) {
+		m_mutex.Unlock();
 		return;
+	}
 	const wxString mapname = TowxString(_mapname);
-	wxImage minimap(LSL::usync().GetMinimap(_mapname, MINIMAP_SIZE, MINIMAP_SIZE).wximage());
+	wxImage minimap(LSL::usync().GetScaledMapImage(_mapname, LSL::IMAGE_MAP_THUMB, MINIMAP_SIZE, MINIMAP_SIZE).wximage());
 
 	const int w = minimap.GetWidth();
 	const int h = minimap.GetHeight();
@@ -550,19 +555,24 @@ void MapGridCtrl::OnGetMapImageAsyncCompleted(const std::string& _mapname)
 	wxCommandEvent evt(REFRESH_EVENT, GetId());
 	evt.SetEventObject(this);
 	wxPostEvent(this, evt);
+	m_mutex.Unlock();
 }
 
 
 void MapGridCtrl::OnGetMapExAsyncCompleted(const std::string& _mapname)
 {
+	m_mutex.Lock();
 	// if mapname is empty, some error occurred in LSL::usync().GetMapEx...
-	if (_mapname.empty())
+	if (!m_async_ex.Connected() || !m_async_image.Connected() || _mapname.empty()) {
+		m_mutex.Unlock();
 		return;
+	}
 	const wxString mapname = TowxString(_mapname);
 	LSL::UnitsyncMap m = LSL::usync().GetMap(_mapname);
 	m_maps[mapname].hash = m.hash;
 	m_maps[mapname].info = m.info;
 	m_async_ops_count--;
+	m_mutex.Unlock();
 }
 
 void MapGridCtrl::OnRefresh(wxCommandEvent& /*event*/)
