@@ -1,30 +1,32 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
-#include <wx/sizer.h>
-#include <wx/statbox.h>
-#include <wx/intl.h>
-#include <wx/stattext.h>
-#include <wx/checkbox.h>
-#include <wx/tooltip.h>
-#include <wx/radiobut.h>
-#include <wx/textctrl.h>
-#include <wx/button.h>
-#include <wx/filedlg.h>
-#include <wx/choice.h>
-#include <wx/spinctrl.h>
-
 #include "lobbyoptionstab.h"
-#include "settings.h"
-#include "utils/slconfig.h"
-#include "gui/customdialogs.h"
-#include "gui/controls.h"
-#include "utils/slpaths.h"
+
+#include <wx/button.h>
+#include <wx/checkbox.h>
+#include <wx/choice.h>
+#include <wx/filedlg.h>
+#include <wx/intl.h>
+#include <wx/radiobut.h>
+#include <wx/sizer.h>
+#include <wx/spinctrl.h>
+#include <wx/statbox.h>
+#include <wx/stattext.h>
+#include <wx/textctrl.h>
+#include <wx/tooltip.h>
+
 #include "aui/auimanager.h"
-#include "gui/ui.h"
+#include "gui/controls.h"
+#include "gui/customdialogs.h"
 #include "gui/mainwindow.h"
-#include "utils/conversion.h"
-#include "utils/uievents.h"
 #include "gui/notifications/notificationmanager.h"
+#include "gui/ui.h"
+#include "settings.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
+#include "utils/slconfig.h"
+#include "utils/slpaths.h"
+#include "utils/uievents.h"
+#include "utils/version.h"
 
 BEGIN_EVENT_TABLE(LobbyOptionsTab, wxPanel)
 
@@ -97,9 +99,9 @@ LobbyOptionsTab::LobbyOptionsTab(wxWindow* parent)
 	m_editor_box_sizer->Add(m_editor_loc_sizer, 0, wxEXPAND | wxALL, 2);
 	////////
 	wxStaticBoxSizer* m_autojoin_sizer = new wxStaticBoxSizer(wxVERTICAL, this, _("Autoconnect"));
-	m_autoconnect_label = new wxStaticText(this,
-					       -1,
-					       _("If checked, SpringLobby will automatically log on to the last used server"));
+	m_autoconnect_label = new wxStaticText(this, -1, wxString::Format (
+	  _("If checked, %s will automatically log on to the last used server"),
+	  GetSpringlobbyName()));
 	m_autojoin = new wxCheckBox(this, -1, _("Autoconnect on lobby start"), wxDefaultPosition, wxDefaultSize, 0);
 	m_autojoin->SetValue(cfg().ReadBool(_T( "/Server/Autoconnect")));
 	m_autojoin_sizer->Add(m_autoconnect_label, 1, wxEXPAND | wxALL, 5);
@@ -107,28 +109,32 @@ LobbyOptionsTab::LobbyOptionsTab(wxWindow* parent)
 
 	m_main_sizer->Add(m_web_box_sizer, 0, wxEXPAND | wxALL, 5);
 	m_main_sizer->Add(m_editor_box_sizer, 0, wxEXPAND | wxALL, 5);
-	m_main_sizer->Add(m_autojoin_sizer, 0, wxALL, 5);
 	wxStaticBoxSizer* m_updater_sizer = new wxStaticBoxSizer(wxVERTICAL, this, _("Automatic updates"));
-	m_updater_label = new wxStaticText(this,
-					   -1,
-					   _("SpringLobby can check at startup if a newer version is available and automatically download it for you."));
+	m_updater_label = new wxStaticText(this, -1, wxString::Format(
+	  _("%s can check at startup if a newer version is available and automatically download it for you."),
+	  GetSpringlobbyName()));
 	m_updater = new wxCheckBox(this, -1, _("automatically check for updates"), wxDefaultPosition, wxDefaultSize, 0);
 	m_updater->SetValue(cfg().ReadBool(_T("/General/AutoUpdate")));
 	m_updater_sizer->Add(m_updater_label, 1, wxEXPAND | wxALL, 5);
 	m_updater_sizer->Add(m_updater, 0, wxEXPAND | wxALL, 5);
 
-	m_main_sizer->Add(m_updater_sizer, 0, wxALL, 5);
+	m_main_sizer->Add(m_autojoin_sizer, 0, wxEXPAND | wxALL, 5);
+	m_main_sizer->Add(m_updater_sizer, 0, wxEXPAND | wxALL, 5);
 
 	wxStaticBoxSizer* m_show_tooltips_sizer = new wxStaticBoxSizer(wxVERTICAL, this, _("Tooltips"));
 	m_show_tooltips = new wxCheckBox(this, -1, _("Show Tooltips?"), wxDefaultPosition, wxDefaultSize, 0);
 	m_show_tooltips->SetValue(sett().GetShowTooltips());
 #ifndef __WXMSW__ // on windows this change is immediate
-	m_show_tooltips_label = new wxStaticText(this, -1, _("Requires SpringLobby restart to take effect."));
+	m_show_tooltips_label = new wxStaticText(this, -1, wxString::Format(
+	  _("Requires %s restart to take effect."), GetSpringlobbyName()));
 	m_show_tooltips_sizer->Add(m_show_tooltips_label, 1, wxEXPAND | wxALL, 5);
 #endif
 	m_show_tooltips_sizer->Add(m_show_tooltips, 0, wxEXPAND | wxALL, 5);
 
-	m_main_sizer->Add(m_show_tooltips_sizer, 0, wxALL, 5);
+	wxStaticBoxSizer* m_show_promotions_sizer = new wxStaticBoxSizer(wxVERTICAL, this, _("Battle Promotion"));
+	m_show_promotions = new wxCheckBox(this, -1, _("Show notifications when someone promotes battle?"), wxDefaultPosition, wxDefaultSize, 0);
+	m_show_promotions->SetValue(cfg().ReadBool("/GUI/ShowPromotions"));
+	m_show_promotions_sizer->Add(m_show_promotions, 0, wxEXPAND | wxALL, 5);
 
 	wxStaticBoxSizer* m_complete_method_sizer = new wxStaticBoxSizer(wxVERTICAL, this, _("Tab completion method"));
 	m_complete_method_label = new wxStaticText(this, -1, _("\"Match exact\" will complete a word if there is one and only one match.\n"
@@ -141,7 +147,9 @@ LobbyOptionsTab::LobbyOptionsTab(wxWindow* parent)
 	m_complete_method_sizer->Add(m_complete_method_old, 0, wxEXPAND | wxALL, 5);
 	m_complete_method_sizer->Add(m_complete_method_new, 0, wxEXPAND | wxALL, 5);
 
-	m_main_sizer->Add(m_complete_method_sizer, 0, wxALL, 5);
+	m_main_sizer->Add(m_show_tooltips_sizer, 0, wxEXPAND | wxALL, 5);
+	m_main_sizer->Add(m_show_promotions_sizer, 0, wxEXPAND | wxALL, 5);
+	m_main_sizer->Add(m_complete_method_sizer, 0, wxEXPAND | wxALL, 5);
 
 	wxStaticBoxSizer* m_misc_gui_sizer = new wxStaticBoxSizer(wxVERTICAL, this, _("Misc GUI"));
 	m_use_tabicons = new wxCheckBox(this, -1, _("Show big icons in mainwindow tabs?"), wxDefaultPosition, wxDefaultSize, 0);
@@ -169,15 +177,16 @@ LobbyOptionsTab::LobbyOptionsTab(wxWindow* parent)
 	m_test_notification = new wxButton(this, TEST_NOTIFICATION, _("Test Notification"));
 	m_misc_gui_sizer->Add(m_x_on_all_tabs, 1, wxEXPAND | wxALL, 5);
 	m_misc_gui_sizer->Add(m_test_notification, 1, wxEXPAND | wxALL, 5);
-	m_main_sizer->Add(m_misc_gui_sizer, 0, wxALL, 5);
 
 	wxStaticBoxSizer* m_start_tab_sizer = new wxStaticBoxSizer(wxHORIZONTAL, this, _("Start tab"));
 	m_start_tab = new wxChoice(this, -1, wxDefaultPosition, wxDefaultSize, ui().mw().GetTabNames());
 	m_start_tab->SetSelection(cfg().ReadLong(_T( "/GUI/StartTab" )));
 	wxStaticText* m_start_tab_label = new wxStaticText(this, -1, _("Select which tab to show at startup"));
-	m_start_tab_sizer->Add(m_start_tab_label, 0, wxALIGN_CENTER_VERTICAL | wxEXPAND | wxALL, 5);
-	m_start_tab_sizer->Add(m_start_tab, 0, wxALIGN_CENTER_VERTICAL, 5);
-	m_main_sizer->Add(m_start_tab_sizer, 0, wxALL, 5);
+	m_start_tab_sizer->Add(m_start_tab_label, 0, wxEXPAND | wxALL, 5);
+	m_start_tab_sizer->Add(m_start_tab, 0, wxEXPAND | wxALIGN_TOP, 5);
+
+	m_main_sizer->Add(m_misc_gui_sizer, 0, wxEXPAND | wxALL, 5);
+	m_main_sizer->Add(m_start_tab_sizer, 0, wxEXPAND | wxALL, 5);
 
 	//dummy event that updates controls to correct state
 	wxCommandEvent evt;
@@ -203,6 +212,7 @@ void LobbyOptionsTab::OnApply(wxCommandEvent& /*unused*/)
 	bool show = m_show_tooltips->IsChecked();
 	wxToolTip::Enable(show);
 	sett().SetShowTooltips(show);
+	cfg().Write(_T("/GUI/ShowPromotions"), m_show_promotions->IsChecked());
 
 	sett().SetCompletionMethod(m_complete_method_new->GetValue() ? Settings::MatchNearest : Settings::MatchExact);
 
@@ -216,6 +226,8 @@ void LobbyOptionsTab::OnApply(wxCommandEvent& /*unused*/)
 	sett().SetUseNotificationPopups(m_use_notif_popups->IsChecked());
 	sett().SetNotificationPopupPosition(m_notif_popup_pos->GetSelection());
 	sett().SetNotificationPopupDisplayTime(m_notif_popup_time->GetValue());
+
+	GlobalEventManager::Instance()->Send(GlobalEventManager::ApplicationSettingsChangedEvent);
 }
 
 
@@ -227,6 +239,8 @@ void LobbyOptionsTab::OnRestore(wxCommandEvent& /*unused*/)
 	m_show_tooltips->SetValue(show);
 	wxToolTip::Enable(show);
 
+	m_show_promotions->SetValue(cfg().ReadBool("/GUI/ShowPromotions"));
+
 	m_complete_method_old->SetValue(sett().GetCompletionMethod() == Settings::MatchExact);
 	m_complete_method_new->SetValue(sett().GetCompletionMethod() == Settings::MatchNearest);
 
