@@ -3,37 +3,34 @@
 //
 // Class: MainOptionsTab
 //
-
 #include "mainoptionstab.h"
 
-#include <wx/icon.h>
-#include <wx/intl.h>
-#include <wx/notebook.h>
-#include <wx/imaglist.h>
 #include <wx/button.h>
-#include <wx/sizer.h>
+#include <wx/icon.h>
+#include <wx/imaglist.h>
+#include <wx/intl.h>
 #include <wx/log.h>
+#include <wx/notebook.h>
+#include <wx/sizer.h>
 
 #include "aui/auimanager.h"
-#include "gui/slbook.h"
-
-#include "springoptionstab.h"
 #include "chatoptionstab.h"
-#include "groupoptionspanel.h"
 #include "downloadoptionspanel.h"
-#include "lobbyoptionstab.h"
-
-#include "settings.h"
-#include "gui/uiutils.h"
+#include "groupoptionspanel.h"
 #include "gui/controls.h"
-#include "utils/conversion.h"
-#include "log.h"
-
-#include "images/torrentoptionspanel_icon.png.h"
+#include "gui/slbook.h"
+#include "gui/uiutils.h"
 #include "images/spring.xpm"
-#include "images/userchat.xpm"
 #include "images/springlobby12x12.xpm"
-
+#include "images/torrentoptionspanel_icon.png.h"
+#include "images/userchat.xpm"
+#include "lobbyoptionstab.h"
+#include "log.h"
+#include "settings.h"
+#include "springoptionstab.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
+#include "utils/version.h"
 
 BEGIN_EVENT_TABLE(MainOptionsTab, wxPanel)
 
@@ -65,8 +62,8 @@ MainOptionsTab::MainOptionsTab(wxWindow* parent)
 	m_spring_opts = new SpringOptionsTab(m_tabs);
 	m_tabs->AddPage(m_spring_opts, _("Spring"), true, wxIcon(spring_xpm));
 
-	m_torrent_opts = new TorrentOptionsPanel(m_tabs);
-	m_tabs->AddPage(m_torrent_opts, _("Downloads"), true, charArr2wxBitmap(torrentoptionspanel_icon_png, sizeof(torrentoptionspanel_icon_png)));
+	m_download_opts = new DownloadOptionsPanel(m_tabs);
+	m_tabs->AddPage(m_download_opts, _("Downloads"), true, charArr2wxBitmap(torrentoptionspanel_icon_png, sizeof(torrentoptionspanel_icon_png)));
 
 	m_chat_opts = new ChatOptionsTab(m_tabs);
 	m_tabs->AddPage(m_chat_opts, _("Chat"), true, wxIcon(userchat_xpm));
@@ -116,10 +113,12 @@ void MainOptionsTab::OnApply(wxCommandEvent& event)
 {
 	m_spring_opts->OnApply(event);
 	m_chat_opts->OnApply(event);
-	m_torrent_opts->OnApply(event);
+	m_download_opts->OnApply(event);
 	m_lobby_opts->OnApply(event);
 
 	sett().SaveSettings();
+
+	GlobalEventManager::Instance()->Send(GlobalEventManager::OnUnitsyncReloaded);
 }
 
 void MainOptionsTab::OnOk(wxCommandEvent& event)
@@ -132,7 +131,7 @@ void MainOptionsTab::OnRestore(wxCommandEvent& event)
 {
 	m_spring_opts->OnRestore(event);
 	m_chat_opts->OnRestore(event);
-	m_torrent_opts->OnRestore(event);
+	m_download_opts->OnRestore(event);
 	m_lobby_opts->OnRestore(event);
 	frame->Close();
 }
@@ -163,7 +162,9 @@ void MainOptionsTab::SavePerspective(const wxString& perspective_name)
 }
 
 OptionsDialog::OptionsDialog(wxWindow* parent)
-    : wxDialog(parent, -1, _("SpringLobby Preferences"), wxDefaultPosition, wxSize(1055, 620), wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER | wxMAXIMIZE_BOX)
+    : wxDialog(parent, -1, wxString::Format(_("%s Preferences"), GetSpringlobbyName()),
+	    wxDefaultPosition, wxSize(1055, 620),
+	    wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER | wxMAXIMIZE_BOX)
     , WindowAttributesPickle(_T("preferences"), this, wxSize(1055, 620))
 {
 	SetMinSize(wxSize(1055, 620));
