@@ -3,10 +3,9 @@
 #ifndef SPRINGLOBBY_HEADERGUARD_MAINOPTIONSTAB_H
 #define SPRINGLOBBY_HEADERGUARD_MAINOPTIONSTAB_H
 
-#include <wx/scrolwin.h>
-#include <wx/dialog.h>
 #include <gui/windowattributespickle.h>
-
+#include <wx/dialog.h>
+#include <wx/scrolwin.h>
 class Ui;
 class wxCommandEvent;
 class wxBoxSizer;
@@ -17,7 +16,7 @@ class SpringOptionsTab;
 class ChatOptionsTab;
 class wxButton;
 class wxBoxSizer;
-class TorrentOptionsPanel;
+class DownloadOptionsPanel;
 class GroupOptionsPanel;
 class LobbyOptionsTab;
 
@@ -53,7 +52,7 @@ private:
 
 	SpringOptionsTab* m_spring_opts;
 	ChatOptionsTab* m_chat_opts;
-	TorrentOptionsPanel* m_torrent_opts;
+	DownloadOptionsPanel* m_download_opts;
 	GroupOptionsPanel* m_groups_opts;
 	LobbyOptionsTab* m_lobby_opts;
 
