@@ -5,26 +5,27 @@
 
 #include <wx/dataview.h>
 #include "gui/basedataviewmodel.h"
-
 struct StoredGame;
 
-class PlaybackDataModel: public BaseDataViewModel<StoredGame>{
+class PlaybackDataModel : public BaseDataViewModel<StoredGame>
+{
 public:
 	PlaybackDataModel();
 	virtual ~PlaybackDataModel();
 
-    virtual void GetValue( wxVariant &variant, const wxDataViewItem &item, unsigned int col ) const override;
-    virtual wxString GetColumnType(unsigned int columnt) const override;
+	virtual int Compare(const wxDataViewItem& itemA, const wxDataViewItem& itemB, unsigned int column, bool ascending) const override;
+	virtual void GetValue(wxVariant& variant, const wxDataViewItem& item, unsigned int col) const override;
+	virtual wxString GetColumnType(unsigned int columnt) const override;
+	virtual bool HasDefaultCompare() const override { return true; }
 
 private:
-	enum ColumnIndexes
-	{
+	enum ColumnIndexes {
 		DATE = 0,
 		GAME,
 		MAP,
 		PLAYERS,
 		DURATION,
-		VERSION,
+		ENGINE,
 		FILESIZE,
 		FILENAME,
 		COLUMN_COUNT
