@@ -4,7 +4,6 @@
 #define SRC_GUI_PLAYBACK_PLAYBACKDATAVIEW_H_
 
 #include "gui/basedataviewctrl.h"
-
 class wxWindow;
 class PlaybackDataModel;
 struct StoredGame;
@@ -19,7 +18,7 @@ public:
 	PlaybackDataView(const wxString& dataViewName, wxWindow* parent);
 	virtual ~PlaybackDataView();
 
-	void AddPlayback(const StoredGame& replay);
+	void AddPlayback(const StoredGame& replay, bool resortIsNeeded = true);
 	void RemovePlayback(const StoredGame& replay);
 	void OnContextMenu(wxDataViewEvent& event);
 	void OnDLMap(wxCommandEvent& event);
@@ -49,7 +48,7 @@ private:
 		MAP,
 		PLAYERS,
 		DURATION,
-		VERSION,
+		ENGINE,
 		FILESIZE,
 		FILENAME
 	};
