@@ -4,15 +4,13 @@
 #define SPRINGLOBBY_HEADERGUARD_SINGLEPLAYERTAB_H
 
 #include <wx/scrolwin.h>
-
 #include "singleplayerbattle.h"
-#include "utils/globalevents.h"
-
 class Ui;
 class MapCtrl;
 class SinglePlayerBattle;
 
 class wxWindow;
+class wxBoxSizer;
 class wxButton;
 class wxStaticLine;
 class wxChoice;
@@ -23,7 +21,7 @@ class wxCheckBox;
 class wxMouseEvent;
 class ColorButton;
 
-class SinglePlayerTab : public wxPanel, public GlobalEvent
+class SinglePlayerTab : public wxPanel
 {
 public:
 	SinglePlayerTab(wxWindow* parent, MainSinglePlayerTab& msptab);
@@ -56,18 +54,19 @@ public:
 	void OnUnitsyncReloaded(wxCommandEvent& /*data*/);
 	void ResetUsername();
 
-	void SetMap(unsigned int index);
-	void SetMod(unsigned int index);
 	void SetEngine(unsigned int index);
+	void SetMod(unsigned int index);
+	void SetMap(unsigned int index);
 
 private:
 	wxBoxSizer* m_main_sizer;
 	SinglePlayerBattle m_battle;
 
 	MapCtrl* m_minimap;
+	wxWindow* m_nominimap;
 	wxChoice* m_map_pick;
-	wxChoice* m_mod_pick;
-	wxChoice* m_engine_pic;
+	wxChoice* m_engine_choice;
+	wxChoice* m_game_choice;
 	wxStaticText* m_map_lbl;
 	wxStaticText* m_mod_lbl;
 	wxButton* m_select_btn;
