@@ -3,79 +3,74 @@
 //
 // Class: Ui
 //
+#include "ui.h"
 
-#include <wx/textdlg.h>
-#include <wx/intl.h>
-#include <wx/utils.h>
-#include <wx/debugrpt.h>
-#include <wx/filename.h>
-#include <wx/app.h>
-#include <wx/log.h>
-#include <wx/stdpaths.h>
-
-#include <stdexcept>
-
-#include <lslutils/globalsmanager.h>
 #include <lslunitsync/springbundle.h>
 #include <lslunitsync/unitsync.h>
+#include <lslutils/globalsmanager.h>
+#include <wx/app.h>
+#include <wx/debugrpt.h>
+#include <wx/filename.h>
+#include <wx/intl.h>
+#include <wx/log.h>
+#include <wx/stdpaths.h>
+#include <wx/textdlg.h>
+#include <wx/utils.h>
+#include <stdexcept>
 
-#include "ui.h"
-#include "offlineserver.h"
-#include "tasserver.h"
-#include "utils/slconfig.h"
-#include "iserver.h"
-#include "serverselector.h"
-#include "spring.h"
 #include "channel.h"
-#include "gui/connectwindow.h"
-#include "gui/mainwindow.h"
-#include "user.h"
-#include "utils/conversion.h"
-#include "utils/uievents.h"
-#include "utils/slpaths.h"
-#include "utils/version.h"
-#include "utils/globalevents.h"
-#include "gui/uiutils.h"
-#include "gui/chatpanel.h"
+#include "downloader/prdownloader.h"
+#include "exception.h"
+#include "gui/agreementdialog.h"
 #include "gui/battlelist/battlelisttab.h"
+#include "gui/chatpanel.h"
+#include "gui/connectwindow.h"
+#include "gui/customdialogs.h"
 #include "gui/hosting/battleroomtab.h"
 #include "gui/hosting/mainjoinbattletab.h"
 #include "gui/hosting/mainsingleplayertab.h"
 #include "gui/mainchattab.h"
-#include "crashreport.h"
 #include "gui/maindownloadtab.h"
-#include "downloader/prdownloader.h"
-#include "gui/agreementdialog.h"
-#include "updatehelper.h"
-#include "gui/customdialogs.h"
-#include "httpfile.h"
+#include "gui/mainwindow.h"
 #include "gui/textentrydialog.h"
+#include "gui/uiutils.h"
+#include "ibattle.h"
+#include "iserver.h"
 #include "log.h"
-#include "settings.h"
+#include "offlineserver.h"
 #include "servermanager.h"
-#include "contentmanager.h"
-#include "exception.h"
-#include "contentdownloadrequest.h"
-
+#include "serverselector.h"
+#include "settings.h"
+#include "spring.h"
+#include "tasserver.h"
+#include "updatehelper.h"
+#include "user.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
+#include "utils/platform.h"
+#include "utils/slconfig.h"
+#include "utils/slpaths.h"
+#include "utils/sortutil.h"
+#include "utils/uievents.h"
+#include "utils/version.h"
 #ifndef DISABLE_SOUND
 #include "sound/alsound.h"
 #endif
 
 
 SLCONFIG("/General/AutoUpdate", true, "Determines if springlobby should check for updates on startup");
-SLCONFIG("/General/LastUpdateCheck", 0L, "Last time springlobby checked for an update");
-SLCONFIG("/GUI/StartTab", (long)MainWindow::PAGE_SINGLE, "which tab to show on startup");
+SLCONFIG("/GUI/StartTab", (long)MainWindow::PAGE_BATTLELIST, "which tab to show on startup");
 SLCONFIG("/Chat/BroadcastEverywhere", true, "setting to spam the server messages in all channels");
 SLCONFIG("/Server/Autoconnect", false, "Connect to server on startup");
 
 
-static unsigned int s_reconnect_delay_ms = 6 * 1000;	  //initial reconnect delay
+static unsigned int s_reconnect_delay_ms = 6 * 1000; //initial reconnect delay
 
 Ui& ui()
 {
 	assert(wxThread::IsMain());
 	static LSL::Util::LineInfo<Ui> m(AT);
-	static LSL::Util::GlobalObjectHolder<Ui, LSL::Util::LineInfo<Ui> > m_ui(m);
+	static LSL::Util::GlobalObjectHolder<Ui, LSL::Util::LineInfo<Ui>> m_ui(m);
 	return m_ui;
 }
 
@@ -86,18 +81,15 @@ Ui::Ui()
     , m_first_update_trigger(true)
     , m_connecting(false)
     , m_connect_retries(0)
-    , m_battle_info_updatedSink(this, &BattleEvents::GetBattleEventSender((BattleEvents::BattleInfoUpdate)))
 {
 	m_main_win = new MainWindow();
 	CustomMessageBoxBase::setLobbypointer(m_main_win);
 	m_serv = new TASServer();
-//	m_serv = new OfflineServer();
+	//	m_serv = new OfflineServer();
 	serverSelector().SetCurrentServer(m_serv);
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnSpringTerminated, wxObjectEventFunction(&Ui::OnSpringTerminated));
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnQuit, wxObjectEventFunction(&Ui::OnQuit));
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::OnLobbyDownloaded, wxObjectEventFunction(&Ui::OnDownloadComplete));
-	GlobalEventManager::Instance()->Subscribe(this, GlobalEventManager::UserBattleStatusChangedEvent, wxObjectEventFunction(&Ui::OnUserBattleStatus));
-
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnSpringTerminated, Ui::OnSpringTerminated);
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnQuit, Ui::OnQuit);
+	SUBSCRIBE_GLOBAL_EVENT(GlobalEventManager::OnLobbyDownloaded, Ui::OnLobbyDownloaded);
 }
 
 Ui::~Ui()
@@ -165,7 +157,7 @@ void Ui::ShowConnectWindow()
 
 void Ui::ReopenServerTab()
 {
-	if (m_serv->IsOnline()) {
+	if (m_serv->IsConnected()) {
 		AddServerWindow(TowxString(m_serv->GetServerName()));
 		// re-add all users to the user list
 		const UserList& list = m_serv->GetUserList();
@@ -205,7 +197,7 @@ void Ui::Quit()
 //! @note this does not return until the user pressed any of the buttons or closed the dialog.
 bool Ui::Ask(const wxString& heading, const wxString& question) const
 {
-	int answer = customMessageBox(SL_MAIN_ICON, question, heading, wxYES_NO);
+	int answer = customMessageBox(SL_MAIN_ICON, question, heading, wxYES_NO | wxCANCEL);
 	return (answer == wxYES);
 }
 
@@ -234,97 +226,42 @@ void Ui::ShowMessage(const wxString& heading, const wxString& message) const
 	serverMessageBox(SL_MAIN_ICON, message, heading, wxOK);
 }
 
-//TODO: Move this to anywhere else
-bool Ui::ExecuteSayCommand(const wxString& cmd)
-{
-	if (ServerManager::Instance()->IsConnected() == false) {
-		return false;
-	}
-
-	if ((cmd.BeforeFirst(' ').Lower() == _T("/join")) || (cmd.BeforeFirst(' ').Lower() == _T("/j"))) {
-		wxString channel = cmd.AfterFirst(' ');
-		const wxString pass = channel.AfterFirst(' ');
-		if (!pass.IsEmpty())
-			channel = channel.BeforeFirst(' ');
-		if (channel.StartsWith(_T("#")))
-			channel.Remove(0, 1);
-		m_serv->JoinChannel(STD_STRING(channel), STD_STRING(pass));
-		return true;
-	} else if (cmd.BeforeFirst(' ').Lower() == _T("/away")) {
-		m_serv->GetMe().Status().away = true;
-		m_serv->GetMe().SendMyUserStatus();
-		mw().GetJoinTab().GetBattleRoomTab().UpdateMyInfo();
-		return true;
-	} else if (cmd.BeforeFirst(' ').Lower() == _T("/back")) {
-		if (ServerManager::Instance()->IsConnected()) {
-			m_serv->GetMe().Status().away = false;
-			m_serv->GetMe().SendMyUserStatus();
-			mw().GetJoinTab().GetBattleRoomTab().UpdateMyInfo();
-			return true;
-		}
-	} else if (cmd.BeforeFirst(' ').Lower() == _T("/ingame")) {
-		const wxString nick = cmd.AfterFirst(' ');
-		m_serv->RequestInGameTime(STD_STRING(nick));
-		return true;
-	} else if (cmd.BeforeFirst(' ').Lower() == _T("/help")) {
-		const wxString topic = cmd.AfterFirst(' ');
-		ConsoleHelp(topic.Lower());
-		return true;
-	} else if (cmd.BeforeFirst(' ').Lower() == _T("/msg")) {
-		const wxString user = cmd.AfterFirst(' ').BeforeFirst(' ');
-		const wxString msg = cmd.AfterFirst(' ').AfterFirst(' ');
-		m_serv->SayPrivate(STD_STRING(user), STD_STRING(msg));
-		return true;
-	} else if (cmd.BeforeFirst(' ').Lower() == _T("/channels")) {
-		mw().ShowChannelChooser();
-		return true;
-	}
-	return false;
-}
-
-
-void Ui::ConsoleHelp(const wxString& topic)
+void Ui::ConsoleHelp()
 {
 	ChatPanel* panel = GetActiveChatPanel();
 	if (panel == 0) {
 		wxLogError(_T("GetActiveChatPanel() failed: couldn't find current active panel."));
 		return;
 	}
-	if (topic == wxEmptyString) {
-		panel->ClientMessage(_("SpringLobby commands help."));
-		panel->ClientMessage(wxEmptyString);
-		panel->ClientMessage(_("Global commands:"));
-		panel->ClientMessage(_("  \"/away\" - Sets your status to away."));
-		panel->ClientMessage(_("  \"/back\" - Resets your away status."));
-		panel->ClientMessage(_("  \"/changepassword newpassword\" - Changes the current active account's password, needs the old password saved in login box"));
-		panel->ClientMessage(_("  \"/changepassword oldpassword newpassword\" - Changes the current active account's password, password cannot contain spaces"));
-		panel->ClientMessage(_("  \"/channels\" - Lists currently active channels."));
-		panel->ClientMessage(_("  \"/help [topic]\" - Put topic if you want to know more specific information about a command."));
-		panel->ClientMessage(_("  \"/join channel [password]\" - Joins a channel."));
-		panel->ClientMessage(_("  \"/j\" - Alias to /join."));
-		panel->ClientMessage(_("  \"/ingame\" - Shows how much time you have in game."));
-		panel->ClientMessage(_("  \"/msg username [text]\" - Sends a private message containing text to username."));
-		panel->ClientMessage(_("  \"/part\" - Leaves current channel."));
-		panel->ClientMessage(_("  \"/p\" - Alias to /part."));
-		panel->ClientMessage(_("  \"/rename newalias\" - Changes your nickname to newalias."));
-		panel->ClientMessage(_("  \"/sayver\" - Says what version of SpringLobby you have in chat."));
-		panel->ClientMessage(_("  \"/testmd5 text\" - Returns md5-b64 hash of given text."));
-		panel->ClientMessage(_("  \"/ver\" - Displays what version of SpringLobby you have."));
-		panel->ClientMessage(_("  \"/clear\" - Clears all text from current chat panel"));
-		panel->ClientMessage(wxEmptyString);
-		panel->ClientMessage(_("Chat commands:"));
-		panel->ClientMessage(_("  \"/me action\" - Say IRC style action message."));
-		panel->ClientMessage(wxEmptyString);
-		panel->ClientMessage(_("If you are missing any commands, go to #springlobby and try to type it there :)"));
-		//    panel->ClientMessage( _("  \"/\" - .") );
-	} else if (topic == _T("topics")) {
-		panel->ClientMessage(_("No topics written yet."));
-	} else {
-		panel->ClientMessage(_("The topic \"") + topic + _("\" was not found. Type \"/help topics\" only for available topics."));
-	}
+	panel->ClientMessage(wxString::Format(_("%s commands help:"), GetSpringlobbyName()));
+	panel->ClientMessage(wxEmptyString);
+	panel->ClientMessage(_("Global commands:"));
+	panel->ClientMessage(_("  \"/away\" - Sets your status to away."));
+	panel->ClientMessage(_("  \"/back\" - Resets your away status."));
+	panel->ClientMessage(_("  \"/changepassword newpassword\" - Changes the current active account's password, needs the old password saved in login box"));
+	panel->ClientMessage(_("  \"/changepassword oldpassword newpassword\" - Changes the current active account's password, password cannot contain spaces"));
+	panel->ClientMessage(_("  \"/channels\" - Lists currently active channels."));
+	panel->ClientMessage(_("  \"/help [topic]\" - Put topic if you want to know more specific information about a command."));
+	panel->ClientMessage(_("  \"/join channel [password]\" - Joins a channel."));
+	panel->ClientMessage(_("  \"/j\" - Alias to /join."));
+	panel->ClientMessage(_("  \"/ingame\" - Shows how much time you have in game."));
+	panel->ClientMessage(_("  \"/msg username [text]\" - Sends a private message containing text to username."));
+	panel->ClientMessage(_("  \"/part\" - Leaves current channel."));
+	panel->ClientMessage(_("  \"/p\" - Alias to /part."));
+	panel->ClientMessage(_("  \"/rename newalias\" - Changes your nickname to newalias."));
+	panel->ClientMessage(wxString::Format(
+	  _("  \"/sayver\" - Says what version of %s you have in chat."), GetSpringlobbyName()));
+	panel->ClientMessage(_("  \"/testmd5 text\" - Returns md5-b64 hash of given text."));
+	panel->ClientMessage(wxString::Format(
+	  _("  \"/ver\" - Displays what version of %s you have."), GetSpringlobbyName()));
+	panel->ClientMessage(_("  \"/clear\" - Clears all text from current chat panel"));
+	panel->ClientMessage(wxEmptyString);
+	panel->ClientMessage(_("Chat commands:"));
+	panel->ClientMessage(_("  \"/me action\" - Say IRC style action message."));
+	panel->ClientMessage(wxEmptyString);
+	panel->ClientMessage(_("If you are missing any commands, go to #springlobby and try to type it there :)"));
 }
 
-
 ChatPanel* Ui::GetChannelChatPanel(const wxString& channel)
 {
 	return mw().GetChannelChatPanel(channel);
@@ -334,38 +271,22 @@ ChatPanel* Ui::GetChannelChatPanel(const wxString& channel)
 ////////////////////////////////////////////////////////////////////////////////////////////
 // EVENTS
 ////////////////////////////////////////////////////////////////////////////////////////////
-
 //! @brief Called when connected to a server
 //!
 //! @todo Display in servertab
-void Ui::OnConnected(IServer& server, const wxString& server_name, const wxString& version, bool /*supported*/)
+void Ui::OnConnected(IServer& server, const wxString& server_name, const wxString& /*version*/, bool /*supported*/)
 {
 	slLogDebugFunc("");
+
+	delete m_con_win;
+	m_con_win = 0;
 	m_connect_retries = 10;
 
 	if (server.panel != nullptr)
 		server.panel->StatusMessage(_T("Connected to ") + server_name + _T("."));
 	mw().GetBattleListTab().OnConnected();
 
-	delete m_con_win;
-	m_con_win = 0;
-
-	if (version.empty()) {
-		wxLogWarning("default version supllied from server is empty!");
-		return;
-	}
-	std::map<std::string, LSL::SpringBundle> enginebundles = SlPaths::GetSpringVersionList();
-	if (enginebundles.size() == 0) {
-		if (Ask(_("Spring can't be found"), wxString::Format(_T("No useable spring engine can be found, download it? (spring %s)"), version.c_str()))) {
-			ContentDownloadRequest req;
-			req.EngineRequired("spring " + STD_STRING(version));
-			try {
-				ContentManager::Instance()->DownloadContent(req);
-			} catch (Exception& e) {
-				wxLogError(_("Failed to download engine: ") + e.Reason());
-			}
-		}
-	}
+	ReopenServerTab();
 }
 
 void Ui::OnLoggedIn()
@@ -384,10 +305,6 @@ void Ui::OnDisconnected(IServer& server, bool wasonline)
 	if (m_main_win == 0)
 		return;
 	slLogDebugFunc("");
-	if (!&server) {
-		wxLogError(_T("WTF got null reference!!!"));
-		return;
-	}
 
 	mw().GetJoinTab().OnDisconnected();
 	mw().GetBattleListTab().OnDisconnected();
@@ -530,30 +447,24 @@ void Ui::OnServerMessage(IServer& server, const wxString& message)
 }
 
 
-void Ui::OnUserSaid(User& user, const wxString& message, bool fromme)
+void Ui::OnUserSaid(User& chan, User& user, const wxString& message)
 {
 	if (m_main_win == 0)
 		return;
-	if (user.panel == nullptr) {
-		mw().OpenPrivateChat(user);
+	if (chan.panel == nullptr) {
+		mw().OpenPrivateChat(chan);
 	}
-	if (fromme)
-		user.panel->Said(TowxString(m_serv->GetMe().GetNick()), message);
-	else
-		user.panel->Said(TowxString(user.GetNick()), message);
+	chan.panel->Said(TowxString(user.GetNick()), message);
 }
 
-void Ui::OnUserSaidEx(User& user, const wxString& action, bool fromme)
+void Ui::OnUserSaidEx(User& chan, User& user, const wxString& action)
 {
 	if (m_main_win == 0)
 		return;
-	if (user.panel == 0) {
-		mw().OpenPrivateChat(user);
+	if (chan.panel == 0) {
+		mw().OpenPrivateChat(chan);
 	}
-	if (fromme)
-		user.panel->DidAction(TowxString(m_serv->GetMe().GetNick()), action);
-	else
-		user.panel->DidAction(TowxString(user.GetNick()), action);
+	chan.panel->DidAction(TowxString(user.GetNick()), action);
 }
 
 void Ui::OnBattleOpened(IBattle& battle)
@@ -581,14 +492,19 @@ void Ui::OnBattleClosed(IBattle& battle)
 	mw().GetBattleListTab().RemoveBattle(battle);
 	try {
 		if (mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle) {
-			if (!battle.IsFounderMe())
-				customMessageBoxNoModal(SL_MAIN_ICON, _("The current battle was closed by the host."), _("Battle closed"));
+			if (!battle.IsFounderMe()) {
+				const wxString msg = _("The current battle was closed by the host.");
+				UiEvents::GetNotificationEventSender().SendEvent(UiEvents::NotficationData(UiEvents::ServerConnection, msg));
+			}
 			mw().GetJoinTab().LeaveCurrentBattle();
 		}
 	} catch (...) {
 	}
-	for (unsigned int b = 0; b < battle.GetNumUsers(); b++) {
-		User& user = battle.GetUser(b);
+
+	for (auto userpair : battle.GetUsers()) {
+		assert(userpair.second != nullptr);
+
+		User& user = *userpair.second;
 		user.SetBattle(0);
 		for (int i = 0; i < m_serv->GetNumChannels(); i++) {
 			Channel& chan = m_serv->GetChannel(i);
@@ -609,7 +525,7 @@ void Ui::OnUserJoinedBattle(IBattle& battle, User& user)
 	try {
 		if (mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle) {
 			mw().GetJoinTab().GetBattleRoomTab().OnUserJoined(user);
-			OnBattleInfoUpdated(std::make_pair(&battle, ""));
+			OnBattleInfoUpdated(battle, wxEmptyString);
 		}
 	} catch (...) {
 	}
@@ -634,10 +550,10 @@ void Ui::OnUserLeftBattle(IBattle& battle, User& user, bool isbot)
 	try {
 		if (mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle) {
 			mw().GetJoinTab().GetBattleRoomTab().OnUserLeft(user);
-			OnBattleInfoUpdated(std::make_pair(&battle, ""));
+			OnBattleInfoUpdated(battle, wxEmptyString);
 			if (&user == &m_serv->GetMe()) {
 				mw().GetJoinTab().LeaveCurrentBattle();
-				mw().ShowTab(MainWindow::PAGE_LIST);
+				mw().ShowTab(MainWindow::PAGE_BATTLELIST);
 			}
 		}
 	} catch (...) {
@@ -652,18 +568,13 @@ void Ui::OnUserLeftBattle(IBattle& battle, User& user, bool isbot)
 	}
 }
 
-void Ui::OnBattleInfoUpdated(BattleEvents::BattleEventData data)
+void Ui::OnBattleInfoUpdated(IBattle& battle, const wxString& Tag)
 {
-	IBattle& battle = *data.first;
-	const wxString Tag = TowxString(data.second);
 	if (m_main_win == 0)
 		return;
 	mw().GetBattleListTab().UpdateBattle(battle);
 	if (mw().GetJoinTab().GetCurrentBattle() == &battle) {
-		if (Tag.IsEmpty())
-			mw().GetJoinTab().UpdateCurrentBattle();
-		else
-			mw().GetJoinTab().UpdateCurrentBattle(Tag);
+		mw().GetJoinTab().UpdateCurrentBattle(Tag);
 	}
 }
 
@@ -672,7 +583,7 @@ void Ui::OnJoinedBattle(IBattle& battle)
 	if (m_main_win == 0)
 		return;
 	mw().GetJoinTab().JoinBattle(battle);
-	mw().ShowTab(MainWindow::PAGE_JOIN);
+	mw().ShowTab(MainWindow::PAGE_BATTLEROOM);
 	if (battle.GetNatType() != NAT_None) {
 		wxLogWarning(_T("joining game with NAT transversal"));
 	}
@@ -684,40 +595,28 @@ void Ui::OnHostedBattle(IBattle& battle)
 	if (m_main_win == 0)
 		return;
 	mw().GetJoinTab().HostBattle(battle);
-	mw().ShowTab(MainWindow::PAGE_JOIN);
+	mw().ShowTab(MainWindow::PAGE_BATTLEROOM);
 }
 
 
-void Ui::OnUserBattleStatus(wxCommandEvent& event)
+void Ui::OnUserBattleStatus(User& user)
 {
 	if (m_main_win == 0) {
 		return;
 	}
+	if (m_serv == 0 || !m_serv->IsOnline()) {
+		return;
+	}
 
-	User* user = static_cast<User*>(event.GetClientData());
-	mw().GetJoinTab().BattleUserUpdated(*user);
-	IBattle* battle = user->GetBattle();
+	mw().GetJoinTab().BattleUserUpdated(user);
+	IBattle* battle = user.GetBattle();
 	if (battle == nullptr) {
 		wxLogWarning("trying to update non-existing battle");
 		return;
 	}
-	OnBattleInfoUpdated(std::make_pair(battle, ""));
+	OnBattleInfoUpdated(*battle, wxEmptyString);
 }
 
-
-void Ui::OnRequestBattleStatus(IBattle& battle)
-{
-	if (m_main_win == 0)
-		return;
-	try {
-		if (mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle) {
-			mw().GetJoinTab().GetBattleRoomTab().GetBattle()->OnRequestBattleStatus();
-		}
-	} catch (...) {
-	}
-}
-
-
 void Ui::OnSaidBattle(IBattle& /*battle*/, const wxString& nick, const wxString& msg)
 {
 	if (m_main_win == 0)
@@ -731,6 +630,7 @@ void Ui::OnSaidBattle(IBattle& /*battle*/, const wxString& nick, const wxString&
 void Ui::OnSpringTerminated(wxCommandEvent& data)
 {
 	const int exit_code = data.GetInt();
+	wxLogInfo("Exiting with %d", exit_code);
 
 	if (!m_serv)
 		return;
@@ -745,13 +645,7 @@ void Ui::OnSpringTerminated(wxCommandEvent& data)
 			battle->SetIsLocked(false);
 			battle->SendHostInfo(IBattle::HI_Locked);
 		}
-	} catch (assert_exception) {
-	}
-
-	if (exit_code != 0) {
-		SpringDebugReport report;
-		if (wxDebugReportPreviewStd().Show(report))
-			report.Process();
+	} catch (assert_exception&) {
 	}
 }
 
@@ -759,9 +653,8 @@ void Ui::OnSpringTerminated(wxCommandEvent& data)
 void Ui::OnAcceptAgreement(const wxString& agreement)
 {
 	AgreementDialog dlg(m_main_win, agreement);
-	if (dlg.ShowModal() == 1) {
+	if (dlg.ShowModal() == wxID_OK) {
 		m_serv->AcceptAgreement();
-		m_serv->Login();
 	} else {
 		m_connect_retries = 0;
 		m_serv->Disconnect();
@@ -816,38 +709,17 @@ void Ui::ReloadPresetList()
 	}
 }
 
-bool Ui::OnPresetRequiringMap(const wxString& mapname)
-{
-	if (wxYES == customMessageBox(SL_MAIN_ICON,
-				      _("The selected preset requires the map ") + mapname + _(". Should it be downloaded? \
-                                    \n Selecting \"no\" will remove the missing map from the preset.\n\
-                                    Please reselect the preset after download finished"),
-				      _("Map missing"),
-				      wxYES_NO)) {
-		ContentDownloadRequest req;
-		req.MapRequired(STD_STRING(mapname), "");
-		try {
-			ContentManager::Instance()->DownloadContent(req);
-		} catch (Exception& e) {
-			wxLogError(_("Failed to download map: ") + e.Reason());
-			return false;
-		}
-		return true;
-	}
-	return false;
-}
-
 void Ui::OpenFileInEditor(const wxString& filepath)
 {
 	const wxString editor_path = TowxString(SlPaths::GetEditorPath());
 	if (editor_path == wxEmptyString) {
-		customMessageBoxNoModal(SL_MAIN_ICON, _T("You have not chosen an external text editor to open files with.\nPlease Select one now."), _T("No editor set"));
+		customMessageBoxModal(SL_MAIN_ICON, _T("You have not chosen an external text editor to open files with.\nPlease Select one now."), _T("No editor set"));
 		mw().ShowConfigure(MainWindow::OPT_PAGE_GENERAL);
 		return;
 	}
 	bool success = (wxExecute(editor_path + _T(" \"") + filepath + _T("\""), wxEXEC_ASYNC) != 0);
 	if (!success) {
-		customMessageBoxNoModal(SL_MAIN_ICON, _T("There was a problem launching the editor.\nPlease make sure the path is correct and the binary executable for your user.\nNote it's currently not possible to use shell-only editors like ed, vi, etc."), _T("Problem launching editor"));
+		customMessageBoxModal(SL_MAIN_ICON, _T("There was a problem launching the editor.\nPlease make sure the path is correct and the binary executable for your user.\nNote it's currently not possible to use shell-only editors like ed, vi, etc."), _T("Problem launching editor"));
 		mw().ShowConfigure(MainWindow::OPT_PAGE_GENERAL);
 	}
 }
@@ -863,12 +735,7 @@ void Ui::OnInit()
 		mw().ShowTab(cfg().ReadLong(_T( "/GUI/StartTab" )));
 		//don't ask for updates on first run, that's a bit much for a newbie
 		if (cfg().ReadBool(_T("/General/AutoUpdate"))) {
-			const time_t now = time(0);
-			const size_t lastcheck = cfg().ReadLong(_T("/General/LastUpdateCheck"));
-			if (now - lastcheck > 3600) {
-				CheckForUpdates(false);
-				cfg().Write(_T("/General/LastUpdateCheck"), (long)now);
-			}
+			CheckForUpdates(false);
 		}
 	}
 }
@@ -883,7 +750,7 @@ void Ui::FirstRunWelcome()
 	ShowConnectWindow();
 }
 
-void Ui::OnDownloadComplete(wxCommandEvent& data)
+void Ui::OnLobbyDownloaded(wxCommandEvent& data)
 {
 	if (data.GetInt() != 0) {
 		wxLogError(_T("Download springlobby update failed"));
@@ -910,56 +777,70 @@ void Ui::OnDownloadComplete(wxCommandEvent& data)
 	mw().Close();
 }
 
-void Ui::CheckForUpdates(bool show)
+void Ui::CheckForUpdates(bool is_interactive)
 {
-	ContentManager* contMan = ContentManager::Instance();
-
-	const wxString latestVersion = contMan->GetLatestApplicationVersionAvailable();
+	std::string latestVersion = GetLatestVersion(!is_interactive);
 
 	if (latestVersion.empty()) {
-		if (show) {
-			customMessageBoxNoModal(SL_MAIN_ICON, _("There was an error checking for the latest version.\nPlease try again later.\nIf the problem persists, please use Help->Report Bug to report this bug."), _("Error"));
+		if (is_interactive) {
+			customMessageBoxModal(SL_MAIN_ICON, _(
+			  "There was an error checking for the latest version.\n"
+			  "Please try again later.\n"
+			  "If the problem persists, please use Help->Report Bug to report this bug."),
+			  _("Error"));
 		}
 		return;
 	}
 	//get current rev w/o AUX_VERSION added
-	const wxString myVersion = TowxString(getSpringlobbyVersion());
+	const std::string myVersion = GetSpringlobbyVersion();
 
-	const wxString msg = _("Your Version: ") + myVersion + _T("\n") + _("Latest Version: ") + latestVersion;
-	if (latestVersion.IsSameAs(myVersion, false)) {
-		if (show) {
-				customMessageBoxNoModal(SL_MAIN_ICON, _("Your SpringLobby version is up to date.\n\n") + msg, _("Up to Date"));
+	const wxString versionMessage = _("Your Version: ") + myVersion + '\n' + _("Latest Version: ") + latestVersion;
+	int isMyVersionOld = CompareVersionStrings(myVersion, latestVersion);
+
+	if (0 == isMyVersionOld) {
+		if (is_interactive) {
+			customMessageBoxModal(SL_MAIN_ICON, wxString::Format(
+			  _("Your %s version is up to date."), GetSpringlobbyName())
+			  + _T("\n\n") + versionMessage, _("Up to Date"));
 		}
-		return;
-	}
+	} else if (isMyVersionOld > 0) {
+		wxString message;
+		message += wxString::Format(_("Your %s version is not up to date."), GetSpringlobbyName());
+		message += wxString::Format(_T("\n\n%s\n\n"), versionMessage);
+
 #ifdef __WXMSW__
-		int answer = customMessageBox(SL_MAIN_ICON,
-					      wxString::Format(_("Your %s version is not up to date.\n\n%s\n\nWould you like to update to the new version?"),
-							       TowxString(getSpringlobbyName()).c_str(),
-							       msg.c_str()),
-					      _("Not up to date"), wxOK | wxCANCEL);
-		if (answer == wxOK) {
-			try{
-				if (!contMan->UpdateApplication()) {
-					//this will also happen if updater exe is not present so we don't really ne special check for existance of it
-					customMessageBox(SL_MAIN_ICON, _("Automatic update failed\n\nyou will be redirected to a web page with instructions and the download link will be opened in your browser.") + msg, _("Updater error."));
-					OpenWebBrowser(_T("https://github.com/springlobby/springlobby/wiki/Install#Windows_Binary"));
-					OpenWebBrowser(TowxString(GetDownloadUrl(STD_STRING(latestVersion))));
-				}
-			} catch(Exception& ex) {
-				//this will also happen if updater exe is not present so we don't really ne special check for existance of it
-				const wxString errormsg = wxString::Format(_("Automatic update failed\n\
-						%s\n\
-						you will be redirected to a web page with instructions and the download link will be opened in your browser. %s"), ex.Reason(), msg);
-				customMessageBox(SL_MAIN_ICON, errormsg, _("Updater error."));
-				OpenWebBrowser(_T("https://github.com/springlobby/springlobby/wiki/Install#Windows_Binary"));
-				OpenWebBrowser(TowxString(GetDownloadUrl(STD_STRING(latestVersion))));
-				return;
-			}
+		message += _("Would you like to update to the new version?");
+
+		const wxString heading = wxString::Format(_("Update %s?"), GetSpringlobbyName());
+		if (!Ask(heading, message))
+			return;
+		try {
+			prDownloader().UpdateApplication(GetDownloadUrl(latestVersion));
+		} catch (Exception& ex) {
+			//this will also happen if updater exe is not present so we don't really ne special check for existance of it
+			wxString errorMsg = _("Automatic update failed.") + '\n';
+			errorMsg += ex.Reason() + '\n';
+			errorMsg += versionMessage + '\n';
+			errorMsg += _("The instructions for updating manually have been opened in your web browser.");
+			customMessageBox(SL_MAIN_ICON, errorMsg, _("Updater error."));
+			OpenWebBrowser(_T("https://github.com/springlobby/springlobby/wiki/Install#Windows_Binary"));
+			OpenWebBrowser(TowxString(GetDownloadUrl(latestVersion)));
+		} catch (...) {
+			wxLogError("Unknown exception");
 		}
 #else
-		customMessageBoxNoModal(SL_MAIN_ICON, _("Your SpringLobby version is not up to date.\n\n") + msg, _("Not up to Date"));
+		message += _("Please update to the latest version before reporting bugs.");
+		customMessageBoxModal(SL_MAIN_ICON, message, _("Not up to Date"));
 #endif
+	} else {
+		if (is_interactive) {
+			wxString message;
+			message += wxString::Format(_("Your %s version is newer than the latest release."), GetSpringlobbyName());
+			message += wxString::Format(_T("\n\n%s\n\n"), versionMessage);
+			message += _("Thank you for helping with testing!");
+			customMessageBoxModal(SL_MAIN_ICON, message, _T("Much development, wow"));
+		}
+	}
 }
 
 
@@ -1005,3 +886,84 @@ void Ui::OnLoginDenied(const std::string& reason)
 	m_con_win->OnLoginDenied(TowxString(reason));
 	ServerManager::Instance()->DisconnectFromServer();
 }
+
+static bool requested(DownloadEnum::Category req, DownloadEnum::Category cat)
+{
+	if (req == cat)
+		return true;
+	if (req == DownloadEnum::CAT_NONE)
+		return true;
+	return false;
+}
+
+bool Ui::NeedsDownload(const IBattle* battle, bool uiprompt, DownloadEnum::Category cat)
+{
+	if (battle == nullptr) {
+		wxLogWarning("Battle is null, nothing required!");
+		return true;
+	}
+	bool needstuff = false;
+	std::string stodl;
+	std::list<std::pair<DownloadEnum::Category, std::string>> todl;
+
+	if (requested(cat, DownloadEnum::CAT_ENGINE) && !battle->EngineExists() && !battle->GetEngineName().empty() && !battle->GetEngineVersion().empty()) {
+		stodl.append("- engine " + battle->GetEngineName() + " " + battle->GetEngineVersion() + "\n");
+		todl.push_back(std::make_pair(DownloadEnum::CAT_ENGINE, battle->GetEngineName() + " " + battle->GetEngineVersion()));
+	}
+	if (requested(cat, DownloadEnum::CAT_MAP) && !battle->MapExists(false) && !battle->GetHostMapName().empty()) {
+		stodl.append("- map " + battle->GetHostMapName() + "\n");
+		todl.push_back(std::make_pair(DownloadEnum::CAT_MAP, battle->GetHostMapName()));
+	}
+	if (requested(cat, DownloadEnum::CAT_GAME) && !battle->GameExists(false) && !battle->GetHostGameName().empty()) {
+		stodl.append("- game " + battle->GetHostGameName() + "\n");
+		todl.push_back(std::make_pair(DownloadEnum::CAT_GAME, battle->GetHostGameName()));
+	}
+
+
+	if (!todl.empty()) {
+		needstuff = true;
+		if (uiprompt) {
+			const wxString prompt = _("Content is required to play. Should it be downloaded?") + _T("\n") + stodl;
+
+			if (!Ask(_("Content is missing"), prompt))
+				return true;
+		}
+
+		for (auto dl : todl) {
+			prDownloader().Download(dl.first, dl.second);
+		}
+	}
+
+	if (battle->GetEngineVersion().empty()) {
+		wxLogWarning("No engine version in battle set, assuming no prequesites");
+		return needstuff;
+	}
+
+	const std::string compatversion = SlPaths::GetCompatibleVersion(battle->GetEngineVersion());
+	if (compatversion == SlPaths::GetCurrentUsedSpringIndex()) {
+		return needstuff;
+	}
+	wxLogWarning("Required engine version doesn't match current selected version, switching to %s", compatversion.c_str());
+	SlPaths::SetUsedSpringIndex(compatversion);
+	LSL::usync().ReloadUnitSyncLib();
+
+	return true;
+}
+
+void Ui::OnInvalidFingerprintReceived(const std::string& fingerprint, const std::string& expected_fingerprint)
+{
+	int answer = wxCANCEL;
+	if (expected_fingerprint.empty()) {
+		answer = customMessageBox(SL_MAIN_ICON, _("The certificate by the server is unkown. Do you want to trust it? Please verify the fingerprint:\n") + TowxString(fingerprint)  , _("Unknown Certificate"), wxYES_NO | wxCANCEL);
+	} else {
+		answer = customMessageBox(SL_MAIN_ICON,
+		  wxString::Format(_("The server provided an invalid certificate! Maybe there is a MITM attack ongoing. Do you want ignore this warning?\nExpected:\n%s\nReceived:\n%s"),
+		  expected_fingerprint, fingerprint), _("Unknown Certificate"), wxYES_NO | wxCANCEL);
+	}
+	if (answer != wxYES) {
+		return;
+	}
+
+	sett().SetServerFingerprint(m_serv->GetServerName(), fingerprint);
+	sett().SaveSettings();
+}
