@@ -15,11 +15,10 @@ class ChatPanel;
 class HttpDownloaderThread;
 class wxEvtHandler;
 
-#include "utils/battleevents.h"
 #include <wx/string.h>
 #include <wx/timer.h>
+#include "downloader/prdownloader.h"
 #include "utils/mixins.h"
-
 //! @brief UI main class
 class Ui : public wxTimer, public SL::NonCopyable
 {
@@ -35,8 +34,7 @@ public:
 	ChatPanel* GetActiveChatPanel();
 	ChatPanel* GetChannelChatPanel(const wxString& channel);
 
-	bool ExecuteSayCommand(const wxString& cmd);
-	void ConsoleHelp(const wxString& topic);
+	void ConsoleHelp();
 
 	void ShowMainWindow();
 	void ShowConnectWindow();
@@ -72,8 +70,8 @@ public:
 	void OnUserOnline(User& user);
 	void OnUserOffline(User& user);
 	void OnUserStatusChanged(User& user);
-	void OnUserSaid(User& user, const wxString& message, bool me = false);
-	void OnUserSaidEx(User& user, const wxString& action, bool me = false);
+	void OnUserSaid(User& chan, User& user, const wxString& message);
+	void OnUserSaidEx(User& chan, User& user, const wxString& action);
 
 	void OnUnknownCommand(IServer& server, const wxString& command, const wxString& params);
 	void OnMotd(IServer& server, const wxString& message);
@@ -84,12 +82,11 @@ public:
 	void OnBattleClosed(IBattle& battle);
 	void OnUserJoinedBattle(IBattle& battle, User& user);
 	void OnUserLeftBattle(IBattle& battle, User& user, bool isbot);
-	void OnBattleInfoUpdated(BattleEvents::BattleEventData data);
+	void OnBattleInfoUpdated(IBattle& battle, const wxString& Tag);
 
 	void OnJoinedBattle(IBattle& battle);
 	void OnHostedBattle(IBattle& battle);
-	void OnUserBattleStatus(wxCommandEvent& event);
-	void OnRequestBattleStatus(IBattle& battle);
+	void OnUserBattleStatus(User& user);
 
 	void OnSaidBattle(IBattle& battle, const wxString& nick, const wxString& msg);
 
@@ -105,8 +102,8 @@ public:
 	void OnRegistrationDenied(const wxString& reason);
 	void OnLoginDenied(const std::string& reason);
 
-	//! ask to download missing map, return true if download attempted
-	bool OnPresetRequiringMap(const wxString& mapname);
+	// return true when engine/game/map is missing & prompts user to dl when needed
+	bool NeedsDownload(const IBattle* battle, bool uiprompt = true, DownloadEnum::Category cat = DownloadEnum::CAT_NONE);
 
 	bool IsThisMe(User& other) const;
 	bool IsThisMe(const User* other) const;
@@ -118,11 +115,12 @@ public:
 
 	//! the welcome box, should be called in all code paths directly after MainWindow might be shown for the first time
 	void FirstRunWelcome();
-	void CheckForUpdates(bool show);
+	void CheckForUpdates(bool is_interactive);
 	void EnableDebug(bool enable);
+	void OnInvalidFingerprintReceived(const std::string& fingerprint, const std::string& expected_fingerprint);
 
 private:
-	void OnDownloadComplete(wxCommandEvent& /*data*/);
+	void OnLobbyDownloaded(wxCommandEvent& /*data*/);
 	void Notify();
 
 	IServer* m_serv;
@@ -134,9 +132,6 @@ private:
 	bool m_first_update_trigger;
 	bool m_connecting;
 	int m_connect_retries;
-
-	EventReceiverFunc<Ui, BattleEvents::BattleEventData, &Ui::OnBattleInfoUpdated>
-	    m_battle_info_updatedSink;
 };
 
 Ui& ui();
