@@ -10,27 +10,27 @@ lsl/battle/ibattle.cpp
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 **/
-
-
-#include <wx/tokenzr.h>
-#include <wx/log.h>
-
-#include <algorithm>
+#include "ibattle.h"
 
 #include <lslunitsync/unitsync.h>
 #include <lslutils/globalsmanager.h>
+#include <wx/filename.h>
+#include <wx/log.h>
+#include <wx/string.h>
+#include <wx/tokenzr.h>
+#include <algorithm>
 
-#include "utils/conversion.h"
-#include "utils/lslconversion.h"
-#include "gui/uiutils.h"
 #include "gui/ui.h"
-#include "ibattle.h"
+#include "gui/uiutils.h"
 #include "iserver.h"
+#include "log.h"
+#include "serverselector.h"
 #include "settings.h"
 #include "spring.h"
 #include "springlobbyapp.h"
-#include "serverselector.h"
-#include "log.h"
+#include "utils/conversion.h"
+#include "utils/lslconversion.h"
+#include "utils/slpaths.h"
 
 #define MAX_TEAMS 255
 
@@ -66,19 +66,19 @@ bool IBattle::IsSynced()
 	LoadGame();
 	LoadMap();
 	if (!m_host_game.name.empty() && m_local_game.name != m_host_game.name) {
-		wxLogWarning("Not synced: game name doesn't match: '%s' '%s'", m_host_game.name.c_str(), m_local_game.name.c_str());
+		wxLogWarning("Not synced: game name doesn't match host:'%s' local:'%s'", m_host_game.name.c_str(), m_local_game.name.c_str());
 		return false;
 	}
 	if (!m_host_map.name.empty() && m_local_map.name != m_host_map.name) {
-		wxLogWarning("Not synced: map name doesn't match: '%s' '%s'", m_host_map.name.c_str(), m_local_map.name.c_str());
+		wxLogWarning("Not synced: map name doesn't match host:'%s' local:'%s'", m_host_map.name.c_str(), m_local_map.name.c_str());
 		return false;
 	}
 	if (!m_host_game.hash.empty() && m_host_game.hash != "0" && m_host_game.hash != m_local_game.hash) {
-		wxLogWarning("Not synced: game hash doesn't match: '%s' '%s'", m_host_game.hash.c_str(), m_local_game.hash.c_str());
+		wxLogWarning("Not synced: game hash doesn't match host:'%s' local:'%s'", m_host_game.hash.c_str(), m_local_game.hash.c_str());
 		return false;
 	}
 	if (!m_host_map.hash.empty() && m_host_map.hash != "0" && m_host_map.hash != m_local_map.hash) {
-		wxLogWarning("Not synced: map hash doesn't match: '%s' '%s'", m_host_map.hash.c_str(), m_local_map.hash.c_str());
+		wxLogWarning("Not synced: map hash doesn't match host:'%s' local:'%s'", m_host_map.hash.c_str(), m_local_map.hash.c_str());
 		return false;
 	}
 	if (!GameExists()) {
@@ -92,7 +92,7 @@ bool IBattle::IsSynced()
 	return true;
 }
 
-std::vector<LSL::lslColor>& IBattle::GetFixColoursPalette(int numteams) const
+const std::vector<LSL::lslColor>& IBattle::GetFixColoursPalette(int numteams) const
 {
 	return GetBigFixColoursPalette(numteams);
 }
@@ -100,20 +100,10 @@ std::vector<LSL::lslColor>& IBattle::GetFixColoursPalette(int numteams) const
 LSL::lslColor IBattle::GetFixColour(int i) const
 {
 	int size = m_teams_sizes.size();
-	std::vector<LSL::lslColor> palette = GetFixColoursPalette(size);
+	const std::vector<LSL::lslColor>& palette = GetFixColoursPalette(size);
 	return palette[i];
 }
 
-int IBattle::GetPlayerNum(const User& user) const
-{
-	for (user_map_t::size_type i = 0; i < GetNumUsers(); i++) {
-		if (&GetUser(i) == &user)
-			return i;
-	}
-	ASSERT_EXCEPTION(false, _T("The player is not in this game."));
-	return -1;
-}
-
 class DismissColor
 {
 private:
@@ -162,7 +152,7 @@ LSL::lslColor IBattle::GetFreeColour(User*) const
 
 	int inc = 1;
 	while (true) {
-		ColorVec fixcolourspalette = GetFixColoursPalette(m_teams_sizes.size() + inc++);
+		ColorVec fixcolourspalette (GetFixColoursPalette(m_teams_sizes.size() + inc++));
 
 		ColorVec::iterator fixcolourspalette_new_end = std::unique(fixcolourspalette.begin(), fixcolourspalette.end(), AreColoursSimilarProxy(20));
 
@@ -212,7 +202,7 @@ int IBattle::GetFreeTeam(bool excludeme) const
 
 int IBattle::GetClosestFixColour(const LSL::lslColor& col, const std::vector<int>& excludes, int difference) const
 {
-	std::vector<LSL::lslColor> palette = GetFixColoursPalette(m_teams_sizes.size() + 1);
+	const std::vector<LSL::lslColor>& palette = GetFixColoursPalette(m_teams_sizes.size() + 1);
 	int result = 0;
 	int t1 = palette.size();
 	int t2 = excludes.size();
@@ -305,16 +295,16 @@ void IBattle::OnUserBattleStatusUpdated(User& user, UserBattleStatus status)
 		UserBattleStatus& loopstatus = loopuser.BattleStatus();
 		if (loopstatus.spectator)
 			m_opts.spectators++;
-		if (!loopstatus.IsBot()) {
-			if (!loopstatus.spectator) {
+		else  {
+			PlayerJoinedTeam(loopstatus.team);
+			PlayerJoinedAlly(loopstatus.ally);
+			if (!loopstatus.IsBot()) {
 				if (loopstatus.ready && loopstatus.spectator)
 					m_players_ready++;
 				if (loopstatus.sync)
 					m_players_sync++;
 				if (loopstatus.ready && loopstatus.sync)
 					m_players_ok++;
-				PlayerJoinedTeam(loopstatus.team);
-				PlayerJoinedAlly(loopstatus.ally);
 			}
 		}
 	}
@@ -405,7 +395,7 @@ bool IBattle::IsEveryoneReady() const
 
 void IBattle::AddStartRect(unsigned int allyno, unsigned int left, unsigned int top, unsigned int right, unsigned int bottom)
 {
-	assert(allyno<MAX_TEAMS);
+	assert(allyno < MAX_TEAMS);
 
 	BattleStartRect sr;
 
@@ -425,35 +415,29 @@ void IBattle::AddStartRect(unsigned int allyno, unsigned int left, unsigned int
 
 void IBattle::RemoveStartRect(unsigned int allyno)
 {
-	assert(allyno<MAX_TEAMS);
+	assert(allyno < MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
 
 	rect_it->second.todelete = true;
-	//BattleStartRect sr = m_rects[allyno];
-	//sr.todelete = true;
-	//m_rects[allyno] = sr;
 }
 
 
 void IBattle::ResizeStartRect(unsigned int allyno)
 {
-	assert(allyno<MAX_TEAMS);
+	assert(allyno < MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
 
 	rect_it->second.toresize = true;
-	//BattleStartRect sr = m_rects[allyno];
-	//&&sr.toresize = true;
-	//m_rects[allyno] = sr;
 }
 
 
 void IBattle::StartRectRemoved(unsigned int allyno)
 {
-	assert(allyno<MAX_TEAMS);
+	assert(allyno < MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::const_iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
@@ -465,35 +449,29 @@ void IBattle::StartRectRemoved(unsigned int allyno)
 
 void IBattle::StartRectResized(unsigned int allyno)
 {
-	assert(allyno<MAX_TEAMS);
+	assert(allyno < MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
 
 	rect_it->second.toresize = false;
-	//BattleStartRect sr = m_rects[allyno];
-	//sr.toresize = false;
-	//m_rects[allyno] = sr;
 }
 
 
 void IBattle::StartRectAdded(unsigned int allyno)
 {
-	assert(allyno<MAX_TEAMS);
+	assert(allyno < MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::iterator rect_it = m_rects.find(allyno);
 	if (rect_it == m_rects.end())
 		return;
 
 	rect_it->second.toadd = false;
-	//BattleStartRect sr = m_rects[allyno];
-	//sr.toadd = false;
-	//m_rects[allyno] = sr;
 }
 
 
 BattleStartRect IBattle::GetStartRect(unsigned int allyno) const
 {
-	assert(allyno<MAX_TEAMS);
+	assert(allyno < MAX_TEAMS);
 	std::map<unsigned int, BattleStartRect>::const_iterator rect_it = m_rects.find(allyno);
 	if (rect_it != m_rects.end())
 		return (*rect_it).second;
@@ -521,17 +499,14 @@ unsigned int IBattle::GetLastRectIdx() const
 //return  the lowest currently unused key in the map of rects.
 unsigned int IBattle::GetNextFreeRectIdx() const
 {
-	const size_t num = GetNumRects();
-	if (num == 0) //rects start at 1
-		return 1;
 	//check for unused allyno keys
-	for (unsigned int i = 1; i <= GetLastRectIdx(); i++) {
+	for (unsigned int i = 0; i <= GetNumRects(); i++) {
 		if (!GetStartRect(i).IsOk()) {
-			assert(i<MAX_TEAMS);
+			assert(i < MAX_TEAMS);
 			return i;
 		}
 	}
-	return num;//if all rects are in use, or no elements exist, return first possible available allyno.
+	return 1; //rects start at 1
 }
 
 void IBattle::ClearStartRects()
@@ -718,18 +693,19 @@ UserPosition IBattle::GetFreePosition()
 void IBattle::SetHostMap(const std::string& mapname, const std::string& hash)
 {
 	assert(hash.empty() || LSL::Util::MakeHashUnsigned(hash) == hash);
-	ASSERT_LOGIC(!mapname.empty(), "Battle with empty map name!");
-	if (mapname != m_host_map.name || hash != m_host_map.hash) {
-		m_map_loaded = false;
-		m_host_map.name = mapname;
-		m_host_map.hash = hash;
-	}
+	m_map_loaded = mapname.empty();
+	m_host_map.name = mapname;
+	m_host_map.hash = hash;
 }
 
 
 void IBattle::SetLocalMap(const std::string& mapname)
 {
-	ASSERT_LOGIC(!mapname.empty(), "Battle with empty map name!");
+	if (mapname.empty()) {
+		wxLogWarning("Battle with empty map name!");
+		return;
+	}
+
 	LSL::UnitsyncMap map = LSL::usync().GetMap(mapname);
 	if (map.name != m_local_map.name || map.hash != m_local_map.hash) {
 		m_local_map = map;
@@ -743,30 +719,27 @@ void IBattle::SetLocalMap(const std::string& mapname)
 
 const LSL::UnitsyncMap& IBattle::LoadMap()
 {
-	if ((!m_map_loaded) && (!m_host_map.name.empty())) {
-		if (MapExists(true)) { //Check if selected map available for engine?
-			try {
-				m_local_map = LSL::usync().GetMap(m_host_map.name);
-				assert(LSL::Util::MakeHashUnsigned(m_local_map.hash) == m_local_map.hash);
-				bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::MapOption, m_host_map.name);
-				//TODO: maybe replace this with "silent" IF operator?
-				ASSERT_EXCEPTION(options_loaded, _T("couldn't load the map options"));
-				m_map_loaded = true;
-			} catch (...) {
-			}
-		}
+	if ((m_map_loaded) || (m_host_map.name.empty()) || !MapExists(true))
+		return m_local_map;
+
+	m_local_map = LSL::usync().GetMap(m_host_map.name);
+	assert(LSL::Util::MakeHashUnsigned(m_local_map.hash) == m_local_map.hash);
+	const bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::MapOption, m_host_map.name);
+	if (!options_loaded) {
+		wxLogWarning( _T("couldn't load the map options"));
 	}
+	m_map_loaded = true;
 	return m_local_map;
 }
 
 
-std::string IBattle::GetHostMapName() const
+const std::string& IBattle::GetHostMapName() const
 {
 	return m_host_map.name;
 }
 
 
-std::string IBattle::GetHostMapHash() const
+const std::string& IBattle::GetHostMapHash() const
 {
 	return m_host_map.hash;
 }
@@ -775,11 +748,12 @@ std::string IBattle::GetHostMapHash() const
 void IBattle::SetHostGame(const std::string& gamename, const std::string& hash)
 {
 	assert(hash.empty() || LSL::Util::MakeHashUnsigned(hash) == hash);
-	if (m_host_game.name != gamename || m_host_game.hash != hash) {
-		m_game_loaded = false;
-		m_host_game.name = gamename;
-		m_host_game.hash = hash;
+	if ((m_host_game.name == gamename) && (m_host_game.hash == hash)) {
+		return;
 	}
+	m_game_loaded = gamename.empty();
+	m_host_game.name = gamename;
+	m_host_game.hash = hash;
 }
 
 
@@ -789,39 +763,43 @@ void IBattle::SetLocalGame(const LSL::UnitsyncGame& mod)
 	if (mod.hash.empty()) {
 		wxLogWarning("empty hash: %s", mod.name);
 	}
-	if (mod.name != m_local_game.name || mod.hash != m_local_game.hash) {
-		m_previous_local_game_name = m_local_game.name;
-		m_local_game = mod;
-		m_game_loaded = true;
+	if ((mod.name == m_local_game.name) && (mod.hash == m_local_game.hash)) {
+		return;
 	}
+	m_previous_local_game_name = m_local_game.name;
+	m_local_game = mod;
+	m_game_loaded = true;
 }
 
 
 const LSL::UnitsyncGame& IBattle::LoadGame()
 {
-	ASSERT_LOGIC(!m_host_game.name.empty(), "m_host_game.name.empty() is FALSE");
-	if (!m_game_loaded) {
-		if (GameExists(true)) {
-			try {
-				SetLocalGame(LSL::usync().GetGame(m_host_game.name));
-				bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::ModOption, m_host_game.name);
-				ASSERT_EXCEPTION(options_loaded, _T("couldn't load the game options"));
-				m_game_loaded = true;
-			} catch (...) {
-			}
-		}
+	if (m_game_loaded || m_host_game.name.empty()) {
+		return m_local_game;
 	}
+	if (!GameExists(true)) {
+		wxLogWarning("Game doesn't exist");
+		return m_local_game;
+	}
+	SetLocalGame(LSL::usync().GetGame(m_host_game.name));
+	const bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::ModOption, m_host_game.name);
+
+	if (!options_loaded) {
+		wxLogWarning("couldn't load the game options");
+	}
+
+	m_game_loaded = true;
 	return m_local_game;
 }
 
 
-std::string IBattle::GetHostGameName() const
+const std::string& IBattle::GetHostGameName() const
 {
 	return m_host_game.name;
 }
 
 
-std::string IBattle::GetHostGameHash() const
+const std::string& IBattle::GetHostGameHash() const
 {
 	return m_host_game.hash;
 }
@@ -829,6 +807,9 @@ std::string IBattle::GetHostGameHash() const
 
 bool IBattle::MapExists(bool comparehash) const
 {
+	if (m_host_map.name.empty()) {
+		return false;
+	}
 	if (comparehash) {
 		return LSL::usync().MapExists(m_host_map.name, m_host_map.hash);
 	}
@@ -864,7 +845,7 @@ void IBattle::UnrestrictAllUnits()
 }
 
 
-std::map<std::string, int> IBattle::RestrictedUnits() const
+const std::map<std::string, int>& IBattle::GetRestrictedUnits() const
 {
 	return m_restricted_units;
 }
@@ -921,13 +902,9 @@ bool IBattle::LoadOptionsPreset(const std::string& name)
 			}
 		} else {
 			if (!options[_T("mapname")].IsEmpty()) {
-				if (LSL::usync().MapExists(STD_STRING(options[_T("mapname")]))) {
+				if (!ui().NeedsDownload(this)) {
 					SetLocalMap(STD_STRING(options[_T("mapname")]));
 					SendHostInfo(HI_Map);
-				} else if (!ui().OnPresetRequiringMap(options[_T("mapname")])) {
-					//user didn't want to download the missing map, so set to empty to not have it tried to be loaded again
-					options[_T("mapname")] = wxEmptyString;
-					sett().SetHostingPreset(TowxString(m_preset), i, options);
 				}
 			}
 
@@ -953,7 +930,6 @@ bool IBattle::LoadOptionsPreset(const std::string& name)
 				RestrictUnit(STD_STRING(unitinfo.BeforeLast(_T('='))), FromwxString(unitinfo.AfterLast(_T('='))));
 			}
 			SendHostInfo(HI_Restrictions);
-			Update(stdprintf("%d_restrictions", LSL::Enum::PrivateOptions));
 		}
 	}
 	SendHostInfo(HI_Send_All_opts);
@@ -1010,7 +986,7 @@ void IBattle::SaveOptionsPreset(const std::string& name)
 }
 
 
-std::string IBattle::GetCurrentPreset()
+const std::string& IBattle::GetCurrentPreset() const
 {
 	return m_preset;
 }
@@ -1034,6 +1010,13 @@ void IBattle::UserPositionChanged(const User& /*unused*/)
 {
 }
 
+void IBattle::SetPlayBackFilePath(const std::string& path)
+{
+	m_playback_file_path = path;
+	// I don't see any easier way of dealing with unicode.
+	m_playback_file_name = TowxString(path).AfterLast(wxFileName::GetPathSeparator());
+}
+
 void IBattle::AddUserFromDemo(User& user)
 {
 	user.BattleStatus().isfromdemo = true;
@@ -1051,7 +1034,7 @@ bool IBattle::IsProxy() const
 	return !m_opts.proxyhost.empty();
 }
 
-std::string IBattle::GetProxy() const
+const std::string& IBattle::GetProxy() const
 {
 	return m_opts.proxyhost;
 }
@@ -1073,12 +1056,6 @@ bool IBattle::IsFounder(const User& user) const
 		return false;
 }
 
-int IBattle::GetMyPlayerNum() const
-{
-	return GetPlayerNum(GetMe());
-}
-
-
 void IBattle::LoadScriptMMOpts(const std::string& sectionname, const LSL::TDF::PDataList& node)
 {
 	if (!node.ok())
@@ -1298,3 +1275,8 @@ void IBattle::RemoveUnfittingBots()
 		}
 	}
 }
+
+bool IBattle::EngineExists() const
+{
+	return !SlPaths::GetCompatibleVersion(GetEngineVersion()).empty();
+}
