@@ -4,6 +4,8 @@
 // Class: ServerEvents
 //
 
+#include "serverevents.h"
+
 #ifdef _MSC_VER
 #ifndef NOMINMAX
 #define NOMINMAX
@@ -11,34 +13,34 @@
 #include <winsock2.h>
 #endif // _MSC_VER
 
+#include <lslutils/globalsmanager.h>
 #include <wx/intl.h>
 #include <wx/log.h>
+#include <exception>
+#include <locale>
+#include <sstream>
 #include <stdexcept>
 
-#include "serverevents.h"
+#include "autohost.h"
+#include "autohostmanager.h"
+#include "channel.h"
+#include "gui/customdialogs.h"
 #include "gui/mainwindow.h"
 #include "gui/ui.h"
-#include "channel.h"
-#include "user.h"
 #include "gui/uiutils.h"
 #include "iserver.h"
+#include "log.h"
+#include "servermanager.h"
 #include "settings.h"
-#include "gui/customdialogs.h"
+#include "user.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
 #include "utils/tasutil.h"
 #include "utils/uievents.h"
-#include "log.h"
-#include "utils/conversion.h"
-#include "autohostmanager.h"
-#include "autohost.h"
-#include "utils/globalevents.h"
-#include "servermanager.h"
-
-#include <lslutils/globalsmanager.h>
-#include <exception>
 
 void ServerEvents::OnConnected(const std::string& server_name, const std::string& server_ver, bool supported, const std::string& server_spring_ver, bool /*unused*/)
 {
-	slLogDebugFunc("%s %s", server_ver.c_str(), server_spring_ver.c_str());
+	wxLogInfo("Connected to %s %s %s",m_serv.m_serverinfo.hostname.c_str(),  server_ver.c_str(), server_spring_ver.c_str());
 	//Server version will include patchlevel from release 89 onwards
 	m_serv.SetRequiredSpring(LSL::Util::BeforeFirst(server_spring_ver, "."));
 	ui().OnConnected(m_serv, TowxString(server_name), TowxString(server_spring_ver), supported);
@@ -48,7 +50,7 @@ void ServerEvents::OnConnected(const std::string& server_name, const std::string
 
 void ServerEvents::OnDisconnected(bool wasonline)
 {
-	slLogDebugFunc("");
+	wxLogInfo("Disconnected from server: %s %d", m_serv.m_serverinfo.hostname.c_str(), wasonline);
 	m_serv.SetRequiredSpring("");
 	try {
 		ui().OnDisconnected(m_serv, wasonline);
@@ -126,9 +128,8 @@ void ServerEvents::OnPong(wxLongLong ping_time)
 void ServerEvents::OnNewUser(const std::string& nick, const std::string& country, int cpu, int id)
 {
 	slLogDebugFunc("");
-	try {
-		ASSERT_LOGIC(!m_serv.UserExists(nick), ("New user from server, but already exists!"));
-	} catch (...) {
+	if (m_serv.UserExists(nick)) {
+		wxLogWarning("New user from server, but already exists: %s", nick.c_str());
 		return;
 	}
 	User& user = m_serv._AddUser(nick);
@@ -139,6 +140,10 @@ void ServerEvents::OnNewUser(const std::string& nick, const std::string& country
 		return;
 	}
 	ui().OnUserOnline(user);
+
+	if (useractions().DoActionOnUser(UserActions::ActNotifLogin, TowxString(nick))) {
+		actNotifBox(SL_MAIN_ICON, TowxString(nick) + _(" just connected"));
+	}
 }
 
 
@@ -170,7 +175,7 @@ void ServerEvents::OnUserStatus(const std::string& nick, UserStatus status)
 							if (status.in_game) {
 								battle.StartSpring();
 							} else {
-								BattleEvents::GetBattleEventSender(BattleEvents::BattleInfoUpdate).SendEvent(std::make_pair(user.GetBattle(), ""));
+								ui().OnBattleInfoUpdated(battle, wxEmptyString);
 							}
 						}
 					}
@@ -326,6 +331,7 @@ void ServerEvents::OnClientBattleStatus(int battleid, const std::string& nick, U
 
 		status.color_index = user.BattleStatus().color_index;
 		battle.OnUserBattleStatusUpdated(user, status);
+		ui().OnUserBattleStatus(user);
 	} catch (std::runtime_error& except) {
 	}
 }
@@ -375,7 +381,7 @@ void ServerEvents::OnUserLeftBattle(int battleid, const std::string& nick)
 }
 
 
-void ServerEvents::OnBattleInfoUpdated(int battleid, int spectators, bool locked, const std::string& maphash, const std::string& map)
+void ServerEvents::OnBattleInfoUpdated(int battleid, int spectators, bool locked, const std::string& mapHash, const std::string& mapName)
 {
 	slLogDebugFunc("");
 	try {
@@ -384,37 +390,52 @@ void ServerEvents::OnBattleInfoUpdated(int battleid, int spectators, bool locked
 		battle.SetSpectators(spectators);
 		battle.SetIsLocked(locked);
 
-		const std::string oldmap = battle.GetHostMapName();
-
-		battle.SetHostMap(map, maphash);
-
-		if ((oldmap != map) && (battle.UserExists(m_serv.GetMe().GetNick()))) {
-			battle.SendMyBattleStatus();
-			battle.CustomBattleOptions().loadOptions(LSL::Enum::MapOption, map);
-			battle.Update(stdprintf("%d_mapname", LSL::Enum::PrivateOptions));
+		const std::string& oldMapName = battle.GetHostMapName();
+		if (oldMapName != mapName) {
+			battle.SetHostMap(mapName, mapHash);
+			if (battle.UserExists(m_serv.GetMe().GetNick())) {
+				battle.SendMyBattleStatus();
+				battle.CustomBattleOptions().loadOptions(LSL::Enum::MapOption, mapName);
+			}
 		}
 
-		BattleEvents::GetBattleEventSender(BattleEvents::BattleInfoUpdate).SendEvent(std::make_pair(&battle, ""));
+		ui().OnBattleInfoUpdated(battle, wxEmptyString);
 	} catch (assert_exception) {
+		wxLogWarning("Exception in OnBattleInfoUpdated");
 	}
 }
 
+bool IsCrap(char c)
+{
+	switch (c) {
+		case '~':
+		case '(':
+		case ')':
+		case '#':
+			return true;
+		default:
+			return false;
+	}
+}
+
+/*
+parse TrueSkill values to a float:
+https://springrts.com/phpbb/viewtopic.php?f=88&p=574686
+FIXME: move to LSL
+*/
 static bool parseSkill(const std::string& value, double& result)
 {
-	int res = sscanf(value.c_str(), "%lf", &result);
-	if (res == 1)
-		return true;
+	if (value == "-")
+		return false;
 
-	res = sscanf(value.c_str(), "~%lf", &result);
-	if (res == 1)
-		return true;
-
-	res = sscanf(value.c_str(), "(%lf)", &result);
-	if (res == 1)
-		return true;
-
-	wxLogWarning("Invalid value for skill received: %s", value.c_str());
-	return false;
+	std::string str = value;
+	str.erase(std::remove_if(str.begin(), str.end(), &IsCrap), str.end());
+	std::istringstream istr(str);
+	istr.imbue(std::locale("C"));
+	double res = -1.0f;
+	istr >> res;
+	result = res;
+	return res != -1.0f;
 }
 
 static bool parseTeam(const std::string& value, int& result)
@@ -433,13 +454,15 @@ void ServerEvents::OnSetBattleInfo(int battleid, const std::string& param, const
 	switch (vec.size()) {
 		case 3: { // depth 3
 			if (param.find("game/mapoptions") == 0) {
-				battle.CustomBattleOptions().setSingleOption(vec[2], value, LSL::Enum::MapOption);
-				battle.Update(stdprintf("%d_%s", LSL::Enum::MapOption, vec[2].c_str()));
+				if (!battle.CustomBattleOptions().setSingleOption(vec[2], value, LSL::Enum::MapOption)) {
+					wxLogWarning("OnSetBattleInfo: Couldn't set map option %s", vec[2].c_str());
+				}
 				return;
 			}
 			if (param.find("game/modoptions/") == 0) {
-				battle.CustomBattleOptions().setSingleOption(vec[2], value, LSL::Enum::ModOption);
-				battle.Update(stdprintf("%d_%s", LSL::Enum::ModOption, vec[2].c_str()));
+				if (!battle.CustomBattleOptions().setSingleOption(vec[2], value, LSL::Enum::ModOption)) {
+					wxLogWarning("OnSetBattleInfo: Couldn't set game option %s", vec[2].c_str());
+				}
 				return;
 			}
 			if (param.find("game/restrict") == 0) {
@@ -464,6 +487,7 @@ void ServerEvents::OnSetBattleInfo(int battleid, const std::string& param, const
 									status.pos.y = LSL::Util::FromIntString(value);
 								}
 								battle.OnUserBattleStatusUpdated(usr, status);
+								ui().OnUserBattleStatus(usr);
 							}
 						}
 						return;
@@ -490,6 +514,10 @@ void ServerEvents::OnSetBattleInfo(int battleid, const std::string& param, const
 		}
 		case 2: { //depth 2
 			if (param == "game/hosttype") {
+				if (battle.m_autohost_manager == nullptr) {
+					wxLogWarning("FIXME: battle.m_autohost_manager == nullptr");
+					return;
+				}
 				if (battle.m_autohost_manager->RecognizeAutohost(value)) {
 					wxLogInfo("detected %s autohost", value.c_str()); //FIXME: add event for that + add a label?!
 				}
@@ -497,7 +525,6 @@ void ServerEvents::OnSetBattleInfo(int battleid, const std::string& param, const
 			}
 			// i.e. game/startpostype
 			battle.CustomBattleOptions().setSingleOption(vec[1], value, LSL::Enum::EngineOption);
-			battle.Update(stdprintf("%d_%s", LSL::Enum::EngineOption, vec[1].c_str()));
 			return;
 		}
 			/*
@@ -523,8 +550,9 @@ void ServerEvents::OnBattleInfoUpdated(int battleid)
 	slLogDebugFunc("");
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
-		BattleEvents::GetBattleEventSender(BattleEvents::BattleInfoUpdate).SendEvent(std::make_pair(&battle, ""));
+		ui().OnBattleInfoUpdated(battle, wxEmptyString);
 	} catch (assert_exception) {
+		wxLogWarning("Exception in OnBattleInfoUpdated(%d)", battleid);
 	}
 }
 
@@ -532,14 +560,13 @@ void ServerEvents::OnBattleInfoUpdated(int battleid)
 void ServerEvents::OnBattleClosed(int battleid)
 {
 	slLogDebugFunc("");
-	try {
-		IBattle& battle = m_serv.GetBattle(battleid);
-
-		ui().OnBattleClosed(battle);
-
-		m_serv._RemoveBattle(battleid);
-	} catch (assert_exception) {
+	if (!m_serv.BattleExists(battleid)) {
+		wxLogWarning("Tried to close non-existing battle %d", battleid);
+		return;
 	}
+	IBattle& battle = m_serv.GetBattle(battleid);
+	ui().OnBattleClosed(battle);
+	m_serv._RemoveBattle(battleid);
 }
 
 
@@ -549,7 +576,7 @@ void ServerEvents::OnBattleDisableUnit(int battleid, const std::string& unitname
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.RestrictUnit(unitname, count);
-		battle.Update(stdprintf("%d_restrictions", LSL::Enum::PrivateOptions));
+		wxLogDebug("OnBattleDisableUnit %d %s %d", battleid, unitname.c_str(), count);
 	} catch (assert_exception) {
 	}
 }
@@ -561,7 +588,6 @@ void ServerEvents::OnBattleEnableUnit(int battleid, const std::string& unitname)
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.UnrestrictUnit(unitname);
-		battle.Update(stdprintf("%d_restrictions", LSL::Enum::PrivateOptions));
 	} catch (assert_exception) {
 	}
 }
@@ -573,7 +599,6 @@ void ServerEvents::OnBattleEnableAllUnits(int battleid)
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.UnrestrictAllUnits();
-		battle.Update(stdprintf("%d_restrictions", LSL::Enum::PrivateOptions));
 	} catch (assert_exception) {
 	}
 }
@@ -651,24 +676,22 @@ void ServerEvents::OnChannelAction(const std::string& channel, const std::string
 }
 
 
-void ServerEvents::OnPrivateMessage(const std::string& user, const std::string& message, bool fromme)
+void ServerEvents::OnPrivateMessage(User& chan, User& who, const std::string& message)
 {
 	slLogDebugFunc("");
 	try {
-		User& who = m_serv.GetUser(user);
 		if (!useractions().DoActionOnUser(UserActions::ActIgnorePM, TowxString(who.GetNick())))
-			ui().OnUserSaid(who, TowxString(message), fromme);
+			ui().OnUserSaid(chan, who, TowxString(message));
 	} catch (std::runtime_error& except) {
 	}
 }
 
-void ServerEvents::OnPrivateMessageEx(const std::string& user, const std::string& action, bool fromme)
+void ServerEvents::OnPrivateMessageEx(User& chan, User& who, const std::string& action)
 {
 	slLogDebugFunc("");
 	try {
-		User& who = m_serv.GetUser(user);
 		if (!useractions().DoActionOnUser(UserActions::ActIgnorePM, TowxString(who.GetNick())))
-			ui().OnUserSaidEx(who, TowxString(action), fromme);
+			ui().OnUserSaidEx(chan, who, TowxString(action));
 	} catch (std::runtime_error& except) {
 	}
 }
@@ -693,7 +716,7 @@ void ServerEvents::OnRequestBattleStatus(int battleid)
 {
 	try {
 		IBattle& battle = m_serv.GetBattle(battleid);
-		ui().OnRequestBattleStatus(battle);
+		battle.OnRequestBattleStatus();
 	} catch (assert_exception) {
 	}
 }
@@ -730,7 +753,6 @@ void ServerEvents::OnBattleStartRectAdd(int battleid, int allyno, int left, int
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.AddStartRect(allyno, left, top, right, bottom);
 		battle.StartRectAdded(allyno);
-		battle.Update(stdprintf("%d_mapname", LSL::Enum::PrivateOptions));
 	} catch (assert_exception) {
 	}
 }
@@ -742,7 +764,6 @@ void ServerEvents::OnBattleStartRectRemove(int battleid, int allyno)
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.RemoveStartRect(allyno);
 		battle.StartRectRemoved(allyno);
-		battle.Update(stdprintf("%d_mapname", LSL::Enum::PrivateOptions));
 	} catch (assert_exception) {
 	}
 }
@@ -755,7 +776,6 @@ void ServerEvents::OnBattleAddBot(int battleid, const std::string& nick, UserBat
 		IBattle& battle = m_serv.GetBattle(battleid);
 		battle.OnBotAdded(nick, status);
 		User& bot = battle.GetUser(nick);
-		ASSERT_LOGIC(&bot != 0, "Bot null after add.");
 		ui().OnUserJoinedBattle(battle, bot);
 	} catch (assert_exception) {
 	}
@@ -794,17 +814,20 @@ void ServerEvents::OnRing(const std::string& from)
 
 void ServerEvents::OnServerBroadcast(const std::string& message)
 {
+	wxLogWarning("%s", message);
 	ui().OnServerBroadcast(m_serv, TowxString(message));
 }
 
 void ServerEvents::OnServerMessage(const std::string& message)
 {
+	wxLogWarning("%s", message);
 	ui().OnServerMessage(m_serv, TowxString(message));
 }
 
 
 void ServerEvents::OnServerMessageBox(const std::string& message)
 {
+	wxLogWarning("%s", message);
 	ui().ShowMessage(_("Server Message"), TowxString(message));
 }
 
@@ -873,16 +896,16 @@ void ServerEvents::OnClientIPPort(const std::string& username, const std::string
 
 void ServerEvents::OnKickedFromBattle()
 {
-	customMessageBoxNoModal(SL_MAIN_ICON, _("You were kicked from the battle!"), _("Kicked by Host"));
+	customMessageBoxModal(SL_MAIN_ICON, _("You were kicked from the battle!"), _("Kicked by Host"));
 }
 
 
 void ServerEvents::OnRedirect(const std::string& address, unsigned int port, const std::string& CurrentNick, const std::string& CurrentPassword)
 {
-	const wxString name = TowxString(address) + _T(":") + TowxString(port);
-	sett().SetServer(name, TowxString(address), port);
+	const std::string name = stdprintf("%s:%d", address.c_str(), port);
+	sett().SetServer(name, TowxString(address), port, "");
 	//TODO: Rework this. Server calls it`s own method through another object!
-	ServerManager::Instance()->DoConnectToServer(name, TowxString(CurrentNick), TowxString(CurrentPassword));
+	ServerManager::Instance()->DoConnectToServer(name, CurrentNick, CurrentPassword);
 }
 
 
@@ -905,14 +928,14 @@ void ServerEvents::AutoCheckCommandSpam(IBattle& battle, User& user)
 
 void ServerEvents::OnMutelistBegin(const std::string& channel)
 {
-	mutelistWindow(_("Begin mutelist for ") + TowxString(channel), wxString::Format(_("%s mutelist"), channel.c_str()));
+	mutelistWindow(wxString::Format(_("Begin mutelist for channel %s"), channel.c_str()), wxString::Format(_("%s mutelist"), channel.c_str()));
 }
 
 void ServerEvents::OnMutelistItem(const std::string& /*unused*/, const std::string& mutee, const std::string& description)
 {
 	wxString message = TowxString(mutee);
 	wxString desc = TowxString(description);
-	wxString mutetime = TowxString(GetWordParam(desc));
+	wxString mutetime = desc.AfterFirst(wxChar(' '));
 	long time;
 	if (mutetime == _T("indefinite"))
 		message << _(" indefinite time remaining");
@@ -979,3 +1002,10 @@ void ServerEvents::OnLoginDenied(const std::string& reason)
 {
 	ui().OnLoginDenied(reason);
 }
+
+void ServerEvents::OnInvalidFingerprintReceived(const std::string& fingerprint, const std::string& expected_fingerprint)
+{
+	ui().OnInvalidFingerprintReceived(fingerprint, expected_fingerprint);
+}
+
+
