@@ -88,8 +88,8 @@ public:
 	void OnChannelList(const std::string& channel, const int& numusers, const std::string& topic);
 	void OnUserJoinChannel(const std::string& channel, const std::string& who);
 
-	void OnPrivateMessage(const std::string& user, const std::string& message, bool fromme = false);
-	void OnPrivateMessageEx(const std::string& user, const std::string& action, bool fromme = false);
+	void OnPrivateMessage(User& chan, User& who, const std::string& message);
+	void OnPrivateMessageEx(User& chan, User& who, const std::string& action);
 
 	void OnRequestBattleStatus(int battleid);
 	void OnSaidBattle(int battleid, const std::string& nick, const std::string& msg);
@@ -130,6 +130,7 @@ public:
 	void RegistrationAccepted(const std::string& user, const std::string& pass);
 	void RegistrationDenied(const std::string& reason);
 	void OnLoginDenied(const std::string& reason);
+	void OnInvalidFingerprintReceived(const std::string& fingerprint, const std::string& expected_fingerprint);
 
 private:
 	IServer& m_serv;
