@@ -12,15 +12,12 @@
 #include "useractions.h"
 #include "utils/sortutil.h"
 
-const long CACHE_VERSION = 14;
-const long SETTINGS_VERSION = 31;
-
 
 const wxString DEFSETT_DEFAULT_SERVER_NAME = _T("Official server");
 const wxString DEFSETT_DEFAULT_SERVER_HOST = _T("lobby.springrts.com");
 const wxString BattlePostfix = _T("_battle");
 const int DEFSETT_DEFAULT_SERVER_PORT = 8200;
-const bool DEFSETT_SAVE_PASSWORD = false;
+const bool DEFSETT_SAVE_PASSWORD = true;
 const unsigned int DEFSETT_SPRING_PORT = 8452;
 
 const long SET_MODE_EXPERT = 5000;
@@ -172,10 +169,14 @@ public:
 
 	wxArrayString GetServers();
 	bool ServerExists(const wxString& server_name);
-	void SetServer(const wxString& server_name, const wxString& url, int port);
+	void SetServer(const wxString& server_name, const wxString& url, int port, const wxString& fingerprint);
 	void DeleteServer(const wxString& server_name);
 
 	bool ShouldAddDefaultServerSettings();
+
+	std::string GetServerFingerprint(const std::string& server_name);
+	void SetServerFingerprint(const std::string& serve_name, const std::string& fingerprint);
+
 	/**@}*/
 
 	/* ================================================================ */
@@ -246,10 +247,10 @@ public:
 	void SetSortOrder(const wxString& list_name, const SortOrder& order);
 
 	void SetColumnWidth(const wxString& list_name, const int column_ind, const int column_width);
-	void SetColumnVisibility(const wxString&, const int, const bool);
+	void SetColumnHidden(const wxString&, const int, const bool);
 
 	int GetColumnWidth(const wxString& list_name, const int column);
-	bool GetColumnVisibility(const wxString& list_name, const int column);
+	bool IsColumnHidden(const wxString& list_name, const int column, bool defVal);
 	//! used to signal unset column width in Get...
 	static const int columnWidthUnset = -3;
 	static const int columnWidthMinimum = 5;
