@@ -1,6 +1,6 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
 #ifndef DISABLE_SOUND
+#include "alsound.h"
 
 #ifdef __APPLE__
 #include <OpenAL/al.h>
@@ -8,23 +8,21 @@
 #include <AL/al.h>
 #endif
 
-#include "alsound.h"
-
 #ifdef WIN32
 //win32 compile uses static libs
 #define ALURE_STATIC_LIBRARY
 #endif
 
 #include <alure.h>
-
-#include "sound/ring_sound.h"
-#include "sound/pm_sound.h"
-#include <wx/log.h>
-#include "utils/conversion.h"
-#include <lslutils/globalsmanager.h>
 #include <assert.h>
+#include <lslutils/globalsmanager.h>
+#include <wx/log.h>
 #include <wx/thread.h>
 
+#include "pm_sound.h"
+#include "ring_sound.h"
+#include "utils/conversion.h"
+
 ALsound& slsound()
 {
 	static LSL::Util::LineInfo<ALsound> m(AT);
@@ -41,7 +39,7 @@ static void eos_callback(void*, ALuint)
 class soundThread : public wxThread
 {
 public:
-	soundThread(int idx)
+	explicit soundThread(int idx)
 	    : wxThread(wxTHREAD_JOINABLE)
 	{
 		m_idx = idx;
