@@ -15,33 +15,32 @@ lsl/spring/spring.cpp
 //
 // Class: Spring
 //
+#include "spring.h"
 
+#include <lsl/battle/tdfcontainer.h>
+#include <lslunitsync/unitsync.h>
+#include <lslutils/conversion.h>
+#include <lslutils/globalsmanager.h>
 #include <wx/filename.h>
 #include <wx/log.h>
 
-#include <stdexcept>
-#include <vector>
+#include <algorithm>
 #include <clocale>
 #include <fstream>
+#include <stdexcept>
+#include <vector>
 
-#include <lsl/battle/tdfcontainer.h>
-#include <lslutils/globalsmanager.h>
-#include <lslutils/conversion.h>
-#include <lslunitsync/unitsync.h>
-
-#include "spring.h"
-#include "springprocess.h"
-#include "gui/ui.h"
-#include "gui/mainwindow.h"
 #include "gui/customdialogs.h"
-#include "utils/conversion.h"
-#include "utils/slpaths.h"
-#include "utils/slconfig.h"
-#include "utils/globalevents.h"
-#include "settings.h"
+#include "gui/mainwindow.h"
+#include "gui/ui.h"
 #include "ibattle.h"
 #include "log.h"
-
+#include "settings.h"
+#include "springprocess.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
+#include "utils/slconfig.h"
+#include "utils/slpaths.h"
 
 SLCONFIG("/Spring/Safemode", false, "launch spring in safemode");
 
@@ -81,19 +80,19 @@ bool Spring::IsRunning() const
 
 bool Spring::Run(IBattle& battle)
 {
-	std::string executable = SlPaths::GetSpringBinary(battle.GetEngineVersion());
+	const std::string executable = SlPaths::GetSpringBinary(battle.GetEngineVersion());
 	if (!wxFile::Exists(TowxString(executable))) {
-		executable = SlPaths::GetSpringBinary(SlPaths::GetCompatibleVersion(battle.GetEngineVersion())); //fallback, no exact version found, try fallback version
-		if (!wxFile::Exists(TowxString(executable))) {
-			customMessageBoxNoModal(SL_MAIN_ICON, wxString::Format(_T("The spring executable version '%s' was not found at the set location '%s', please re-check."), battle.GetEngineVersion().c_str(), executable.c_str()), _T("Executable not found"));
-			ui().mw().ShowConfigure(MainWindow::OPT_PAGE_SPRING);
-			return false;
-		}
+		customMessageBoxModal(SL_MAIN_ICON, wxString::Format(
+		  _T("The Spring engine executable version '%s' was not found at the set location '%s', please re-check."),
+		  battle.GetEngineVersion().c_str(), executable.c_str()), _T("Executable not found"));
+		ui().mw().ShowConfigure(MainWindow::OPT_PAGE_SPRING);
+		return false;
 	}
+	wxLogMessage("Going to start version %s with %s", battle.GetEngineVersion().c_str(), executable.c_str());
 
 	wxArrayString params;
 
-	const std::string demopath = battle.GetPlayBackFilePath();
+	const std::string& demopath = battle.GetPlayBackFilePath();
 	if (!demopath.empty()) {
 		params.push_back(TowxString(demopath));
 		return LaunchEngine(executable, params);
@@ -134,8 +133,16 @@ bool Spring::LaunchEngine(const std::string& cmd, wxArrayString& params)
 	if (cfg().ReadBool(_T( "/Spring/Safemode" ))) {
 		params.push_back(_T("--safemode"));
 	}
-	wxLogMessage(_T("spring call params: %s"), TowxString(cmd).c_str());
-	wxSetWorkingDirectory(TowxString(SlPaths::GetDataDir()));
+	std::string stdparams;
+	for (const wxString param: params) {
+		if (!stdparams.empty())
+			stdparams += " ";
+		stdparams += STD_STRING(param);
+	}
+
+	const std::string datadir = SlPaths::GetDataDir();
+	wxLogMessage(_T("spring call params: %s %s %s"),datadir.c_str(), TowxString(cmd).c_str(), stdparams.c_str());
+	wxSetWorkingDirectory(TowxString(datadir));
 
 	if (m_process == 0) {
 		m_process = new SpringProcess(*this);
@@ -215,7 +222,7 @@ std::string Spring::WriteScriptTxt(IBattle& battle) const
 		case BT_Played:
 			break;
 		case BT_Replay: {
-			wxString path = TowxString(battle.GetPlayBackFilePath());
+			wxString path(battle.GetPlayBackFilePath());
 			if (path.Find(_T("/")) != wxNOT_FOUND)
 				path.BeforeLast(_T('/'));
 			tdf.AppendStr("DemoFile", STD_STRING(path));
@@ -223,7 +230,7 @@ std::string Spring::WriteScriptTxt(IBattle& battle) const
 			break;
 		}
 		case BT_Savegame: {
-			wxString path = TowxString(battle.GetPlayBackFilePath());
+			wxString path(battle.GetPlayBackFilePath());
 			if (path.Find(_T("/")) != wxNOT_FOUND)
 				path.BeforeLast(_T('/'));
 			tdf.AppendStr("Savefile", STD_STRING(path));
@@ -285,7 +292,7 @@ std::string Spring::WriteScriptTxt(IBattle& battle) const
 	}
 	tdf.LeaveSection();
 
-	std::map<std::string, int> units = battle.RestrictedUnits();
+	const std::map<std::string, int>& units = battle.GetRestrictedUnits();
 	tdf.AppendInt("NumRestrictions", units.size());
 	tdf.EnterSection("RESTRICT");
 	int restrictcount = 0;
