@@ -3,6 +3,7 @@
 //
 // Class: SpringLobbyApp
 //
+#include "springlobbyapp.h"
 
 #ifdef _MSC_VER
 #ifndef NOMINMAX
@@ -11,59 +12,54 @@
 #include <winsock2.h>
 #endif // _MSC_VER
 
+#include <lslunitsync/unitsync.h>
+#include <lslutils/config.h>
+#include <lslutils/globalsmanager.h>
+#include <wx/choicdlg.h>
+#include <wx/cmdline.h>
+#include <wx/debugrpt.h>
+#include <wx/dirdlg.h>
+#include <wx/file.h>
+#include <wx/filefn.h>
+#include <wx/filename.h>
+#include <wx/fs_zip.h> //filesystem zip handler
+#include <wx/image.h>
 #include <wx/intl.h>
 #include <wx/msgdlg.h>
-#include <wx/stdpaths.h>
-#include <wx/filefn.h>
-#include <wx/image.h>
-#include <wx/cmdline.h>
-#include <wx/choicdlg.h>
-#include <wx/filename.h>
-#include <wx/dirdlg.h>
-#include <wx/tooltip.h>
-#include <wx/file.h>
-#include <wx/wfstream.h>
-#include <wx/fs_zip.h> //filesystem zip handler
 #include <wx/socket.h>
+#include <wx/stdpaths.h>
+#include <wx/tooltip.h>
+#include <wx/utils.h>
+#include <wx/wfstream.h>
 #ifdef __WXMSW__
 #include <wx/msw/registry.h>
 #endif
-#include <wx/utils.h>
-#include <wx/wfstream.h>
-
-#include "springlobbyapp.h"
-#include "gui/mainwindow.h"
-#include "settings.h"
-#include "utils/slconfig.h"
-#include "crashreport.h"
-#include "gui/controls.h"
-#include "utils/platform.h"
-#include "utils/version.h"
-#include "utils/globalevents.h"
-#include "channel.h"
-#include "gui/customdialogs.h"
-#include "downloader/prdownloader.h"
-#include <lslutils/globalsmanager.h>
-#include <lslutils/config.h>
-#include <lslunitsync/unitsync.h>
-#include "gui/notifications/notificationmanager.h"
-#include "utils/wxTranslationHelper.h"
-#include "gui/playback/playbacktab.h"
-#include "utils/slpaths.h"
-#include "downloader/lib/src/FileSystem/FileSystem.h"
-#include "log.h"
-#include "utils/conversion.h"
-#include "gui/ui.h"
-#include "servermanager.h"
-#include "gui/iconscollection.h"
-
-#include <wx/debugrpt.h>
-#include <wx/intl.h>
-
 #if wxUSE_UNIX
 #include <X11/Xlib.h>
 #endif
 
+#include "channel.h"
+#include "downloader/lib/src/FileSystem/FileSystem.h"
+#include "downloader/prdownloader.h"
+#include "gui/controls.h"
+#include "gui/customdialogs.h"
+#include "gui/iconscollection.h"
+#include "gui/mainwindow.h"
+#include "gui/notifications/notificationmanager.h"
+#include "gui/playback/playbacktab.h"
+#include "gui/ui.h"
+#include "log.h"
+#include "servermanager.h"
+#include "settings.h"
+#include "stacktrace.h"
+#include "sysinfo.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
+#include "utils/platform.h"
+#include "utils/slconfig.h"
+#include "utils/slpaths.h"
+#include "utils/version.h"
+#include "utils/wxTranslationHelper.h"
 
 SLCONFIG("/ResetLayout", false, "reset layout on restart");
 
@@ -75,11 +71,11 @@ END_EVENT_TABLE()
 SpringLobbyApp::SpringLobbyApp()
     : quit_called(false)
     , m_translationhelper(NULL)
-    , m_log_verbosity(3)
+    , m_log_verbosity(6)
     , m_log_console(true)
     , m_log_window_show(false)
     , m_crash_handle_disable(false)
-    , m_appname(_T("SpringLobby"))
+    , m_appname(GetSpringlobbyName())
 {
 #if wxUSE_UNIX
 	/*
@@ -98,6 +94,29 @@ The error was 'RenderBadPicture (invalid Picture parameter)'.
 #endif
 }
 
+SLCONFIG("/General/LocalePath", "", "Path to locales");
+
+static wxString getLocalePath()
+{
+	wxString path = cfg().ReadString("/General/LocalePath");
+
+	if (path.empty()) {
+#ifdef __WXMSW__
+		path = wxPathOnly(wxStandardPaths::Get().GetExecutablePath()) + wxFileName::GetPathSeparator() + _T("locale");
+#else
+#if defined(LOCALE_INSTALL_DIR)
+		path = _T(LOCALE_INSTALL_DIR);
+#else
+	// use a dummy name here, we're only interested in the base path
+		path = wxStandardPaths::Get().GetLocalizedResourcesDir(_T("noneWH"), wxStandardPaths::ResourceCat_Messages);
+		path = path.Left(path.First(_T("noneWH")));
+#endif
+#endif
+		cfg().Write("/General/LocalePath", path);
+	}
+	return path;
+}
+
 //! @brief Initializes the application.
 //!
 //! It will open the main window and connect default to server or open the connect window.
@@ -111,12 +130,16 @@ bool SpringLobbyApp::OnInit()
 	SetAppName(m_appname);
 #if wxUSE_ON_FATAL_EXCEPTION
 	wxHandleFatalExceptions(!m_crash_handle_disable);
+#else
+	try {
 #endif
 
+	const wxString m_log_file_path = SlPaths::GetLobbyWriteDir() + "springlobby.log";
+
 	//initialize all loggers, we'll use the returned pointer to set correct parent window later
 	wxLogWindow* loggerwin = Logger::InitializeLoggingTargets(0, m_log_console, m_log_file_path, m_log_window_show, m_log_verbosity);
 
-	wxLogMessage(_T("SpringLobby %s started"), TowxString(getSpringlobbyVersion()).c_str());
+	wxLogMessage(_T("%s started"), TowxString(GetSpringlobbyAgent()).c_str());
 
 	//this needs to called _before_ mainwindow instance is created
 	wxInitAllImageHandlers();
@@ -124,23 +147,14 @@ bool SpringLobbyApp::OnInit()
 	wxSocketBase::Initialize();
 
 
-#ifdef __WXMSW__
-	wxString path = wxPathOnly(wxStandardPaths::Get().GetExecutablePath()) + wxFileName::GetPathSeparator() + _T("locale");
-#else
-#if defined(LOCALE_INSTALL_DIR)
-	wxString path(_T(LOCALE_INSTALL_DIR));
-#else
-	// use a dummy name here, we're only interested in the base path
-	wxString path = wxStandardPaths::Get().GetLocalizedResourcesDir(_T("noneWH"), wxStandardPaths::ResourceCat_Messages);
-	path = path.Left(path.First(_T("noneWH")));
-#endif
-#endif
-	m_translationhelper = new wxTranslationHelper(GetAppName().Lower(), path);
+	m_translationhelper = new wxTranslationHelper(GetAppName().Lower(), getLocalePath());
 
-	const wxString configdir = TowxString(SlPaths::GetConfigfileDir());
-	SlPaths::mkDir(STD_STRING((configdir)));
+	const std::string configdir = SlPaths::GetConfigfileDir();
+	wxLogMessage("Config dir: %s", configdir.c_str());
+	SlPaths::mkDir(configdir);
 
 	if (cfg().ReadBool(_T("/ResetLayout"))) {
+		wxLogMessage("Resetting Layout...");
 		//we do this early on and reset the config var a little later so we can save a def. perps once mw is created
 		sett().RemoveLayouts();
 		cfg().Write(_T( "/ResetLayout" ), false);
@@ -155,25 +169,41 @@ bool SpringLobbyApp::OnInit()
 		SlPaths::SetSpringBinary(SlPaths::GetCurrentUsedSpringIndex(), SlPaths::GetSpringBinary());
 		SlPaths::SetUnitSync(SlPaths::GetCurrentUsedSpringIndex(), SlPaths::GetUnitSync());
 	}
-
+	wxLogMessage("Configuring Unitsync...");
 	// configure unitsync paths before trying to load
 	SlPaths::ReconfigureUnitsync();
 
-	//unitsync first load, NEEDS to be blocking
-	SlPaths::RefreshSpringVersionList();
-	LSL::usync().ReloadUnitSyncLib();
-
-
 	sett().Setup(m_translationhelper);
 
 	notificationManager(); //needs to be initialized too
+
+	wxLogMessage("Showing Main Window");
 	ui().ShowMainWindow();
 	SetTopWindow(&ui().mw());
+	ui().mw().SetLogWin(loggerwin);
+
+	//unitsync first load, FIXME move to a thread!
+	wxLogMessage("Refreshing Spring Version List...");
+	SlPaths::RefreshSpringVersionList();
+	if (LSL::usync().ReloadUnitSyncLib()) {
+		GlobalEventManager::Instance()->Send(GlobalEventManager::OnUnitsyncReloaded);
+	} else {
+		wxLogWarning("Couldn't load unitsync");
+	}
+
+	wxLogWarning("%s", TowxString(GetSpringlobbyInfo()).c_str());
 
 	ui().OnInit();
 
-	ui().mw().SetLogWin(loggerwin);
-	return true;
+#if !wxUSE_ON_FATAL_EXCEPTION
+}
+catch (std::exception& ex)
+{
+	wxLogError(_T("Error had happened: " + wxString(ex.what())));
+}
+#endif
+
+return true;
 }
 
 
@@ -193,10 +223,10 @@ int SpringLobbyApp::OnExit()
 
 	IconsCollection::Release();
 	ServerManager::Release();
-	GlobalEventManager::Release();
 	SetEvtHandlerEnabled(false);
 	UiEvents::GetNotificationEventSender().Enable(false);
 	LSL::Util::DestroyGlobals();
+	GlobalEventManager::Release();
 
 	return 0;
 }
@@ -204,7 +234,13 @@ int SpringLobbyApp::OnExit()
 //! @brief is called when the app crashes
 void SpringLobbyApp::OnFatalException()
 {
-	CrashReport::instance().GenerateReport();
+	wxLogError("Fatal exception!");
+
+	StackTrace stackTracer;
+	stackTracer.WalkFromException();
+	auto trace = stackTracer.GetStackTrace();
+
+	wxLogError("Stack trace: " + trace);	
 }
 
 
@@ -219,7 +255,6 @@ void SpringLobbyApp::OnInitCmdLine(wxCmdLineParser& parser)
 	    {
 	     {wxCMD_LINE_SWITCH, "h", "help", wxTRANSLATE("show this help message"), wxCMD_LINE_VAL_NONE, wxCMD_LINE_OPTION_HELP},
 	     {wxCMD_LINE_SWITCH, "nc", "no-crash-handler", wxTRANSLATE("don't use the crash handler (useful for debugging)"), wxCMD_LINE_VAL_NONE, wxCMD_LINE_PARAM_OPTIONAL},
-	     {wxCMD_LINE_OPTION, "fl", "file-logging", wxTRANSLATE("dumps application log to a file ( enter path )"), wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL | wxCMD_LINE_NEEDS_SEPARATOR},
 	     {wxCMD_LINE_SWITCH, "cl", "console-logging", wxTRANSLATE("shows application log to the console(if available)"), wxCMD_LINE_VAL_NONE, wxCMD_LINE_PARAM_OPTIONAL},
 	     {wxCMD_LINE_SWITCH, "gl", "gui-logging", wxTRANSLATE("enables application log window"), wxCMD_LINE_VAL_NONE, wxCMD_LINE_PARAM_OPTIONAL},
 	     {wxCMD_LINE_OPTION, "f", "config-file", wxTRANSLATE("override default choice for config-file"), wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL | wxCMD_LINE_NEEDS_SEPARATOR},
@@ -240,7 +275,6 @@ bool SpringLobbyApp::OnCmdLineParsed(wxCmdLineParser& parser)
 	if (!parser.Parse(true)) {
 		m_log_console = parser.Found(_T("console-logging"));
 		m_log_window_show = parser.Found(_T("gui-logging"));
-		parser.Found(_T("file-logging"), &m_log_file_path);
 		m_crash_handle_disable = parser.Found(_T("no-crash-handler"));
 		parser.Found(_T("log-verbosity"), &m_log_verbosity);
 
@@ -263,7 +297,7 @@ bool SpringLobbyApp::OnCmdLineParsed(wxCmdLineParser& parser)
 			return false; // not a syntax error, but program should stop if user asked for command line usage
 
 		if (parser.Found(_T("version"))) {
-			wxLogMessage(TowxString(getSpringlobbyVersion()).c_str());
+			wxLogMessage(TowxString(GetSpringlobbyVersion()).c_str());
 			return false;
 		}
 		return true;
@@ -275,5 +309,6 @@ bool SpringLobbyApp::OnCmdLineParsed(wxCmdLineParser& parser)
 
 void SpringLobbyApp::OnQuit(wxCommandEvent& /*data*/)
 {
+	wxLogWarning("MainWindow::OnClose");
 	GlobalEventManager::Instance()->Send(GlobalEventManager::OnQuit);
 }
