@@ -1,22 +1,20 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
 #include "tab_quality_video.h"
-#include <wx/string.h>
-#include <wx/sizer.h>
-#include <wx/event.h>
-#include <wx/defs.h>
-#include <wx/slider.h>
-#include <wx/checkbox.h>
-#include <wx/stattext.h>
-#include <wx/checkbox.h>
-#include <wx/radiobut.h>
-#include <wx/combobox.h>
-#include <wx/textctrl.h>
-#include <wx/spinctrl.h>
 
-#include "utils/conversion.h"
+#include <wx/checkbox.h>
+#include <wx/combobox.h>
+#include <wx/defs.h>
+#include <wx/event.h>
+#include <wx/radiobut.h>
+#include <wx/sizer.h>
+#include <wx/slider.h>
+#include <wx/spinctrl.h>
+#include <wx/stattext.h>
+#include <wx/string.h>
+#include <wx/textctrl.h>
 
 #include "ctrlconstants.h"
+#include "utils/conversion.h"
 
 void tab_quality_video::initVideoSizer(wxFlexGridSizer* sizer)
 {
@@ -64,8 +62,8 @@ void tab_quality_video::updateControls(int what_to_update)
 	}
 
 	if (what_to_update == UPDATE_VIDEO_MODE || what_to_update == UPDATE_ALL) {
-		ctrl_x_res->SetValue(wxString::Format(_("%d"), intSettings[RC_TEXT[0].key]));
-		ctrl_y_res->SetValue(wxString::Format(_("%d"), intSettings[RC_TEXT[1].key]));
+		ctrl_x_res->SetValue(wxString::Format(_T("%d"), intSettings[RC_TEXT[0].key]));
+		ctrl_y_res->SetValue(wxString::Format(_T("%d"), intSettings[RC_TEXT[1].key]));
 	}
 	if (what_to_update == UPDATE_QA_BOXES || what_to_update == UPDATE_ALL) {
 		//option 7-9 are not on presets
