@@ -14,10 +14,6 @@ struct StoredGame
 	bool can_watch;
 	int duration; //in seconds
 	int size;     //in bytes
-	std::string MapName;
-	std::string ModName;
-	std::string SpringVersion;
-	std::string Filename;
 	time_t date;
 	std::string date_string;
 	OfflineBattle battle;
@@ -53,10 +49,6 @@ struct StoredGame
 		can_watch = moved.can_watch;
 		duration = moved.duration;
 		size = moved.size;
-		MapName = moved.MapName;
-		ModName = moved.ModName;
-		SpringVersion = moved.SpringVersion;
-		Filename = moved.Filename;
 		date = moved.date;
 		date_string = moved.date_string;
 		battle.operator=((OfflineBattle && )moved.battle);
@@ -65,7 +57,7 @@ struct StoredGame
 
 	bool Equals(const StoredGame& other) const
 	{
-		return Filename == other.Filename;
+		return battle.GetPlayBackFilePath() == other.battle.GetPlayBackFilePath();
 	}
 };
 
