@@ -1,17 +1,30 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
-
 #define BOOST_TEST_MODULE lobbyid
-#include <boost/test/unit_test.hpp>
 
+#include <boost/test/unit_test.hpp>
+#include <lslutils/conversion.h>
+#include <lslutils/misc.h>
 #include <stdio.h>
 #include <wx/colour.h>
-#include <lslutils/misc.h>
-#include <lslutils/conversion.h>
 
+#include "testingstuff/silent_logger.h"
 #include "user.h"
-#include "utils/lslconversion.h"
 #include "utils/conversion.h"
+#include "utils/lslconversion.h"
+#include "utils/tasutil.h"
 
+struct TestInitializer
+{
+	TestInitializer()
+	{
+		InitWxLogger();
+	}
+	~TestInitializer()
+	{
+	}
+};
+
+BOOST_GLOBAL_FIXTURE(TestInitializer);
 
 void test_wxColourTolsl(const unsigned char red, const unsigned char green, const unsigned char blue, const unsigned char alpha)
 {
@@ -210,6 +223,10 @@ BOOST_AUTO_TEST_CASE(convertfloat)
 	BOOST_CHECK(b == LSL::Util::FromFloatString("-1.5"));
 	BOOST_CHECK(c == LSL::Util::FromFloatString("1.999"));
 
+	BOOST_CHECK(a == LSL::Util::FromFloatString("1,0"));
+	BOOST_CHECK(b == LSL::Util::FromFloatString("-1,5"));
+	BOOST_CHECK(c == LSL::Util::FromFloatString("1,999"));
+
 	BOOST_CHECK(a == LSL::Util::FromFloatString(LSL::Util::ToFloatString(a)));
 	BOOST_CHECK(b == LSL::Util::FromFloatString(LSL::Util::ToFloatString(b)));
 	BOOST_CHECK(c == LSL::Util::FromFloatString(LSL::Util::ToFloatString(c)));
@@ -254,3 +271,48 @@ BOOST_AUTO_TEST_CASE(tokenize)
 	BOOST_CHECK(v.size() == 1);
 	BOOST_CHECK(v[0] == "0");
 }
+
+
+BOOST_AUTO_TEST_CASE(tasutils)
+{
+	std::string input = "BATTLECLOSED 18172";
+	BOOST_CHECK(GetWordParam(input) == "BATTLECLOSED");
+	BOOST_CHECK(GetIntParam(input) == 18172);
+	BOOST_CHECK(input.empty());
+
+	input = "A B C";
+
+	BOOST_CHECK(GetParamByChar(input, ' ') == "A");
+	BOOST_CHECK(GetParamByChar(input, ' ') == "B");
+	BOOST_CHECK(GetParamByChar(input, ' ') == "C");
+	BOOST_CHECK(GetParamByChar(input, ' ').empty());
+	BOOST_CHECK(input.empty());
+
+	input = "A\tB\tC";
+	BOOST_CHECK(GetSentenceParam(input) == "A");
+	BOOST_CHECK(GetSentenceParam(input) == "B");
+	BOOST_CHECK(GetSentenceParam(input) == "C");
+	BOOST_CHECK(GetSentenceParam(input).empty());
+	BOOST_CHECK(input.empty());
+
+	input = "1 0 1";
+	BOOST_CHECK(GetBoolParam(input));
+	BOOST_CHECK(!GetBoolParam(input));
+	BOOST_CHECK(GetBoolParam(input));
+	BOOST_CHECK(!GetBoolParam(input)); //input is already empty
+	BOOST_CHECK(input.empty());
+
+	BOOST_CHECK(LSL::Util::ToLower("AbCdEfghIJ") == "abcdefghij");
+	BOOST_CHECK(LSL::Util::ToLower("A") == "a");
+	BOOST_CHECK(LSL::Util::ToLower("") == "");
+
+	BOOST_CHECK(LSL::Util::FromLongString("1238129312390") == 1238129312390l);
+	BOOST_CHECK(LSL::Util::FromLongString("-1238129312390") == -1238129312390l);
+	BOOST_CHECK(LSL::Util::FromLongString("") == 0l);
+
+	BOOST_CHECK(LSL::Util::FromIntString("2147483647") == INT_MAX);
+	//Check for overflow
+	BOOST_CHECK(LSL::Util::FromIntString("2147483648") == INT_MIN);
+	BOOST_CHECK(LSL::Util::FromIntString("-2147483647") == INT_MIN + 1);
+	BOOST_CHECK(LSL::Util::FromIntString("") == 0);
+}
