@@ -4,21 +4,12 @@
 #include "curlhelper.h"
 #include "settings.h"
 
+#include <curl/curl.h>
 #include <curl/easy.h>
+#include "downloader/prdownloader.h"
+#include "downloader/lib/src/Downloader/CurlWrapper.h"
 
 extern "C" {
-size_t wxcurl_string_write(void* ptr, size_t size, size_t nmemb, void* pcharbuf)
-{
-	size_t iRealSize = size * nmemb;
-	wxCharBuffer* pStr = (wxCharBuffer*)pcharbuf;
-
-	if (pStr) {
-		wxString str = wxCURL_BUF2STRING(*pStr) + wxString((const char*)ptr, wxConvLibc);
-		*pStr = wxCURL_STRING2BUF(str);
-	}
-
-	return iRealSize;
-}
 size_t wxcurl_stream_write(void* ptr, size_t size, size_t nmemb, void* stream)
 {
 	size_t iRealSize = size * nmemb;
@@ -33,21 +24,6 @@ size_t wxcurl_stream_write(void* ptr, size_t size, size_t nmemb, void* stream)
 
 	return 0;
 }
-/* reads from a stream */
-size_t wxcurl_stream_read(void* ptr, size_t size, size_t nmemb, void* stream)
-{
-	size_t iRealSize = size * nmemb;
-
-	wxInputStream* pBuf = (wxInputStream*)stream;
-
-	if (pBuf) {
-		pBuf->Read(ptr, iRealSize);
-
-		return pBuf->LastRead();
-	}
-
-	return 0;
-}
 } //end extern "C"
 
 
@@ -55,12 +31,13 @@ wxString Paste2Pastebin(const wxString& message)
 {
 	wxStringOutputStream response;
 	wxStringOutputStream rheader;
-	CURL* curl_handle;
-	curl_handle = curl_easy_init();
+	prDownloader().UpdateSettings();
+	CurlWrapper cw;
+	CURL* curl_handle = cw.GetHandle();
 	struct curl_slist* m_pHeaders = NULL;
 	struct curl_httppost* m_pPostHead = NULL;
 	struct curl_httppost* m_pPostTail = NULL;
-	static const char* url = "http://paste.springfiles.com/api/create";
+	static const char* url = "https://paste.springfiles.com/api/create";
 	// these header lines will overwrite/add to cURL defaults
 	m_pHeaders = curl_slist_append(m_pHeaders, "Expect:");
 
@@ -95,7 +72,6 @@ wxString Paste2Pastebin(const wxString& message)
 	CURLcode ret = curl_easy_perform(curl_handle);
 
 	/* cleanup curl stuff */
-	curl_easy_cleanup(curl_handle);
 	curl_formfree(m_pPostHead);
 
 	if (ret == CURLE_OK) {
